% #########################################################################
% This is the replication file to reproduce the following Tables and Figure 
% in the Online Appendix:
% - Tables  D.6 - D.14
% - Figures D.1 - D.7 
% of the paper:
%
% ``Inference in Group Factor Models 
%   with an Application to Mixed Frequency Data''
% 
% by Elena Andreou, Patrick Gagliardini, Eric Ghysels, Mirco Rubin 
%--------------------------------------------------------------------------
% Date  : 31.03.2019
% Author: Mirco Rubin
% Email : mircorubin@gmail.com
% updated files can be found also on the author's website:
% Web   : https://sites.google.com/site/mircorubin/ 
%##########################################################################
clear all; close all;  clc;
% #########################################################################
% Select set of sectoral indices by uncommenting the relevant sets
SEC_IND_SUBSET = 1 ; % ALL           sectoral quarterly IP  indexes
% SEC_IND_SUBSET = 2 ; % ALL           sectoral annual    GDP indexes
% SEC_IND_SUBSET = 3 ; % MANUFACTURING sectoral annual    GDP indexes
% SEC_IND_SUBSET = 4 ; % NON-MANUFACT. sectoral annual    GDP indexes
%##########################################################################
% NO NEED TO NOT CHANGE CODE FROM HERE ONWARDS
%--------------------------------------------------------------------------
% Data loading
load IP_data
load GDP_data
%--------------------------------------------------------------------------
%Figure D.1 : Sectoral Decomposition of US GDP
w_temp = gdp_nominal_weights_all ; T_temp = size(w_temp,2) ;

% Create vectors of weights for each macro-sector
man_w_TS = w_temp(12,:) ; % Manifacturing (line 12 in 'gdp_nominal_weights_all' matrix )

% NON MANUFACTURING AGGREGATES
farm_w_TS  = w_temp( 4,:) ; % farms        (line 4  )
for_w_TS   = w_temp( 5,:) ; % forestry     (line 5  )
min_w_TS   = w_temp( 6,:) ; % mining       (line 6  )
util_w_TS  = w_temp(10,:) ; % Utilities    (line 10 )
const_w_TS = w_temp(11,:) ; % Construction (line 11 ) 

% Services (lines 34,35,36,45,50,59,68,74,81)
serv_w_TS = w_temp(34,:) + w_temp(35,:) + w_temp(36,:) + ...
            w_temp(45,:) + w_temp(50,:) + w_temp(59,:) + ...    
            w_temp(68,:) + w_temp(74,:) + w_temp(81,:) ;

gov_w_TS = w_temp(82,:)   ; % Government   (line 82 )

% IP sectors: sum of manufacturing, utilities, forestry, and mining
man_util_for_mining_w_TS = man_w_TS + util_w_TS + for_w_TS + min_w_TS ; 
% OTHER: farms, not included in IP sectors
farm_resid_w_TS  = 100*ones(1,35) - (man_util_for_mining_w_TS + serv_w_TS + const_w_TS + gov_w_TS)  ; 
% Matrix for AREA plot : TS of weights of sector-aggregates
area_mtx_temp    = [man_util_for_mining_w_TS', serv_w_TS', gov_w_TS', const_w_TS', farm_resid_w_TS'];
%--------------------------------------------------------------------------
% Generate Figure D.1 : Sectoral Decomposition of US GDP
disp(['================================================================='])
disp(['Generate Figure D.1'])
figure; h = area(area_mtx_temp);
set(h(1),'FaceColor', 'yellow'     ) ; set(h(2),'FaceColor', [0.8 0 0])
set(h(3),'FaceColor', 'green'      ) ; set(h(4),'FaceColor', 'white')
set(h(5),'FaceColor', [0.6 0.6 0.6])
set(gca,'YGrid','on'); set(gca,'Layer','top')
gdp_year_1977_2011 = {'77','78','79', ...
                      '80','81','82','83','84','85','86','87','88','89', ...
                      '90','91','92','93','94','95','96','97','98','99', ...
                      '00','01','02','03','04','05','06','07','08','09', ...
                      '10','11'}; % x-axis label
lab_sel = 1:2:T_temp ;  % plot 1 label every 2 years            
%--------------------------------------------------------------------------
% labels used later of IP
ip_year_rep_temp  = [gdp_year_1977_2011;gdp_year_1977_2011;gdp_year_1977_2011;gdp_year_1977_2011];
ip_year_1977_2011_rep4 =  reshape(ip_year_rep_temp,[1,4*size(ip_year_rep_temp,2)]);
lab_sel_rep4 = 1:8:size(ip_year_1977_2011_rep4,2) ;  % plot 1 label every 2 years            
%--------------------------------------------------------------------------
set(gca, 'XTick'     , lab_sel )                    ; 
set(gca, 'XTickLabel', gdp_year_1977_2011(lab_sel)) ;
ylabel('Share of nominal GDP (\%)','interpreter','latex','FontSize',10);
xlabel('Year','interpreter','latex','FontSize',10);  
title('Figure D.1');
%--------------------------------------------------------------------------
t1 = annotation('textbox',[0.18 0.1   0.4 0.15],'String','INDUSTRIAL PRODUCTION'); t1.LineStyle = 'none';
t2 = annotation('textbox',[0.18 0.3   0.4 0.15],'String','SERVICES')             ; t2.LineStyle = 'none';
t3 = annotation('textbox',[0.18 0.7   0.4 0.15],'String','GOVERNMENT')           ; t3.LineStyle = 'none';
t4 = annotation('textbox',[0.55 0.779 0.4 0.15],'String','CONSTRUCTION')         ; t4.LineStyle = 'none';
%--------------------------------------------------------------------------
% Uncomment next 4 lines to Manually positon/modify labels in figure
% and comment the previous 4 lines.
% gtext('\textbf{INDUSTRIAL PRODUCTION}','interpreter','latex','FontSize',16)
% gtext('\textbf{SERVICES}','interpreter','latex','FontSize',16)
% gtext('\textbf{GOVERNMENT}','interpreter','latex','FontSize',14)
% gtext('\textbf{CONSTRUCTION}','interpreter','latex','FontSize',10)
%--------------------------------------------------------------------------
% Generate Tables D.3 - D.14, and Figures D.2 - D.7
% The following 4 sample periods are selected:
% 1977 - 2011 (full sample),  1977 - 1983, 1984 - 2007, 2008 - 2011 
%==========================================================================
if SEC_IND_SUBSET == 1 % IP quarterly data
% 1977.Q1 - 1983.Q4
sely_start     = 1977 ; selq_start = 1 ; 
sely_end       = 2011 ; selq_end   = 4 ;  
[r_ip_start,~] = find((IPq_g_year == sely_start)& (IPq_g_quarter == selq_start)) ;
[r_ip_end,~]   = find((IPq_g_year == sely_end)  & (IPq_g_quarter == selq_end))   ;
dates_7711   = r_ip_start:r_ip_end   ; 
%--------------------------------------------------------------------------
% 1977.Q1 - 1983.Q4
sely_start     = 1977 ; selq_start = 1 ; 
sely_end       = 1983 ; selq_end   = 4 ; 
[r_ip_start,~] = find((IPq_g_year == sely_start)& (IPq_g_quarter == selq_start)) ;
[r_ip_end,~]   = find((IPq_g_year == sely_end)  & (IPq_g_quarter == selq_end))   ;
dates_7783   = r_ip_start:r_ip_end   ;
%--------------------------------------------------------------------------
% 1984.Q1 - 2007.Q4 
sely_start     = 1984 ; selq_start = 1 ; 
sely_end       = 2007 ; selq_end   = 4 ; 
[r_ip_start,~] = find((IPq_g_year == sely_start)& (IPq_g_quarter == selq_start)) ;
[r_ip_end,~]   = find((IPq_g_year == sely_end)  & (IPq_g_quarter == selq_end))   ;
dates_8407   = r_ip_start:r_ip_end   ;
%--------------------------------------------------------------------------
% 2008.Q1-2011.Q4 
sely_start     = 2008 ; selq_start = 1 ;
sely_end       = 2011 ; selq_end   = 4 ;  
[r_ip_start,~] = find((IPq_g_year == sely_start) & (IPq_g_quarter == selq_start));
[r_ip_end,~]   = find((IPq_g_year == sely_end)   & (IPq_g_quarter == selq_end))  ;
dates_0811   = r_ip_start:r_ip_end   ;
%--------------------------------------------------------------------------    
elseif (SEC_IND_SUBSET == 2 || SEC_IND_SUBSET == 3 || SEC_IND_SUBSET == 4) % GDP annual data
% SELECT SAMPLE PERIOD: 1977 - 1983
sely_start    = 1977 ; sely_end = 2011         ; % start & end years
[~,r_start]   = find((gdp_year == sely_start)) ;
[~,r_end]     = find((gdp_year == sely_end)  ) ;
dates_7711  = r_start:r_end                  ; % dates vector identifier 
% SELECT SAMPLE PERIOD: 1977 - 1983
sely_start    = 1977 ; sely_end   = 1983       ; 
[~,r_start]   = find((gdp_year == sely_start)) ;
[~,r_end]     = find((gdp_year == sely_end)  ) ;
dates_7783  = r_start:r_end                  ;
% SELECT SAMPLE PERIOD: 1984 - 2007 
sely_start    = 1984 ; sely_end  = 2007        ;  
[~,r_start]   = find((gdp_year == sely_start)) ;
[~,r_end]     = find((gdp_year == sely_end)  ) ;
dates_8407  = r_start:r_end                  ;
% SELECT SAMPLE PERIOD: 2008 - 2011
sely_start    = 2008 ; sely_end   = 2011       ; 
[~,r_start]   = find((gdp_year == sely_start)) ;
[~,r_end]     = find((gdp_year == sely_end)  ) ;
dates_0811  = r_start:r_end                  ;
end
%==========================================================================
% Load data, and rename variables for analysis
if     SEC_IND_SUBSET == 1 % ALL sectoral quarterly IP indexes
x = IPq_g                       ; % matrix of x_it (T X N)
w = IPq_w_quarter/100           ; % matrix of w_it (T X N)
g = IPq_g_INDEX                 ; % vector of g_t  (T X 1)
%--------------------------------------------------------------------------
elseif SEC_IND_SUBSET == 2 % ALL sectoral annual GDP indexes
x = gdp_g_real_allsub'          ; % matrix of x_it (T X N)
w = gdp_nominal_w_allsub'/100   ; % matrix of w_it (T X N)
g = gdp_g_real_index'           ; % vector of g_t  (T X 1)
%--------------------------------------------------------------------------
elseif SEC_IND_SUBSET == 3 % MANUFACTURING sectoral annual GDP indexes
x = gdp_g_real_man'                 ; % matrix of x_it (T X N)
g = gdp_g_real_MANUF_index'         ; % vector similar to g_t  (T X 1)
w_mat_temp = gdp_nominal_w_man'/100 ;
for t = 1:size(x,1)
    w_vec_temp = w_mat_temp(t,:)           ;
    w(t,:)     = w_vec_temp/sum(w_vec_temp);
end
%--------------------------------------------------------------------------
elseif SEC_IND_SUBSET == 4 % NON-MANUFACTURING sectoral annual GDP indexes
x = gdp_g_real_nonIP'                     ; % matrix of x_it (T X N)

w_mat_temp = gdp_nominal_w_nonIP'/100     ;
for t = 1:size(x,1)
    w_vec_temp = w_mat_temp(t,:)           ;
    w(t,:)     = w_vec_temp/sum(w_vec_temp);
end
end
%==========================================================================
% Produce Tables
N = size(x,2) ; T = size(x,1) ;
% Generate growth index using DIFFERENT weights
for t = 1:size(x,1)
    g_t(t,1) = sum(w(t,:).*x(t,:));
end

% Generate growth index using EQUAL weights
g_ew       = mean(x,2)        ; 
w_it_tilde = w - ones(T,N)/N  ;
w_i_bar    = mean(w)          ; % time series mean of weights

for t = 1:T
    g_w_dots(t,1) = sum((w_i_bar-ones(1,N)/N).*x(t,:)) ;
    g_w_hat(t,1)  = sum((w(t,:)-w_i_bar).*x(t,:))      ;
end 
%--------------------------------------------------------------------------
% Table D.3,
% Analogous to TABLE 1 in Foerster, Sarte, Watson (JPE 2011)
%==========================================================================
if SEC_IND_SUBSET == 1 % 
% weighted IP index (Q)
tab1(1,1) = std(g)              ;
tab1(1,2) = std(g(dates_7783))  ;
tab1(1,3) = std(g(dates_8407))  ;
tab1(1,4) = std(g(dates_0811))  ;
% tab1(1,1) = std(g_t)              ;
% tab1(1,2) = std(g_t(dates_7783))  ;
% tab1(1,3) = std(g_t(dates_8407))  ;
% tab1(1,4) = std(g_t(dates_0811))  ;
elseif (SEC_IND_SUBSET == 2 || SEC_IND_SUBSET == 3 || SEC_IND_SUBSET == 4) 
% weighted GDP index (A)
tab1(1,1) = std(g_t)            ;
tab1(1,2) = std(g_t(dates_7783));
tab1(1,3) = std(g_t(dates_8407));
tab1(1,4) = std(g_t(dates_0811));
% tab1(1,1) = std(g)              ;
% tab1(1,2) = std(g(dates_7783))  ;
% tab1(1,3) = std(g(dates_8407))  ;
% tab1(1,4) = std(g(dates_0811))  ;
end
%==========================================================================
% COMPONENTS of aggregate weighted index:
% ST.DEV (g_ew): equally weighted GDP index
tab1(2,1) = std(g_ew)              ;
tab1(2,2) = std(g_ew(dates_7783));
tab1(2,3) = std(g_ew(dates_8407));
tab1(2,4) = std(g_ew(dates_0811));

% ST.DEV sum(w_i - 1/N)*x_it
tab1(3,1) = std(g_w_dots)              ;
tab1(3,2) = std(g_w_dots(dates_7783));
tab1(3,3) = std(g_w_dots(dates_8407));
tab1(3,4) = std(g_w_dots(dates_0811));

% ST.DEV sum(w_it - w_i_bar)*x_it
tab1(4,1) = std(g_w_hat)              ;
tab1(4,2) = std(g_w_hat(dates_7783));
tab1(4,3) = std(g_w_hat(dates_8407));
tab1(4,4) = std(g_w_hat(dates_0811));

disp(['================================================================='])
if SEC_IND_SUBSET == 1
    disp(['Table D.3 in Latex format'])
elseif SEC_IND_SUBSET == 2
    disp(['Table D.6 in Latex format'])    
elseif SEC_IND_SUBSET == 3
    disp(['Table D.9 in Latex format'])
elseif SEC_IND_SUBSET == 4
    disp(['Table D.12 in Latex format'])
end    
disp(['================================================================='])
disp(['~~~~~~~~', ...
     ' & ', '1977-2011', ...
     ' & ', '1977-1983', ...
     ' & ', '1984-2007', ...
     ' & ', '2008-2011', '\\'])
disp(['$g_t = \sum w_{it} x_{it}$'  , ...
     ' & ',num2str(tab1(1,1),'%.1f'), ...
     ' & ',num2str(tab1(1,2),'%.1f'), ...
     ' & ',num2str(tab1(1,3),'%.1f'), ...
     ' & ',num2str(tab1(1,4),'%.1f'), '\\'])
 disp(['$(1/N)\sum x_{it}$'  , ...
     ' & ',num2str(tab1(2,1),'%.1f'), ...
     ' & ',num2str(tab1(2,2),'%.1f'), ...
     ' & ',num2str(tab1(2,3),'%.1f'), ...
     ' & ',num2str(tab1(2,4),'%.1f'), '\\'])
 disp(['$\sum (\bar{w}_{i}-(1/N)) x_{it}$'  , ...
     ' & ',num2str(tab1(3,1),'%.1f'), ...
     ' & ',num2str(tab1(3,2),'%.1f'), ...
     ' & ',num2str(tab1(3,3),'%.1f'), ...
     ' & ',num2str(tab1(3,4),'%.1f'), '\\'])
 disp(['$\sum (w_{it} - \bar{w}_{i}) x_{it}$'  , ...
     ' & ',num2str(tab1(4,1),'%.1f'), ...
     ' & ',num2str(tab1(4,2),'%.1f'), ...
     ' & ',num2str(tab1(4,3),'%.1f'), ...
     ' & ',num2str(tab1(4,4),'%.1f'), '\\'])
%--------------------------------------------------------------------------
% Table D.4
% Analogous to TABLE 2 of Foerster, Sarte, Watson (JPE 2011)
N_corr   = N*(N-1)/2 ;

corr_mtx = corr(x)                         ;
tab2(1,1)= sum(sum(tril(corr_mtx)))/N_corr ;

corr_mtx = corr(x(dates_7783,:))         ;
tab2(1,2)= sum(sum(tril(corr_mtx)))/N_corr ;

corr_mtx = corr(x(dates_8407,:))         ;
tab2(1,3)= sum(sum(tril(corr_mtx)))/N_corr ;

corr_mtx = corr(x(dates_0811,:))         ;
tab2(1,4)= sum(sum(tril(corr_mtx)))/N_corr ;

disp(['================================================================='])
if     SEC_IND_SUBSET == 1; disp(['Table D.4 in Latex format']) ;
elseif SEC_IND_SUBSET == 2; disp(['Table D.7 in Latex format']) ;
elseif SEC_IND_SUBSET == 3; disp(['Table D.10 in Latex format']);
elseif SEC_IND_SUBSET == 4; disp(['Table D.13 in Latex format']);
end  
disp(['================================================================='])
disp(['& ', '1977-2011', ...
     ' & ', '1977-1983', ...
     ' & ', '1984-2007', ...
     ' & ', '2008-2011', '\\'])
disp([' & ',num2str(tab2(1,1),'%.2f'), ...
      ' & ',num2str(tab2(1,2),'%.2f'), ...
      ' & ',num2str(tab2(1,3),'%.2f'), ...
      ' & ',num2str(tab2(1,4),'%.2f'), '\\'])
%--------------------------------------------------------------------------
% Table D.5 
% Analogous to TABLE 3 of Foerster, Sarte, Watson (JPE 2011)
%--------------------------------------------------------------------------
% 1977-2011
x_temp    = x(:,:)    ;
w_temp    = w(:,:)    ;

if SEC_IND_SUBSET == 1  
% weighted IP index
g_temp    = g(:,:)  ;
elseif (SEC_IND_SUBSET == 2 || SEC_IND_SUBSET == 3 || SEC_IND_SUBSET == 4) 
% weighted GDP index 
g_temp    = g_t(:,:)  ;
end

g_ew_temp = g_ew(:,:) ;
[T,N]     = size(x)   ;

x_i_bar_mtx = repmat(mean(x_temp),T,1);
% w
tab3(1,1) = std(g_temp);
tab3(2,1) = sqrt( (1/T)*sum(sum((w_temp.^2).*((x_temp - x_i_bar_mtx).^2) )));
% 1/N
tab3(3,1) = std(g_ew_temp);
tab3(4,1) = sqrt( (1/T)*sum(sum(((ones(T,N)/N).^2).*((x_temp - x_i_bar_mtx).^2) )));
%--------------------------------------------------------------------------
% 1977-1983
x_temp    = x(dates_7783,:)     ;
w_temp    = w(dates_7783,:)     ;

if SEC_IND_SUBSET == 1  
% weighted IP index
g_temp    = g(dates_7783,:)   ;
elseif (SEC_IND_SUBSET == 2 || SEC_IND_SUBSET == 3 || SEC_IND_SUBSET == 4) 
% weighted GDP index 
g_temp    = g_t(dates_7783,:)   ;
end

g_ew_temp = g_ew(dates_7783,:)  ;
[T,N]     = size(x_temp)        ; 

x_i_bar_mtx = repmat(mean(x_temp),T,1);
% w
tab3(1,2) = std(g_temp);
tab3(2,2) = sqrt( (1/T)*sum(sum((w_temp.^2).*((x_temp - x_i_bar_mtx).^2) )));
% 1/N
tab3(3,2) = std(g_ew_temp);
tab3(4,2) = sqrt( (1/T)*sum(sum(((ones(T,N)/N).^2).*((x_temp - x_i_bar_mtx).^2) )));
%--------------------------------------------------------------------------
% 1984-2007
x_temp    = x(dates_8407,:)     ;
w_temp    = w(dates_8407,:)     ;

if SEC_IND_SUBSET == 1  
% weighted IP index
g_temp    = g(dates_8407,:)   ;
elseif (SEC_IND_SUBSET == 2 || SEC_IND_SUBSET == 3 || SEC_IND_SUBSET == 4) 
% weighted GDP index 
g_temp    = g_t(dates_8407,:)   ;
end


g_ew_temp = g_ew(dates_8407,:)  ;
[T,N]     = size(x_temp)        ; 

x_i_bar_mtx = repmat(mean(x_temp),T,1);
% w
tab3(1,3) = std(g_temp);
tab3(2,3) = sqrt( (1/T)*sum(sum((w_temp.^2).*((x_temp - x_i_bar_mtx).^2) )));
% 1/N
tab3(3,3) = std(g_ew_temp);
tab3(4,3) = sqrt( (1/T)*sum(sum(((ones(T,N)/N).^2).*((x_temp - x_i_bar_mtx).^2) )));
%--------------------------------------------------------------------------
% 2008-2011
x_temp    = x(dates_0811,:)     ;
w_temp    = w(dates_0811,:)     ;

if SEC_IND_SUBSET == 1  
% weighted IP index
g_temp    = g(dates_0811,:)   ;
elseif (SEC_IND_SUBSET == 2 || SEC_IND_SUBSET == 3 || SEC_IND_SUBSET == 4) 
% weighted GDP index 
g_temp    = g_t(dates_0811,:)   ;
end


g_ew_temp = g_ew(dates_0811,:)  ;
[T,N]     = size(x_temp)        ; 

x_i_bar_mtx = repmat(mean(x_temp),T,1);
% w
tab3(1,4) = std(g_temp);
tab3(2,4) = sqrt( (1/T)*sum(sum((w_temp.^2).*((x_temp - x_i_bar_mtx).^2) )));
% 1/N
tab3(3,4) = std(g_ew_temp);
tab3(4,4) = sqrt( (1/T)*sum(sum(((ones(T,N)/N).^2).*((x_temp - x_i_bar_mtx).^2) )));

disp(['================================================================='])
if     SEC_IND_SUBSET == 1; disp(['Table D.5 in Latex format'] );
elseif SEC_IND_SUBSET == 2; disp(['Table D.8 in Latex format'] );    
elseif SEC_IND_SUBSET == 3; disp(['Table D.11 in Latex format']);
elseif SEC_IND_SUBSET == 4; disp(['Table D.14 in Latex format']);
end  
disp(['================================================================='])
disp(['~' , ...
     ' & ', '1977-2011', ...
     ' & ', '1977-1983', ...
     ' & ', '1984-2007', ...
     ' & ', '2008-2011', '\\'])
disp(['With Sectoral covariation'  , ...
     ' & ',num2str(tab3(1,1),'%.1f'), ...
     ' & ',num2str(tab3(1,2),'%.1f'), ...
     ' & ',num2str(tab3(1,3),'%.1f'), ...
     ' & ',num2str(tab3(1,4),'%.1f'), '\\'])
 disp(['Without Sectoral covariation'  , ...
     ' & ',num2str(tab3(2,1),'%.1f'), ...
     ' & ',num2str(tab3(2,2),'%.1f'), ...
     ' & ',num2str(tab3(2,3),'%.1f'), ...
     ' & ',num2str(tab3(2,4),'%.1f'), '\\'])
 disp(['With Sectoral covariation'  , ...
     ' & ',num2str(tab3(3,1),'%.1f'), ...
     ' & ',num2str(tab3(3,2),'%.1f'), ...
     ' & ',num2str(tab3(3,3),'%.1f'), ...
     ' & ',num2str(tab3(3,4),'%.1f'), '\\'])
 disp(['Without Sectoral covariation'  , ...
     ' & ',num2str(tab3(4,1),'%.1f'), ...
     ' & ',num2str(tab3(4,2),'%.1f'), ...
     ' & ',num2str(tab3(4,3),'%.1f'), ...
     ' & ',num2str(tab3(4,4),'%.1f'), '\\'])
%-------------------------------------------------------------------------- 
% Figure D.2-D.5
T      = size(x,1) ;
disp(['================================================================='])
if     SEC_IND_SUBSET == 1; disp(['Generate Figure D.2']);
elseif SEC_IND_SUBSET == 2; disp(['Generate Figure D.3']);
elseif SEC_IND_SUBSET == 3; disp(['Generate Figure D.4']);
elseif SEC_IND_SUBSET == 4; disp(['Generate Figure D.5']);
end
disp(['================================================================='])
figure; hold on
l1 = line(1:T, g_t     );
l2 = line(1:T, g_ew    );
l3 = line(1:T, g_w_dots);
l4 = line(1:T, g_w_hat );

set(l1, 'LineWidth',2,'Color', 'k' )                 ;
set(l2, 'LineWidth',2,'LineStyle', '-.','Color', 'k');
set(l3, 'LineWidth',1,'Color', 'k')                  ;
set(l4, 'LineWidth',1,'LineStyle', ':','Color', 'k') ;
%==========================================================================
% x-axis appearence
if    SEC_IND_SUBSET == 1; % for IP data only
set(gca, 'XTick'     , lab_sel_rep4 )                        ;% as Tab.D.1
set(gca, 'XTickLabel', ip_year_1977_2011_rep4(lab_sel_rep4)) ; 
elseif  (SEC_IND_SUBSET == 2 || SEC_IND_SUBSET == 3 || SEC_IND_SUBSET == 4) 
set(gca, 'XTick'     , lab_sel )                              ;% as Tab.D.1
set(gca, 'XTickLabel', gdp_year_1977_2011(lab_sel))           ;
end
%==========================================================================
xlabel('Date'); 
if     SEC_IND_SUBSET == 1; title('Figure D.2');
elseif SEC_IND_SUBSET == 2; title('Figure D.3');
elseif SEC_IND_SUBSET == 3; title('Figure D.4');
elseif SEC_IND_SUBSET == 4; title('Figure D.5');
end
hold off
%==========================================================================
if SEC_IND_SUBSET == 1 ; % sectoral quarterly IP  indexes
%--------------------------------------------------------------------------    
% Figure D.6: Sectoral IP growth (Y) standard deviations hist. and stat.
%--------------------------------------------------------------------------
% SAMPLE: 1977 - 2011 
std_temp = std(x(dates_7711,:))    ; % compute Standard deviations
% Generate histogram
[nhist,xout] = hist(std_temp',[0:2:180]) ; N_temp = size(std_temp,2) ;
disp('=================================================================')
disp('Generate Figure D.6')
figure; suptitle({'Figure D.6',' '}); 
subplot(2,2,1); h = bar(xout,100*nhist/N_temp,'hist') ;
set(h(1),'facecolor','white'); set(h(1),'edgecolor','blue') ;
xlim([0 180]); ylim([0 16]); ylabel('Percent','interpreter','latex','FontSize',10);
xlabel('(a) 1977.Q1-2011.Q4')
disp('=================================================================')
disp('Table at the bottom of Figure D.6 (Latex format)')
disp('=================================================================')
% Table in caption: quantiles of standard deviations (line 1)
disp(['Panel &', ' 25th Percentile &', ' Median &', ' 75th Percentile \\'])  
disp(['(a) & ',...
      num2str(quantile(std_temp',0.25),'%.2f'),' & ',...
      num2str(quantile(std_temp',0.50),'%.2f'),' & ',...
      num2str(quantile(std_temp',0.75),'%.2f'),' \\ '])
%--------------------------------------------------------------------------
% SAMPLE: 1977 - 1983
std_temp = std(x(dates_7783,:));
% Generate histogram
[nhist,xout] = hist(std_temp',[0:2:180]) ; N_temp = size(std_temp,2) ;
subplot(2,2,2); h = bar(xout,100*nhist/N_temp,'hist') ;
set(h(1),'facecolor','white'); set(h(1),'edgecolor','blue') ;
xlim([0 180]); ylim([0 16]); ylabel('Percent','interpreter','latex','FontSize',10);
xlabel('(b) 1977.Q1-1983.Q4')
% Table in caption: quantiles of standard deviations (line 2)
disp(['(b) & ',...
      num2str(quantile(std_temp',0.25),'%.2f'),' & ',...
      num2str(quantile(std_temp',0.50),'%.2f'),' & ',...
      num2str(quantile(std_temp',0.75),'%.2f'),' \\ '])
%--------------------------------------------------------------------------
% SAMPLE: 1984 - 2007
std_temp = std(x(dates_8407,:));
% Generate histogram
[nhist,xout] = hist(std_temp',[0:2:180]) ; N_temp = size(std_temp,2) ;
subplot(2,2,3); h = bar(xout,100*nhist/N_temp,'hist') ;
set(h(1),'facecolor','white'); set(h(1),'edgecolor','blue') ;
xlim([0 180]); ylim([0 16]); ylabel('Percent','interpreter','latex','FontSize',10);
xlabel('(c) 1984.Q1-2007.Q4')
% Table in caption: quantiles of standard deviations (line 3)
disp(['(c) & ',...
      num2str(quantile(std_temp',0.25),'%.2f'),' & ',...
      num2str(quantile(std_temp',0.50),'%.2f'),' & ',...
      num2str(quantile(std_temp',0.75),'%.2f'),' \\ '])
%--------------------------------------------------------------------------
% SAMPLE: 2008 - 2011
std_temp = std(x(dates_0811,:));
% Generate histogram
[nhist,xout] = hist(std_temp',[0:2:180]) ; N_temp = size(std_temp,2) ;
subplot(2,2,4); h = bar(xout,100*nhist/N_temp,'hist') ;
set(h(1),'facecolor','white'); set(h(1),'edgecolor','blue') ;
xlim([0 180]); ylim([0 16]); ylabel('Percent','interpreter','latex','FontSize',10);
xlabel('(d) 2008.Q1-2011.Q4')
% Table in caption: quantiles of standard deviations (line 4)
disp(['(d) & ',...
      num2str(quantile(std_temp',0.25),'%.2f'),' & ',...
      num2str(quantile(std_temp',0.50),'%.2f'),' & ',...
      num2str(quantile(std_temp',0.75),'%.2f'),' \\ '])
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
elseif SEC_IND_SUBSET == 4 ; % NON-MANUFACT. sectoral annual GDP indexes
%--------------------------------------------------------------------------    
% Figure D.7: Sectoral GDP growth (Y) standard deviations hist. and stat.
%--------------------------------------------------------------------------
% SAMPLE: 1977 - 2011 
std_temp = std(x(dates_7711,:))    ; % compute Standard deviations
% Generate histogram
[nhist,xout] = hist(std_temp',[0:1:45]) ; N_temp = size(std_temp,2) ;
disp(['================================================================='])
disp(['Generate Figure D.7'])
figure; suptitle({'Figure D.7',' '}); 
subplot(2,2,1); h = bar(xout,100*nhist/N_temp,'hist') ;
set(h(1),'facecolor','white'); set(h(1),'edgecolor','blue') ;
xlim([0 45]); ylim([0 25]); ylabel('Percent','interpreter','latex','FontSize',10);
xlabel('(a) 1977-2011')
disp(['================================================================='])
disp(['Table at the bottom of Figure D.7 (Latex format)'])
disp(['================================================================='])
% Table in caption: quantiles of standard deviations (line 1)
disp(['Panel &', ' 25th Percentile &', ' Median &', ' 75th Percentile \\'])  
disp(['(a) & ',...
      num2str(quantile(std_temp',0.25),'%.2f'),' & ',...
      num2str(quantile(std_temp',0.50),'%.2f'),' & ',...
      num2str(quantile(std_temp',0.75),'%.2f'),' \\ '])
%--------------------------------------------------------------------------
% SAMPLE: 1977 - 1983
std_temp = std(x(dates_7783,:));
% Generate histogram
[nhist,xout] = hist(std_temp',[0:1:45]) ; N_temp = size(std_temp,2) ;
subplot(2,2,2); h = bar(xout,100*nhist/N_temp,'hist') ;
set(h(1),'facecolor','white'); set(h(1),'edgecolor','blue') ;
xlim([0 45]); ylim([0 25]); ylabel('Percent','interpreter','latex','FontSize',10);
xlabel('(b) 1977-1983')
% Table in caption: quantiles of standard deviations (line 2)
disp(['(b) & ',...
      num2str(quantile(std_temp',0.25),'%.2f'),' & ',...
      num2str(quantile(std_temp',0.50),'%.2f'),' & ',...
      num2str(quantile(std_temp',0.75),'%.2f'),' \\ '])
%--------------------------------------------------------------------------
% SAMPLE: 1984 - 2007
std_temp = std(x(dates_8407,:));
% Generate histogram
[nhist,xout] = hist(std_temp',[0:1:45]) ; N_temp = size(std_temp,2) ;
subplot(2,2,3); h = bar(xout,100*nhist/N_temp,'hist') ;
set(h(1),'facecolor','white'); set(h(1),'edgecolor','blue') ;
xlim([0 45]); ylim([0 25]); ylabel('Percent','interpreter','latex','FontSize',10);
xlabel('(c) 1984-2007')
% Table in caption: quantiles of standard deviations (line 3)
disp(['(c) & ',...
      num2str(quantile(std_temp',0.25),'%.2f'),' & ',...
      num2str(quantile(std_temp',0.50),'%.2f'),' & ',...
      num2str(quantile(std_temp',0.75),'%.2f'),' \\ '])
%--------------------------------------------------------------------------
% SAMPLE: 2008 - 2011
std_temp = std(x(dates_0811,:));
% Generate histogram
[nhist,xout] = hist(std_temp',[0:1:45]) ; N_temp = size(std_temp,2) ;
subplot(2,2,4); h = bar(xout,100*nhist/N_temp,'hist') ;
set(h(1),'facecolor','white'); set(h(1),'edgecolor','blue') ;
xlim([0 45]); ylim([0 25]); ylabel('Percent','interpreter','latex','FontSize',10);
xlabel('(d) 2008-2011')
% Table in caption: quantiles of standard deviations (line 4)
disp(['(d) & ',...
      num2str(quantile(std_temp',0.25),'%.2f'),' & ',...
      num2str(quantile(std_temp',0.50),'%.2f'),' & ',...
      num2str(quantile(std_temp',0.75),'%.2f'),' \\ '])
end
%==========================================================================