% #########################################################################
% This is the replication file to reproduce all results of the 
% Empirical Application of the paper:
% 
% ``Inference in Group Factor Models 
%   with an Application to Mixed Frequency Data''
% 
% by Elena Andreou, Patrick Gagliardini, Eric Ghysels, Mirco Rubin 
% 
% In particular, the files replicates the empirical results in:
% - the Main Paper, Section 7 and
% - the Online Appendix Sections D.11.2, D.11.3, D.11.4 
%--------------------------------------------------------------------------
% Date  : 31.03.2019
% Author: Mirco Rubin
% Email : mircorubin@gmail.com
% updated files can be found also on the author's website:
% Web   : https://sites.google.com/site/mircorubin/ 
%##########################################################################
clear all; close all;  clc;
%##########################################################################
% SAMPLE SELECTION
% Select dates set of sectoral indices by uncommenting relevant set
DATES_SUBSET = 1 ;  % 1977-2011 : Full Sample
% DATES_SUBSET = 2 ;  % 1984-2007 : Great Moderation
% DATES_SUBSET = 3 ;  % 1984-2011 : Great Moderation + last 4 years in the sample
%##########################################################################
% Select by uncommenting relevant set
AGGREGATION_FIRST = 1 ;   % Aggregation First
% AGGREGATION_FIRST = 0 ;  % PCA first
%##########################################################################
% NO NEED TO NOT CHANGE CODE FROM HERE ONWARDS
%--------------------------------------------------------------------------
% Data loading
load IP_data
load GDP_data
%--------------------------------------------------------------------------
if DATES_SUBSET == 1 % FULL SAMPLE: 
dates_ip_subsamp  =  dates_ip(1,1:140) ; % all 140 quarters
dates_gdp_subsamp =  dates_gdp(1,1:35) ; % all  35 years
disp('Display results for years: 1977-2011 (Full sample)');
elseif DATES_SUBSET == 2 %  GREAT MODERATION 
dates_ip_subsamp  =  dates_ip(1,29:124); % 24*4 = 96 quarters
dates_gdp_subsamp =  dates_gdp(1,8:31) ; % 24 years
disp('Display results for years: 1984-2007 (Great Moderation sample)');
elseif DATES_SUBSET == 3 %  GREAT MODERATION + last part of sample
dates_ip_subsamp  =  dates_ip(1,29:140); % 28*4 = 112 quarters
dates_gdp_subsamp =  dates_gdp(1,8:35) ; % 28 years
disp('Display results for years: 1984-2011 (Great Moderation + last 4 years in the sample)');
end

if AGGREGATION_FIRST == 1 
disp('Display results for "Aggregation First"');
elseif AGGREGATION_FIRST == 0 
disp('Display results for "PCA First"');
end
%%-------------------------------------------------------------------------
% Load and standardize HF data: X
X = zscore(IPq_g(dates_ip_subsamp,:))              ; % X : (M*T X N) matrix

% Load and standardize LF data: Y
Y = zscore(gdp_g_real_nonIP(:,dates_gdp_subsamp)'); % Y : (T   X N) matrix

% Panels dimensions
[T_HF, N_HF] = size(X) ;
[T_LF, N_LF] = size(Y) ;

m = 4;  % n. of HF subperiods (quarters) within each LF period (year)
%--------------------------------------------------------------------------
% Labels and plots for full sample only
if DATES_SUBSET == 1 

%  LABELS for graphs
for t = 1:T_LF
    dates_u_yy_LF(t,1)= datenum(gdp_year(dates_ip_subsamp(1,t)),12,1) ;
    dates_yy_LF(t,1)  = cellstr(datestr(dates_u_yy_LF(t,1),'yy'))     ;
end
for t = 1:T_HF
    dates_u_yy_HF(t,1)= datenum(IPq_g_year(dates_ip_subsamp(1,t)),12,1) ;
    dates_yy_HF(t,1)  = cellstr(datestr(dates_u_yy_HF(t,1),'yy'))       ;
end

clear dates_u_yy_LF dates_u_yy_HF

% Ticks and labels for x-axis on plots
Xtick_HF      = 4:8:T_HF              ; % label every 2 years @ end of year
XtickLabel_HF = dates_yy_HF(Xtick_HF) ;
Xtick_LF      = 1:2:T_LF              ; % label every 2 years @ end of year
XtickLabel_LF = dates_yy_LF(Xtick_LF) ;

%--------------------------------------------------------------------------
% PLOT aggregate IP & GDP indexes
if DATES_SUBSET == 1 && AGGREGATION_FIRST == 1;  

disp(' '); disp(' ');
disp('=================================================================')
disp('Generate Figure 2 (a)')
disp('=================================================================')
% Repeat 4 times annual GDP growth to obtain red rectangles in Figure 2(a)
GDP_rep = NaN(T_HF,1); 
for t = 1:T_LF
    t0 = (t-1)*4 + 1 ;  
    GDP_rep(t0  ,1) = gdp_g_real_index(1,t)' ;
    GDP_rep(t0+1,1) = gdp_g_real_index(1,t)' ;
    GDP_rep(t0+2,1) = gdp_g_real_index(1,t)' ;
    GDP_rep(t0+3,1) = gdp_g_real_index(1,t)' ;
end
figure
y   = line((1:T_HF)',GDP_rep                        );% GDP (LF - Y)
y2  = line((1:T_HF)',IPq_g_INDEX(dates_ip_subsamp,1));% IP  (HF - Q)
set(y  ,'LineStyle','-' ,'LineWidth',1.0,'Color','r','Marker','s','MarkerSize',5,'MarkerFaceColor','r'   );
set(y2 ,'LineStyle','-.','LineWidth',1.0,'Color','k','Marker','o','MarkerSize',5,'MarkerFaceColor','none');
ylim([-25 20]); xlabel('Date'); set(gca,'XTick', Xtick_HF); set(gca,'XTickLabel', XtickLabel_HF); grid on ;
suptitle('Figure 2(a): IP and GDP growth rates');
end
end
%--------------------------------------------------------------------------
% SELECTION OF NUMBER OF FACTORS for different panels (or 'groups')

% Creates table for selection of number of factors for 2 given datasets 
kmax = 15 ; % Maximum number of factors for Bai and Ng(2002) procedure
[tab_IPC1, tab_IPC2] = k1k2_selection_func(X,Y,kmax);

disp(' '); disp(' ');
disp('=================================================================')
if DATES_SUBSET == 1 ;      % Full sample 
disp('Table D.18 : Estimated number of factors in each group. IC_p criteria of Bai and Ng 2002. (Aggregation first)')
disp('=================================================================')
disp('Full Sample: 1977-2011')
elseif DATES_SUBSET == 2 ;  % Great Moderation & PCA first
disp('Table D.28: Estimated number of factors in each group. IC_p criteria of Bai and Ng 2002. (Aggregation first)')
disp('=================================================================')
disp('Sample: 1984-2007')
elseif DATES_SUBSET == 3 ;  % Great Moderation + last part of sample & PCA first
disp('Table D.28: Estimated number of factors in each group. IC_p criteria of Bai and Ng 2002. (Aggregation first)')
disp('=================================================================')
disp('Sample: 1984-2011')
end
disp('------------------------------------------------------------')
% display selected n. of factors for the following 3 panels: X_HF,  X^H,  X_L
disp('    X_HF  X^H    X_L ')
disp('------------------------------------------------------------')
if DATES_SUBSET == 1
disp('IC p1'); disp(tab_IPC1(1,9:11)); 
end
disp('IC p2'); disp(tab_IPC2(1,9:11)); 

%--------------------------------------------------------------------------
% Test for the number of common factors: parameters
alpha_test = 0.05 ;
c_test     = 0.95 ;
gamma      = 0.1 ;
%--------------------------------------------------------------------------
if DATES_SUBSET == 1  && AGGREGATION_FIRST == 1; % full sample and aggregation first
%--------------------------------------------------------------------------
k_1   = 2              ; 
k_2   = 2              ; 
k_min = min([k_1,k_2]) ;
kChat_savef  = 1       ;

[can_corr_all,...
 cc_test_mat_summary,...
 cc_test_mat_all,... 
 eigvalues_vcovHstack,...
 corr_factors_LF,...
 FC_hat, FH_hat, FL_hat] = Estimation_nfac_and_factors_EMPIRICAL(X, Y, AGGREGATION_FIRST, k_1, k_2, '3', c_test, gamma, kChat_savef);

% Display output of testing procedure
disp('=================================================================')
disp(['The ',num2str(k_min,'%.0f'),' canonical correlations are :']); disp(' ');
for i = 1:size(can_corr_all,1); disp(num2str(can_corr_all(i),'%.4f')); end ; disp(' '); 
disp('=================================================================')
disp(' ');
disp('Summary of testing procedure for the number of common factors :'); disp(' ');
disp('---------------------------------')
disp('H_0: k^c   |  \tilde{\Xi}(k^c)  |')
disp('---------------------------------')
for i = 1:size(cc_test_mat_all,1)
disp([num2str(cc_test_mat_all(i,1) ,'%.0f') ,'          |       ',...
      num2str(cc_test_mat_all(i,2) ,'%.4f') ,'      |    ']);
end
disp('=================================================================')
%--------------------------------------------------------------------------
elseif DATES_SUBSET == 1  && AGGREGATION_FIRST == 0; % full sample and PCA first

k_1   = 2             ; 
k_2   = 2             ; 
k_min = min([k_1,k_2]);
kChat_savef  = 1      ;

[can_corr_all,...
 cc_test_mat_summary,...
 cc_test_mat_all,... 
 eigvalues_vcovHstack,...
 corr_factors_LF,...
 FC_hat, FH_hat, FL_hat] = Estimation_nfac_and_factors_EMPIRICAL(X, Y, AGGREGATION_FIRST, k_1, k_2, '3', c_test, gamma, kChat_savef);
% Display output of testing procedure
disp('=================================================================')
disp(['The ',num2str(k_min,'%.0f'),' canonical correlations are :']); disp(' ');
for i = 1:size(can_corr_all,1); disp(num2str(can_corr_all(i),'%.4f')); end ; disp(' '); 
disp('=================================================================')
disp(' '); disp(' ');
disp('Summary of testing procedure for the number of common factors :'); disp(' ');
disp('---------------------------------')
disp('H_0: k^c   |  \tilde{\Xi}(k^c)  |')
disp('---------------------------------')
for i = 1:size(cc_test_mat_all,1)
disp([num2str(cc_test_mat_all(i,1) ,'%.0f') ,'          |       ',...
      num2str(cc_test_mat_all(i,2) ,'%.4f') ,'      |    ']);
end
%--------------------------------------------------------------------------
elseif DATES_SUBSET == 2 || 3 && AGGREGATION_FIRST == 1;  % Subsample and PCA first

k_1   = 1              ; 
k_2   = 1              ; 
k_min = min([k_1,k_2]) ;
kChat_savef  = 1       ;

[can_corr_all,...
 cc_test_mat_summary,...
 cc_test_mat_all,... 
 eigvalues_vcovHstack,...
 corr_factors_LF,...
 FC_hat, FH_hat, FL_hat] = Estimation_nfac_and_factors_EMPIRICAL(X, Y, AGGREGATION_FIRST, k_1, k_2, '3',c_test, gamma, kChat_savef);

% Display output of testing procedure
disp('=================================================================')
disp('Quantities displayed in TABLE D.29')
disp('=================================================================')
disp(['The ',num2str(k_min,'%.0f'),' canonical correlations are :']); disp(' ');
for i = 1:size(can_corr_all,1); disp(num2str(can_corr_all(i),'%.4f')); end ; disp(' '); 
disp('=================================================================')
disp(' '); disp(' ');
disp('Summary of testing procedure for the number of common factors :'); disp(' ');
disp('---------------------------------')
disp('H_0: k^c   |  \tilde{\Xi}(k^c)  |')
disp('---------------------------------')
for i = 1:size(cc_test_mat_all,1)
disp([num2str(cc_test_mat_all(i,1) ,'%.0f') ,'          |       ',...
      num2str(cc_test_mat_all(i,2) ,'%.4f') ,'      |    ']);
end
disp('=================================================================')
clear cc_test_mat_summary cc_test_mat_all

k_1   = 2              ; 
k_2   = 2              ; 
k_min = min([k_1,k_2]) ;
kChat_savef  = 1       ;

[can_corr_all,...
 cc_test_mat_summary,...
 cc_test_mat_all,... 
 eigvalues_vcovHstack,...
 corr_factors_LF,...
 FC_hat, FH_hat, FL_hat] = Estimation_nfac_and_factors_EMPIRICAL(X, Y, AGGREGATION_FIRST, k_1, k_2, '3',c_test, gamma, kChat_savef);

% Display output of testing procedure
disp('=================================================================')
disp(['The ',num2str(k_min,'%.0f'),' canonical correlations are :']); disp(' ');
for i = 1:size(can_corr_all,1); disp(num2str(can_corr_all(i),'%.4f')); end ; disp(' '); 
disp('=================================================================')
disp(' '); disp(' ');
disp('Summary of testing procedure for the number of common factors :'); disp(' ');
disp('---------------------------------')
disp('H_0: k^c   |  \tilde{\Xi}(k^c)  |')
disp('---------------------------------')
for i = 1:size(cc_test_mat_all,1)
disp([num2str(cc_test_mat_all(i,1) ,'%.0f') ,'          |       ',...
      num2str(cc_test_mat_all(i,2) ,'%.4f') ,'      |    ']);
end
disp('=================================================================')
end
%--------------------------------------------------------------------------
% 'Unstack' estimated factors: from 1 HF panel --> 4 LF panels
FC_hat_unstacked  = Stack_HF_LF_m_superiods(FC_hat,m);

FC1       = FC_hat_unstacked(:,:,1) ; 
FC2       = FC_hat_unstacked(:,:,2) ;
FC3       = FC_hat_unstacked(:,:,3) ;
FC4       = FC_hat_unstacked(:,:,4) ;

clear FC_hat_unstacked % clean memory
%--------------------------------------------------------------------------
FH_hat_unstacked  = Stack_HF_LF_m_superiods(FH_hat,m);

FH1       = FH_hat_unstacked(:,:,1) ;
FH2       = FH_hat_unstacked(:,:,2) ;
FH3       = FH_hat_unstacked(:,:,3) ;
FH4       = FH_hat_unstacked(:,:,4) ;

clear FH_hat_unstacked % clean memory

%--------------------------------------------------------------------------                                                       
if DATES_SUBSET == 1 
%--------------------------------------------------------------------------
if AGGREGATION_FIRST == 1;  % Full sample & PCA first only  
disp(' '); disp(' ');
disp('============================================================================================')
disp('Table D.19: Eigenvalues of the variance-covariance matrix of stacked PCs (aggregation first)');
disp('============================================================================================')
for i = 1:size(eigvalues_vcovHstack,1); 
    disp(num2str(eigvalues_vcovHstack(i,1),'%.2f')); 
end ; disp(' '); 
disp('============================================================================================')
end
%--------------------------------------------------------------------------

%--------------------------------------------------------------------------
% Change sign of factors so that majority of the loadings is positive
%--------------------------------------------------------------------------
% regressions Ys on different sets of estimated factors: adj. R^2 values
RY_fL          = zeros(N_LF,1) ;
RY_fLC         = zeros(N_LF,1) ;
RY_fC          = zeros(N_LF,1) ;
RY_fLC_midas   = zeros(N_LF,1) ;
% regressions Ys on different sets of estimated factors: BIC values
bicY_fL        = zeros(N_LF,1) ;
bicY_fLC       = zeros(N_LF,1) ;
bicY_fC        = zeros(N_LF,1) ;
bicY_fLC_midas = zeros(N_LF,1) ;
% regressions Ys on different sets of estimated factors: %-BIC contribution if model selcted by BIC
bicY_fL_sel    = zeros(N_LF,1) ;
bicY_fLC_sel   = zeros(N_LF,1) ;
bicY_fC_sel    = zeros(N_LF,1) ;
% regressions Xs on different sets of estimated factors: adj. R^2 values
RX_fH          = zeros(N_HF,1) ;
RX_fHC         = zeros(N_HF,1) ;
RX_fC          = zeros(N_HF,1) ;
% regressions Xs on different sets of estimated factors: BIC values
bicX_fH        = zeros(N_HF,1) ;
bicX_fHC       = zeros(N_HF,1) ;
bicX_fC        = zeros(N_HF,1) ;
% regressions Xs on different sets of estimated factors: %-BIC contribution if model selcted by BIC
bicX_fH_sel    = zeros(N_HF,1) ;
bicX_fHC_sel   = zeros(N_HF,1) ;
bicX_fC_sel    = zeros(N_HF,1) ;
% .... TO CHECK!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
bicY_sel_tab   = cell(N_LF,1)  ;
RY_sel_tab     = cell(N_LF,1)  ;
bicX_sel_tab   = cell(N_HF,1)  ;
RX_sel_tab     = cell(N_HF,1)  ; 
%--------------------------------------------------------------------------
whichstats = {'adjrsquare','beta','mse'}; % regression output to save
% Y : LF OBSERVABLES ------------------------------------------------------
for i = 1:N_LF
    % LF Factors
    reg = regstats(Y(:,i),[FL_hat],'linear',whichstats);
    RY_fL(i,1)= reg.adjrsquare*100; 
    bicY_fL(i,1)= (size(Y(:,i),1))*log(reg.mse) + (size(reg.beta,1))*log(size(Y(:,i),1)); 
    % LF Factors and COM factor  (sum of values over the LF period)
    reg = regstats(Y(:,i),[(FC1+FC2+FC3+FC4) FL_hat ],'linear',whichstats);
    RY_fLC(i,1)  = reg.adjrsquare*100; 
    bicY_fLC(i,1)= (size(Y(:,i),1))*log(reg.mse) + (size(reg.beta,1))*log(size(Y(:,i),1)); 
    
    Lambda_LC_hat(i,1)= reg.beta(2); 
    Lambda_L_hat(i,1) = reg.beta(3);
    
    % COM Factor (sum of values over the LF period)
    reg = regstats(Y(:,i),[(FC1+FC2+FC3+FC4)],'linear',whichstats);
    RY_fC(i,1)= reg.adjrsquare*100; 
    bicY_fC(i,1)= (size(Y(:,i),1))*log(reg.mse) + (size(reg.beta,1))*log(size(Y(:,i),1)); 

    % BIC selection
    if (bicY_fL(i,1) < bicY_fLC(i,1)) && (bicY_fL(i,1) < bicY_fC(i,1))
        bicY_fL_sel(i,1)     = 1/N_LF*100;
        bicY_sel_tab(i,1) = {'L'};
    elseif (bicY_fLC(i,1) < bicY_fL(i,1)) && (bicY_fLC(i,1) < bicY_fC(i,1))
        bicY_fLC_sel(i,1) = 1/N_LF*100;
        bicY_sel_tab(i,1) = {'CL'};
    elseif (bicY_fC(i,1) < bicY_fL(i,1)) && (bicY_fC(i,1) < bicY_fLC(i,1))
        bicY_fC_sel(i,1)  = 1/N_LF*100;
        bicY_sel_tab(i,1) = {'C'};
    end
end
% HF OBSERVABLES ----------------------------------------------------------
for i = 1:N_HF
    % on Common factors
    reg = regstats(X(:,i),[FC_hat],'linear',whichstats);
    RX_fC(i,1)= reg.adjrsquare*100;  
    bicX_fC(i,1)= (size(X(:,i),1))*log(reg.mse) + (size(reg.beta,1))*log(size(X(:,i),1)); 
    % COM and HF factors
    reg = regstats(X(:,i),[FC_hat FH_hat],'linear',whichstats);
    RX_fHC(i,1)= reg.adjrsquare*100; 
    bicX_fHC(i,1)= (size(X(:,i),1))*log(reg.mse) + (size(reg.beta,1))*log(size(X(:,i),1));
    
    Lambda_HC_hat(i,1)= reg.beta(2); 
    Lambda_H_hat(i,1) = reg.beta(3);
    % HF factor
    reg = regstats(X(:,i),[FH_hat],'linear',whichstats);
    RX_fH(i,1)= reg.adjrsquare*100;  
    bicX_fH(i,1)= (size(X(:,i),1))*log(reg.mse) + (size(reg.beta,1))*log(size(X(:,i),1));
    % BIC selection
    if (bicX_fH(i,1) < bicX_fHC(i,1)) && (bicX_fH(i,1) < bicX_fC(i,1))
        bicX_fH_sel(i,1)  = 1/N_HF*100;
        bicX_sel_tab(i,1) = {'H'};
    elseif (bicX_fHC(i,1) < bicX_fH(i,1)) && (bicX_fHC(i,1) < bicX_fC(i,1))
        bicX_fHC_sel(i,1)  = 1/N_HF*100;
        bicX_sel_tab(i,1) = {'CH'};
    elseif (bicX_fC(i,1) < bicX_fH(i,1)) && (bicX_fC(i,1) < bicX_fHC(i,1))
        bicX_fC_sel(i,1)  = 1/N_HF*100;
        bicX_sel_tab(i,1) = {'C'};
    end    
end 
%--------------------------------------------------------------------------
% Computes Quantiles of adj. R^2 to show in Table 1
q2show = [0.10 0.25 0.50 0.75 0.90] ; % quantiles to compute and to show

RY_fL_quant  = quantile(RY_fL, q2show); 
RY_fLC_quant = quantile(RY_fLC,q2show); 
RY_fC_quant  = quantile(RY_fC, q2show); 
RX_fH_quant  = quantile(RX_fH, q2show); 
RX_fHC_quant = quantile(RX_fHC,q2show); 
RX_fC_quant  = quantile(RX_fC, q2show); 
%--------------------------------------------------------------------------
% change sign of factors if median (majority) of loadings is < 0
if quantile(Lambda_HC_hat,0.5) < 0 ; FC_hat = -FC_hat; end 
if quantile(Lambda_L_hat ,0.5) < 0 ; FL_hat = -FL_hat; end
if quantile(Lambda_H_hat ,0.5) < 0 ; FH_hat = -FH_hat; end
%--------------------------------------------------------------------------
% % 'Unstack' estimated factors: from HF --> LF
FC_hat_unstacked  = Stack_HF_LF_m_superiods(FC_hat,m);

FC1       = FC_hat_unstacked(:,:,1) ; % Q1 estimated of common factor
FC2       = FC_hat_unstacked(:,:,2) ; % Q2 estimated of common factor
FC3       = FC_hat_unstacked(:,:,3) ; % Q3 estimated of common factor
FC4       = FC_hat_unstacked(:,:,4) ; % Q4 estimated of common factor

clear FC_hat_unstacked % clean memory
%--------------------------------------------------------------------------
FH_hat_unstacked  = Stack_HF_LF_m_superiods(FH_hat,m);

FH1       = FH_hat_unstacked(:,:,1) ; % Q1 estimated of HF-spec. factor
FH2       = FH_hat_unstacked(:,:,2) ; % Q2 estimated of HF-spec. factor
FH3       = FH_hat_unstacked(:,:,3) ; % Q3 estimated of HF-spec. factor
FH4       = FH_hat_unstacked(:,:,4) ; % Q4 estimated of HF-spec. factor

clear FH_hat_unstacked % clean memory

%--------------------------------------------------------------------------
% Factor Plots
disp(' '); disp(' ');
disp('=================================================================')
if AGGREGATION_FIRST == 1;      % Aggregation first 
disp(['Generate Figure 2(b): Common factor'])
elseif AGGREGATION_FIRST == 0;  % PCA first 
disp(['Generate Figure D.8(a): Common factor'])
end
disp('=================================================================')
figure
y = line((1:T_HF)',FC_hat) ;
set(y,'LineStyle','-','LineWidth',1.2,'Color','k','Marker','o','MarkerSize',5);
ylim([-6 2]); xlabel('Date'); set(gca,'XTick', Xtick_HF); set(gca,'XTickLabel', XtickLabel_HF); grid on ;
if AGGREGATION_FIRST == 1;      % Aggregation first 
suptitle('Figure 2(b): Common Factor');
elseif AGGREGATION_FIRST == 0;  % PCA first 
suptitle('Figure D.8(a): Common factor');
end
disp('=================================================================')
if AGGREGATION_FIRST == 1;  % Aggregation first 
disp(['Generate Figure 2(c): High Frequency-specific factor'])
elseif AGGREGATION_FIRST == 0;  % PCA first 
disp(['Generate Figure D.8(b): High Frequency-specific factor'])
end
disp('=================================================================')
figure
y = line((1:T_HF)', FH_hat) ;
set(y ,'LineStyle','-','LineWidth',1.2,'Color','k','Marker','o','MarkerSize',5);
ylim([-4 4]); xlabel('Date'); set(gca,'XTick', Xtick_HF); set(gca,'XTickLabel', XtickLabel_HF); grid on ;
if AGGREGATION_FIRST == 1;  % Aggregation first 
suptitle('Figure 2(c): High Frequency-specific factor');
elseif AGGREGATION_FIRST == 0;  % PCA first 
suptitle('Figure D.8(b): High Frequency-specific factor');
end
disp('=================================================================')
if AGGREGATION_FIRST == 1;  % Aggregation first 
disp(['Generate Figure 2(d): Low Frequency-specific factor'])
elseif AGGREGATION_FIRST == 0;  % PCA first 
disp(['Generate Figure D.8(c): Low Frequency-specific factor'])
end
disp('=================================================================')
for t = 1:T_LF
    t0 = (t-1)*4 + 1 ;  
    FL_hat_rep(t0  ,1) = FL_hat(t,1) ;
    FL_hat_rep(t0+1,1) = FL_hat(t,1) ;
    FL_hat_rep(t0+2,1) = FL_hat(t,1) ;
    FL_hat_rep(t0+3,1) = FL_hat(t,1) ;
end
figure
y = line((1:T_HF)',FL_hat_rep) ;
set(y,'LineStyle','-','LineWidth',1.0,'Color','k','Marker','s','MarkerSize',5,'MarkerFaceColor','k');
ylim([-4 4]); xlabel('Date'); set(gca,'XTick', Xtick_HF); set(gca,'XTickLabel', XtickLabel_HF); grid on ;
if AGGREGATION_FIRST == 1;      % Aggregation first 
suptitle('Figure 2(d): Low Frequency-specific factor');
elseif AGGREGATION_FIRST == 0;  % PCA first 
suptitle('Figure D.8(c): Low Frequency-specific factor');
end
%--------------------------------------------------------------------------
if AGGREGATION_FIRST == 1;  % PCA first only  
disp(' '); disp(' ');
disp('=================================================================')
disp('Generate Figure D.9: All 3 estimated factors overlapped ')
disp('=================================================================')
figure
y1C = line((1:T_HF)', FC_hat    ) ; % Common      factor
y2H = line((1:T_HF)', FH_hat    ) ; % HF-specific factor
y3L = line((1:T_HF)', FL_hat_rep) ; % LF-specific factor
set(y1C, 'LineStyle','-' ,'LineWidth',1.0, 'Color', 'b', 'Marker','o', 'MarkerSize', 5, 'MarkerFaceColor', 'b');
set(y2H, 'LineStyle','-' ,'LineWidth',1.0, 'Color', 'g', 'Marker','d', 'MarkerSize', 5, 'MarkerFaceColor', 'g');
set(y3L, 'LineStyle','--','LineWidth',1.0, 'Color', 'r', 'Marker','s', 'MarkerSize', 5, 'MarkerFaceColor', 'r', 'MarkerEdgeColor', 'r');
ylim([-5.5 3.5]); xlabel('Date'); set(gca,'XTick', Xtick_HF); set(gca,'XTickLabel', XtickLabel_HF); grid on ;
suptitle('Figure D.9: All 3 estimated factors overlapped');
h = legend('COMMON factor','HF factor','LF factor') ; set(h, 'interpreter', 'latex', 'Location','southwest')
%--------------------------------------------------------------------------

% Tables with factors correlations:
disp(' '); disp(' ');
disp('=================================================================')
disp('TABLE D.20: Correlation betw. all factors(computed at LF)') 
disp('=================================================================') 
for i = 1:size(corr_factors_LF,1)
    disp([' ',num2str(corr_factors_LF(i,1),'%.4f'),'   & ',... 
          ' ',num2str(corr_factors_LF(i,2),'%.4f'),'   & ',...
          ' ',num2str(corr_factors_LF(i,3),'%.4f'),'   \\'])  
end

disp(' '); disp(' ');
disp('=================================================================')
disp('TABLE D.21: Correlation betw. all factors computed at HF') 
disp('=================================================================') 
corr_factors = corr([FC1, FC2, FC3, FC4, FH1, FH2, FH3, FH4, FL_hat])      ;
% Print corr. matrix  for lattex
for i = 1:size(corr_factors,1)
    disp([' ',num2str(corr_factors(i,1),'%.2f'),'   & ',... 
          ' ',num2str(corr_factors(i,2),'%.2f'),'   & ',...
          ' ',num2str(corr_factors(i,3),'%.2f'),'   & ',...
          ' ',num2str(corr_factors(i,4),'%.2f'),'   & ',...
          ' ',num2str(corr_factors(i,5),'%.2f'),'   & ',...
          ' ',num2str(corr_factors(i,6),'%.2f'),'   & ',...
          ' ',num2str(corr_factors(i,7),'%.2f'),'   & ',...
          ' ',num2str(corr_factors(i,8),'%.2f'),'   & ',...
          ' ',num2str(corr_factors(i,9),'%.2f'),'   \\'])  
end
%--------------------------------------------------------------------------

% Autocorrelations of factors 
disp(' '); disp(' ');
disp('=================================================================')
disp('Generate Figure D.10(a): Common factor ACF')
disp('=================================================================')
figure; autocorr(FC_hat); title('COMMON FACTOR')
suptitle('Figure D.10(a): Common factor: Autocorrelation function');
%--------------------------------------------------------------------------
disp(' '); disp(' ');
disp('=================================================================')
disp('Generate Figure D.10(b): HF-specific factor: ACF')
disp('=================================================================')
figure; autocorr(FH_hat); title('HF specific factor ACF') 
suptitle('Figure D.10(b): High Frequency-specific factor: Autocorrelation function');
%--------------------------------------------------------------------------
disp(' '); disp(' ');
disp('=================================================================')
disp('Generate Figure D.10(c): Common factor: ACF')
disp('=================================================================')
figure; autocorr(FL_hat); title('LF specific FACTOR')
suptitle('Figure D.10(c): Low Frequency-specific factor: Autocorrelation function');
%--------------------------------------------------------------------------
end

disp(' '); disp(' ');
disp('=================================================================')
if AGGREGATION_FIRST == 1;  % Aggregation first  
disp('Table 1: R^2 quantiles, latex format')
elseif AGGREGATION_FIRST == 0;  % PCA first  
disp('Table D.15: R^2 quantiles, latex format')
end
disp('=================================================================')
disp(['Factors                         R^2 quantiles            '])
disp(['Factors                10%    25%   50%    75%     90%   %BIC'])
disp('-----------------------------------------------------------------') 
disp('Observables: GDP, 1977-2011')
disp(['common             ',...
      ' & ', num2str(RY_fC_quant(1,1), '%.1f'), ...
      ' & ', num2str(RY_fC_quant(1,2), '%.1f'), ...
      ' & ', num2str(RY_fC_quant(1,3), '%.1f'), ...
      ' & ', num2str(RY_fC_quant(1,4), '%.1f'), ...
      ' & ', num2str(RY_fC_quant(1,5), '%.1f'), ...
      ' & ', num2str(sum(bicY_fC_sel), '%.1f'),'\\']) 
disp(['common, LF-specific',...
      ' & ', num2str(RY_fLC_quant(1,1), '%.1f'), ...
      ' & ', num2str(RY_fLC_quant(1,2), '%.1f'), ...
      ' & ', num2str(RY_fLC_quant(1,3), '%.1f'), ...
      ' & ', num2str(RY_fLC_quant(1,4), '%.1f'), ...
      ' & ', num2str(RY_fLC_quant(1,5), '%.1f'), ...
      ' & ', num2str(sum(bicY_fLC_sel), '%.1f'),'\\'])
disp(['LF-Specific        ',...
      ' & ', num2str(RY_fL_quant(1,1), '%.1f'), ...
      ' & ', num2str(RY_fL_quant(1,2), '%.1f'), ...
      ' & ', num2str(RY_fL_quant(1,3), '%.1f'), ...
      ' & ', num2str(RY_fL_quant(1,4), '%.1f'), ...
      ' & ', num2str(RY_fL_quant(1,5), '%.1f'), ...
      ' & ', num2str(sum(bicY_fL_sel), '%.1f'),'\\'])
disp(['\midrule']) 
disp('Observables: IP, 1977.Q1-2011.Q4')
disp(['common             ',...
      ' & ', num2str(RX_fC_quant(1,1), '%.1f'), ...
      ' & ', num2str(RX_fC_quant(1,2), '%.1f'), ...
      ' & ', num2str(RX_fC_quant(1,3), '%.1f'), ...
      ' & ', num2str(RX_fC_quant(1,4), '%.1f'), ...
      ' & ', num2str(RX_fC_quant(1,5), '%.1f'), ...
      ' & ', num2str(sum(bicX_fC_sel), '%.1f'),'\\']) 
disp(['common, HF-specific',...
      ' & ', num2str(RX_fHC_quant(1,1), '%.1f'), ...
      ' & ', num2str(RX_fHC_quant(1,2), '%.1f'), ...
      ' & ', num2str(RX_fHC_quant(1,3), '%.1f'), ...
      ' & ', num2str(RX_fHC_quant(1,4), '%.1f'), ...
      ' & ', num2str(RX_fHC_quant(1,5), '%.1f'), ...
      ' & ', num2str(sum(bicX_fHC_sel), '%.1f'),'\\'])
disp(['HF-Specific        ',...
      ' & ', num2str(RX_fH_quant(1,1), '%.1f'), ...
      ' & ', num2str(RX_fH_quant(1,2), '%.1f'), ...
      ' & ', num2str(RX_fH_quant(1,3), '%.1f'), ...
      ' & ', num2str(RX_fH_quant(1,4), '%.1f'), ...
      ' & ', num2str(RX_fH_quant(1,5), '%.1f'), ...
      ' & ', num2str(sum(bicX_fH_sel), '%.1f'),'\\']) 
end
%--------------------------------------------------------------------------
% Adjusted R^2: GDP growth indexes on COMMON factor
% close all; clc;
if DATES_SUBSET == 1 
disp(' '); disp(' ');
disp('=================================================================')
if AGGREGATION_FIRST == 1;  % Aggregation first 
disp('Table 2: Regression of yearly sectoral GDP growth on common and LF-specific factors. Adjusted R^2')
elseif AGGREGATION_FIRST == 0;  % PCA first 
disp('Table D.16: Regression of yearly sectoral GDP growth on common and LF-specific factors. Adjusted R^2')
end
disp('=================================================================')
disp('Panel A. Regressor: common factor')
disp('-----------------------------------------------------------------') 
disp('Ten sectors with largest adj. R^2')
disp('-----------------------------------------------------------------')
% Sorts all GDP non-IP sectors from largest to smallest adjusted R^2  from regression on common factor
[sorted_r2, sorted_r2_ind] = sort(RY_fC,1,'descend');
% Selects and display top ten
index_v_temp = sorted_r2_ind(1:10) ;

for i=1:10
i_temp = index_v_temp(i,1) ;
disp([gdp_names_nonIP{i_temp}, ' & ', num2str(RY_fC(i_temp),'%.2f'), ' \\']);
end

disp('-----------------------------------------------------------------') 
disp('Ten sectors with smallest adj. R^2')
disp('-----------------------------------------------------------------')
% Selects and display smallest ten
index_v_temp = sorted_r2_ind((end-9):end) ;

for i=1:10
i_temp = index_v_temp(i,1) ;
disp([gdp_names_nonIP{i_temp}, ' & ', num2str(RY_fC(i_temp),'%.2f'), ' \\']);
end
%--------------------------------------------------------------------------
if AGGREGATION_FIRST == 1;  % Aggregation first 
disp(' '); disp(' ');
disp('=================================================================')
disp('Table D.24: Adj. R^2 of regressions of yearly sectoral GDP growth on common factor. All non-manufacturing sectors.')
disp('===================================================================')
% Display all
index_v_temp = sorted_r2_ind(1:end) ;

for i=1:length(sorted_r2_ind)
i_temp = index_v_temp(i,1);
disp([gdp_names_nonIP{i_temp} ' & ', num2str(RY_fC(i_temp),'%.2f'),'\\']);
end

%--------------------------------------------------------------------------
disp(' '); disp(' ');
disp('=================================================================')
disp('Generate Figure D.11(a): Adj. R^2 from regressions of sectoral GDP and IP growth rates on estimated factors')
disp('=================================================================')
% Histogram of all R^2 % Selects and display top ten
[nhist,xout] = hist(RY_fC(:,1),[-20:5:100]);
figure
h = bar(xout,100*nhist/N_LF,'hist') ;
set(h(1),'facecolor','white','edgecolor','blue') 
xlim([-20 103]); ylim([0 30]);
xlabel('$\overline{R}^{2}$','interpreter','latex','FontSize',10)
ylabel('Percentage','interpreter','latex','FontSize',10)
suptitle('Figure D.11(a): GDP sectors vs. common factor');
end
end
%--------------------------------------------------------------------------
% Adjusted R^2: GDP growth indexes on COMMON and LF-specific factors
if DATES_SUBSET == 1 
%clc
disp(' '); disp(' ');
disp('=================================================================')
if AGGREGATION_FIRST == 1;  % Aggregation first  
disp(['Table 2: Regression of yearly sectoral GDP growth on common and LF-specific factors. Adjusted R^2'])
elseif AGGREGATION_FIRST == 0;  % PCA first  
disp(['Table D.16: Regression of yearly sectoral GDP growth on common and LF-specific factors. Adjusted R^2'])
end
disp('=================================================================')
disp(['Panel B. Regressor: common and LF-specific factor'])
disp('-----------------------------------------------------------------') 
disp(['Ten sectors with largest adj. R^2'])
disp('-----------------------------------------------------------------')
% Sorts all GDP non-IP sectors from largest to smallest adjusted R^2 from regression on common and LF-specific Factors
[sorted_r2, sorted_r2_ind] = sort(RY_fLC,1,'descend');

% Selects and display top ten
index_v_temp = sorted_r2_ind(1:10) ; 

for i=1:10
i_temp = index_v_temp(i,1) ;
disp([gdp_names_nonIP{i_temp}, ' & ', num2str(RY_fLC(i_temp),'%.2f'),'\\']);
end

disp('-----------------------------------------------------------------') 
disp('Ten sectors with smallest adj. R^2')
disp('-----------------------------------------------------------------')
% Selects and display ten smallest
index_v_temp = sorted_r2_ind((end-9):end) ; 

for i=1:10
i_temp = index_v_temp(i,1) ;
disp([gdp_names_nonIP{i_temp}, ' & ',num2str(RY_fLC(i_temp),'%.2f'),'\\']);
end

%--------------------------------------------------------------------------
if AGGREGATION_FIRST == 1;  % Aggregation first 
disp(' '); disp(' ');
disp('=================================================================')
disp('Table D.25: Adj. R^2 of regressions of yearly sectoral GDP growth on common factor and LF-specific factors. All non-manufacturing sectors.')
disp('=================================================================')
% Display all
index_v_temp = sorted_r2_ind(1:end) ;

for i=1:length(sorted_r2_ind)
    i_temp = index_v_temp(i,1);
    disp([gdp_names_nonIP{i_temp}, ' & ', num2str(RY_fLC(i_temp),'%.2f'),'\\']);
end

disp(' '); disp(' ');
disp('=================================================================')
disp('Generate Figure D.11(b): Adj. R^2 from regressions of sectoral GDP and IP growth rates on estimated factors')
disp('=================================================================')
% Histogram of all R^2
[nhist,xout] = hist(RY_fLC(:,1),[-20:5:100]);
figure
h = bar(xout,100*nhist/N_LF,'hist') ;
set(h(1),'facecolor','white'); set(h(1),'edgecolor','blue')  
xlim([-20 103]); ylim([0 30]);
xlabel('$\overline{R}^{2}$','interpreter','latex','FontSize',10);
ylabel('Percentage','interpreter','latex','FontSize',10);
suptitle('Figure D.11(b): GDP sectors vs.common & LF factors');
end
end

%--------------------------------------------------------------------------
% Adjusted R^2: GDP growth indexes on COMMON and LF-specific factors vs. COMMON factor only
if DATES_SUBSET == 1 
%clc
disp(' '); disp(' ');
disp('=================================================================')
if AGGREGATION_FIRST == 1;  % Aggregation first  
disp(['Table 2: Regression of yearly sectoral GDP growth on common and LF-specific factors. Adjusted R^2'])
elseif AGGREGATION_FIRST == 0;  % PCA first  
disp(['Table D.16: Regression of yearly sectoral GDP growth on common and LF-specific factors. Adjusted R^2'])
end
disp('=================================================================')
disp(['Panel C. Increments in adj. R2'])
disp('-----------------------------------------------------------------') 
disp(['Ten sectors with largest Delta adj. R^2'])
disp('-----------------------------------------------------------------')
% Compute change ('Delta') in Adj. R^2 for all non-IP sectors when LF-specific factor is added to common factor
delta_R2 = RY_fLC - RY_fC ;

% Sorts all changes in R^2 ('Delta R^2') from largest to smallest 
[sorted_r2,sorted_r2_ind] = sort(delta_R2,1,'descend');

% Selects and display top ten
index_v_temp = sorted_r2_ind(1:10) ;

for i=1:10
i_temp = index_v_temp(i,1) ;
disp([gdp_names_nonIP{i_temp},' & ',num2str(delta_R2(i_temp),'%.2f'),'\\']);
end

disp('-----------------------------------------------------------------') 
disp('Ten sectors with smallest Delta adj. R^2')
disp('-----------------------------------------------------------------')
% Selects and display ten smallest
index_v_temp = sorted_r2_ind((end-9):end) ; 
for i=1:10
i_temp = index_v_temp(i,1) ;
disp([gdp_names_nonIP{i_temp},' & ',num2str(delta_R2(i_temp),'%.2f'),'\\']);
end

%--------------------------------------------------------------------------
if AGGREGATION_FIRST == 1;  % Aggregation first
disp(' '); disp(' ');
disp('=================================================================')
disp('Table D.26: Changes in adj. R^2 of regressions of yearly sectoral GDP growth on')
disp('common factor and LF-specific factors. All non-manufacturing sectors ')
disp('=================================================================')
% Display all
index_v_temp = sorted_r2_ind(1:end) ;

for i=1:length(sorted_r2_ind)
i_temp = index_v_temp(i,1) ;
disp([gdp_names_nonIP{i_temp}, ' & ', num2str(delta_R2(i_temp),'%.2f'),'\\']);
end
end
end

%--------------------------------------------------------------------------
% Adjusted R^2: IP growth indexes on COMMON factor
if DATES_SUBSET == 1 
%clc
disp(' '); disp(' ');
disp('=================================================================')
if AGGREGATION_FIRST == 1;  % Aggregation first 
disp('Table D.22: Regression of quarterly sectoral IP growth on common and HF-specific factors. Adjusted R^2 (Aggregation first)')
elseif AGGREGATION_FIRST == 0;  % PCA first
disp('Table D.23: Regression of quarterly sectoral IP growth on common and HF-specific factors. Adjusted R^2 (PCA first)')
end
disp('=================================================================')
disp('Panel A. Regressor: common factor')
disp('-----------------------------------------------------------------') 
disp('Ten sectors with largest adj. R^2')
disp('-----------------------------------------------------------------')
% Sorts all IP sectors from largest to smallest adjusted R^2 from regression on common factor
[sorted_r2, sorted_r2_ind] = sort(RX_fC,1,'descend');

% Selects and display top ten
index_v_temp = sorted_r2_ind(1:10) ;
for i=1:10
i_temp = index_v_temp(i,1) ;
disp([ip_names_all{i_temp}, ' & ', num2str(RX_fC(i_temp),'%.2f'), ' \\']);
end

disp('-----------------------------------------------------------------') 
disp('Ten sectors with smallest adj. R^2')
disp('-----------------------------------------------------------------')
% Selects and display ten smallest
index_v_temp = sorted_r2_ind((end-9):end) ;
for i=1:10
    i_temp = index_v_temp(i,1) ;
     disp([ip_names_all{i_temp}, ' & ', num2str(RX_fC(i_temp),'%.2f'), ' \\']);
end

if AGGREGATION_FIRST == 1;  % Aggregation first 
disp(' '); disp(' ');
disp('=================================================================')
disp('Generate Figure D.11(c): Adj. R^2 from regressions of sectoral GDP and IP growth rates on common factor')
disp('=================================================================')
% Histogram of all R^2 
[nhist,xout] = hist(RX_fC(:,1),[-20:5:100]);
figure
h = bar(xout,100*nhist/N_HF,'hist') ;
set(h(1),'facecolor','white','edgecolor','blue');
xlim([-20 103]); ylim([0 30]);
xlabel('$\overline{R}^{2}$','interpreter','latex','FontSize',10)
ylabel('Percentage','interpreter','latex','FontSize',10)
suptitle('Figure D.11(c): IP sectors vs. common factors');
end
end

%--------------------------------------------------------------------------
% Adjusted R^2: IP growth indexes on COMMON and HF-specific factors
if DATES_SUBSET == 1 
%clc
disp(' '); disp(' ');
disp('=================================================================')
if AGGREGATION_FIRST == 1;  % Aggregation first 
disp('Table D.22: Regression of quarterly sectoral IP growth on common and HF-specific factors. Adjusted R^2 (Aggregation first)')
elseif AGGREGATION_FIRST == 0;  % PCA first
disp('Table D.23: Regression of quarterly sectoral IP growth on common and HF-specific factors. Adjusted R^2 (PCA first)')
end
disp('=================================================================')
disp('Panel B. Regressor: common and HF-specific factor')
disp('-----------------------------------------------------------------') 
disp('Ten sectors with largest adj. R^2')
disp('-----------------------------------------------------------------')
% Sorts all IP sectors from largest to smallest adjusted R^2 from regression on common and HF-specific
[sorted_r2,sorted_r2_ind] = sort(RX_fHC,1,'descend');

% Selects and display top ten
index_v_temp = sorted_r2_ind(1:10) ;

for i=1:10
i_temp = index_v_temp(i,1) ;
disp([ip_names_all{i_temp}, ' & ', num2str(RX_fHC(i_temp),'%.2f'), ' \\']);
end

disp('-----------------------------------------------------------------') 
disp('Ten sectors with smallest adj. R^2')
disp('-----------------------------------------------------------------')
% Selects and display ten smallest
index_v_temp = sorted_r2_ind((end-9):end) ; 

for i=1:10
i_temp = index_v_temp(i,1) ;
disp([ip_names_all{i_temp}, ' & ', num2str(RX_fHC(i_temp),'%.2f'), ' \\']);
end

%--------------------------------------------------------------------------
if AGGREGATION_FIRST == 1;  % Aggregation first
disp(' '); disp(' ');
disp('=================================================================')
disp('Generate Figure D.11(d): Adj. R^2 from regressions of sectoral GDP and IP growth rates on common and HF-specific factors')
disp('=================================================================')
% Histogram of all R^2
[nhist,xout] = hist(RX_fHC(:,1),[-20:5:100]);
figure
h = bar(xout,100*nhist/N_HF,'hist') ;
set(h(1),'facecolor','white','edgecolor','blue');
xlim([-20 103]); ylim([0 30]);
xlabel('$\overline{R}^{2}$','interpreter','latex','FontSize',10)
ylabel('Percentage','interpreter','latex','FontSize',10)
suptitle('Figure D.11(d): IP sectors vs. common & HF factors');
end
end

%--------------------------------------------------------------------------
% Adjusted R^2: IP growth indexes on COMMON and LF-specific factors vs. COMMON factor only
if DATES_SUBSET == 1 
%clc
disp(' '); disp(' ');
disp('=================================================================')
if AGGREGATION_FIRST == 1;  % Aggregation first 
disp('Table D.22: Regression of quarterly sectoral IP growth on common and HF-specific factors. Adjusted R^2 (Aggregation first)')
elseif AGGREGATION_FIRST == 0;  % PCA first
disp('Table D.23: Regression of quarterly sectoral IP growth on common and HF-specific factors. Adjusted R^2 (PCA first)')
end
disp('=================================================================')
disp(['Panel C. Increments in adj. R2'])
disp('-----------------------------------------------------------------') 
disp(['Ten sectors with largest Delta adj. R^2'])
disp('-----------------------------------------------------------------')
% Compute change ('Delta') in Adj. R^2 for all IP sectors when HF-specific factor is added to common factor
delta_R2 = RX_fHC - RX_fC ;

% Sorts all changes in R^2 ('Delta R^2') from largest to smallest 
[sorted_r2,sorted_r2_ind] = sort(delta_R2,1,'descend');

% Selects and display top ten
index_v_temp = sorted_r2_ind(1:10) ;

for i=1:10
    i_temp = index_v_temp(i,1) ;
    disp([ip_names_all{i_temp}, ' & ', num2str(delta_R2(i_temp),'%.2f'), ' \\']);
end

disp('-----------------------------------------------------------------') 
disp('Ten sectors with smallest Delta adj. R^2')
disp('-----------------------------------------------------------------')
% Selects and display ten smallest
index_v_temp = sorted_r2_ind((end-9):end) ;

for i=1:10
    i_temp = index_v_temp(i,1) ;
        disp([ip_names_all{i_temp}, ' & ', num2str(delta_R2(i_temp),'%.2f'), ' \\']);
end
disp('=================================================================')
end

%--------------------------------------------------------------------------
% REGRESSIONS OF AGGREGATE INDEXES ON ESTIMATED FACTORS
whichstats = {'adjrsquare','beta', 'yhat', 'mse'}; % statisitcs to be used

% Outoput matrix contianing R2s to display
R2_table = NaN(1,4) ; 
% clc ;

disp(' '); disp(' ');
disp('=================================================================')
if DATES_SUBSET == 1 && AGGREGATION_FIRST == 1;      % Full sample & Aggregation first 
disp('Table 3: Regression of quarterly IP index growth on common and HF-specific factors. Adjusted R^2 in latex format (Aggregation first)')
disp('===================================================================')
disp(['Panel A. Quarterly observations, 1977.Q1-2011.Q4'])
elseif DATES_SUBSET == 1 && AGGREGATION_FIRST == 0;  % % Full sample & PCA first
disp('Table D.17: Regression of quarterly IP index growth on common and HF-specific factors. Adjusted R^2 in latex format (PCA first)')
disp('===================================================================')
disp(['Panel A. Quarterly observations, 1977.Q1-2011.Q4'])
elseif DATES_SUBSET == 2 && AGGREGATION_FIRST == 1;  % Great Moderation & PCA first
disp('Table D.30: Regression of quarterly IP index growth on common and HF-specific factors. Adjusted R^2 in latex format (Aggregation first)')
disp('===================================================================')
disp(['Panel A. Quarterly observations, 1984.Q1-2007.Q4'])
elseif DATES_SUBSET == 3 && AGGREGATION_FIRST == 1;  % Great Moderation + last part of sample & PCA first
disp('Table D.30: Regression of quarterly IP index growth on common and HF-specific factors. Adjusted R^2 in latex format (Aggregation first)')
disp('===================================================================')
disp(['Panel A. Quarterly observations, 1984.Q1-2007.Q4'])
end
disp('-----------------------------------------------------------------') 
% regressions: IP index growth vs estimated common (and HF-specific) factor
y_reg = IPq_g_INDEX(dates_ip_subsamp,1); 

statsC       = regstats(y_reg, FC_hat,'linear',whichstats)       ;
statsH       = regstats(y_reg, FH_hat,'linear',whichstats)       ;
statsCH      = regstats(y_reg, [FC_hat FH_hat],'linear',whichstats);

bic_C  = (size(y_reg,1))*log(statsC.mse)  + (size(statsC.beta ,1))*log(size(y_reg,1));
bic_H  = (size(y_reg,1))*log(statsH.mse)  + (size(statsH.beta ,1))*log(size(y_reg,1));
bic_CH = (size(y_reg,1))*log(statsCH.mse) + (size(statsCH.beta,1))*log(size(y_reg,1));

% bic selection : select model with smallest bic
if     (bic_H  < bic_CH) && (bic_H  < bic_C ) ; sel_bic = 'H'  ;
elseif (bic_CH < bic_H ) && (bic_CH < bic_C ) ; sel_bic = 'CH' ;
elseif (bic_C  < bic_H ) && (bic_C  < bic_CH) ; sel_bic = 'C'  ;
end
% Display table with adj. R^2
if DATES_SUBSET == 1 
disp(' Sector                     R2(C)   R2(H)  R2(C+H) 3-1   BIC ')
elseif DATES_SUBSET == 2 || 3 
disp(' Sector                     R2(C)   R2(H)  R2(C+H) 3-1   ')    
end
disp('-----------------------------------------------------------------')
% save adj R2s to display
R2_table(1,1) = statsC.adjrsquare*100 ;
R2_table(1,2) = statsH.adjrsquare*100 ;
R2_table(1,3) = statsCH.adjrsquare*100;
%Increment of adj.R2 when specific factor is added
R2_table(1,4) = (statsCH.adjrsquare - statsC.adjrsquare)*100;

% Display table with adj. R^2
if DATES_SUBSET == 1 
disp(['Industrial Production (Q)'   , ' & ',... 
      num2str(R2_table(1,1) ,'%.2f')   ,' & ',...
      num2str(R2_table(1,2) ,'%.2f')   ,' & ',...
      num2str(R2_table(1,3) ,'%.2f')   ,' & ',...
      num2str(R2_table(1,4) ,'%.2f')   ,' & ',...
      sel_bic, ' \\' ]);
elseif DATES_SUBSET == 2 || 3
disp(['Industrial Production (Q)'   , ' & ',... 
      num2str(R2_table(1,1) ,'%.2f')   ,' & ',...
      num2str(R2_table(1,2) ,'%.2f')   ,' & ',...
      num2str(R2_table(1,3) ,'%.2f')   ,' & ',...
      num2str(R2_table(1,4) ,'%.2f')   , ' \\' ]);    
end

%--------------------------------------------------------------------------
if (DATES_SUBSET == 1 && AGGREGATION_FIRST == 1)  % full sample only & Aggregation first  
disp(' '); disp(' ');
disp('=================================================================')
disp('Generate Figure D.12(a): Regressions of IP index growth on factors')
disp('==================================================================')
figure;
y         = line((1:T_HF)', y_reg       ) ;
y_hat_C   = line((1:T_HF)', statsC.yhat ) ;
y_hat_CH  = line((1:T_HF)', statsCH.yhat) ;

set(y       , 'LineWidth',1.5, 'Color', 'b'                  );
set(y_hat_C , 'LineWidth',1.5, 'Color', 'r', 'LineStyle',':' );
set(y_hat_CH, 'LineWidth',1.5, 'Color', 'k', 'LineStyle','--');
set(gca,'XTick', Xtick_HF); set(gca,'XTickLabel', XtickLabel_HF); grid on ;
title('IP INDEX growth'); xlabel('Date');
suptitle('Figure D.12(a): Regressions of IP index growth on factors');
end

%--------------------------------------------------------------------------
% Regressions: LF obsrvables vs factors:
disp(' '); disp(' ');
disp('=================================================================')
if DATES_SUBSET == 1 && AGGREGATION_FIRST == 1;      % Full sample & Aggregation first 
disp('Table 3: Regression of annual aggregate GDP indexes growth on common and LF-specific factors. Adjusted R^2 in latex format (Aggregation first)')
disp('===================================================================')
disp(['Panel B. Yearly observations, 1977 - 2011'])
elseif DATES_SUBSET == 1 && AGGREGATION_FIRST == 0;  % % Full sample & PCA first
disp('Table D.17: Regression of annual aggregate GDP indexes growth on common and LF-specific factors. Adjusted R^2 in latex format (PCA first)')
disp('===================================================================')
disp(['Panel B. Yearly observations, 1977 - 2011'])
elseif DATES_SUBSET == 2 && AGGREGATION_FIRST == 1;  % Great Moderation & PCA first
disp('Table D.30: Regression of annual aggregate GDP indexes growth on common and LF-specific factors. Adjusted R^2 in latex format (Aggregation first)')
disp('===================================================================')
disp(['Panel B. Yearly observations, 1984 - 2007'])
elseif DATES_SUBSET == 3 && AGGREGATION_FIRST == 1;  % Great Moderation + last part of sample & PCA first
disp('Table D.30: Regression of annual aggregate GDP indexes growth on common and LF-specific factors. Adjusted R^2 in latex format (Aggregation first)')
disp('===================================================================')
disp(['Panel C. Yearly observations, 1984 - 2011'])
end
disp('-----------------------------------------------------------------') 

% Selects matrix of sectoral AGGREGATED GDP indexes to be regressed on factors
n_gdp_ind  = size(gdp_g_real_MACRO_INDEXES,1) ;

% Outoput matrix contianing R2 to display
R2_table = NaN(n_gdp_ind,5) ; i =[];

% Display table with adj. R^2
if DATES_SUBSET == 1; 
disp('Sector R2(C) R2(L)  R2(C+L)   3-1    BIC ')
elseif DATES_SUBSET == 2 || 3
disp('Sector R2(C) R2(L)  R2(C+L)  3-1')
end
disp('-----------------------------------------------------------------')
    
for i = 1:n_gdp_ind
y_reg   = gdp_g_real_MACRO_INDEXES(i,dates_gdp_subsamp)'               ;
    
statsC  = regstats(y_reg, [FC1+FC2+FC3+FC4],'linear',whichstats)       ;
statsL  = regstats(y_reg, [FL_hat],'linear',whichstats)                ;
statsCL = regstats(y_reg, [FC1+FC2+FC3+FC4, FL_hat],'linear',whichstats);
    
R2_table(i,1) = statsC.adjrsquare*100  ;
R2_table(i,2) = statsL.adjrsquare*100  ;
R2_table(i,3) = statsCL.adjrsquare*100 ;
%Increment of adj.R2 when specific factor is added
R2_table(i,4) = (statsCL.adjrsquare - statsC.adjrsquare)*100 ;
%--------------------------------------------------------------------------
bicC  = (size(y_reg,1))*log(statsC.mse ) + (size(statsC.beta,1) )*log(size(y_reg,1));
bicL  = (size(y_reg,1))*log(statsL.mse ) + (size(statsL.beta,1) )*log(size(y_reg,1));
bicCL = (size(y_reg,1))*log(statsCL.mse) + (size(statsCL.beta,1))*log(size(y_reg,1));

% bic selection
if     (bicL  < bicCL) && (bicL  < bicC ) ; sel_bic = 'L'  ;
elseif (bicCL < bicL ) && (bicCL < bicC ) ; sel_bic = 'CL' ;
elseif (bicC  < bicL ) && (bicC  < bicCL) ; sel_bic = 'C'  ;
end
%--------------------------------------------------------------------------
% Display table with adj. R^2
if DATES_SUBSET == 1 
disp([gdp_g_real_MACRO_INDEXES_names{i},' & ',...
      num2str(R2_table(i,1) ,'%.2f')   ,' & ',...
      num2str(R2_table(i,2) ,'%.2f')   ,' & ',...
      num2str(R2_table(i,3) ,'%.2f')   ,' & ',...
      num2str(R2_table(i,4) ,'%.2f')   ,' & ',...
      sel_bic, ' \\' ]);
elseif DATES_SUBSET == 2 || 3
disp([gdp_g_real_MACRO_INDEXES_names{i},' & ',...
      num2str(R2_table(i,1) ,'%.2f')   ,' & ',...
      num2str(R2_table(i,2) ,'%.2f')   ,' & ',...
      num2str(R2_table(i,3) ,'%.2f')   ,' & ',...
      num2str(R2_table(i,4) ,'%.2f')   , ' \\' ]);    
end
end

%--------------------------------------------------------------------------
% Figure: GDP index (all sectors) growth vs. all 3 estimated values from factor model
%clc
if (DATES_SUBSET == 1 && AGGREGATION_FIRST == 1)  % full sample only & Aggregation first 
disp(' '); disp(' ');
disp('=================================================================')
disp('Generate Figure D.12(b): Regressions of GDP index growth on factors')
disp('===================================================================')
y_reg = gdp_g_real_MACRO_INDEXES(1,dates_gdp)'; % Aggregate GDP (all sectors)

statsC  = regstats(y_reg, [FC1+FC2+FC3+FC4        ],'linear',whichstats);
statsCL = regstats(y_reg, [FC1+FC2+FC3+FC4 FL_hat ],'linear',whichstats);

figure;
y         = line((1:T_LF)', y_reg       ) ;
y_hat_C   = line((1:T_LF)', statsC.yhat ) ;
y_hat_CL  = line((1:T_LF)', statsCL.yhat) ;

set(y       , 'LineWidth',1.5, 'Color', 'b'                  );
set(y_hat_C , 'LineWidth',1.5, 'Color', 'r', 'LineStyle',':' );
set(y_hat_CL, 'LineWidth',1.5, 'Color', 'k', 'LineStyle','--');
set(gca,'XTick', Xtick_LF); set(gca,'XTickLabel', XtickLabel_LF); grid on ;
title('GDP growth'); xlabel('Date');
suptitle('Figure D.12(b): Regressions of GDP index growth on factors');

%--------------------------------------------------------------------------
% Figure: GDP CONSTRUCTION Sector index growth vs. estimated values from factor model
disp(' '); disp(' ');
disp('=================================================================')
disp('Generate Figure D.12(c): Regressions of GDP CONSTRUCTION Sector index growth on factors')
disp('===================================================================')
y_reg = gdp_g_real_MACRO_INDEXES(4,dates_gdp)'; % CONSTRUCTION Sector

statsC  = regstats(y_reg, [FC1+FC2+FC3+FC4        ],'linear',whichstats);
statsCL = regstats(y_reg, [FC1+FC2+FC3+FC4 FL_hat ],'linear',whichstats);

figure;
y         = line((1:T_LF)', y_reg       ) ;
y_hat_C   = line((1:T_LF)', statsC.yhat ) ;
y_hat_CL  = line((1:T_LF)', statsCL.yhat) ;

set(y       , 'LineWidth',1.5, 'Color', 'b'                  );
set(y_hat_C , 'LineWidth',1.5, 'Color', 'r', 'LineStyle',':' );
set(y_hat_CL, 'LineWidth',1.5, 'Color', 'k', 'LineStyle','--');
set(gca,'XTick', Xtick_LF); set(gca,'XTickLabel', XtickLabel_LF); grid on ;
title('GDP CONSTR. growth'); xlabel('Date');
suptitle('Figure D.12(c): Regressions of GDP CONSTRUCTION Sector index growth on factors');

%--------------------------------------------------------------------------
% Figure: GDP "Professional & Business Services" Sector index growth vs. estimated values from factor model
disp(' '); disp(' ');
disp('=================================================================')
disp('Generate Figure D.12(d): Regressions of GDP "Professional & Business Services" Sector index growth on factors')
disp('===================================================================')
y_reg = gdp_g_real_MACRO_INDEXES(10,dates_gdp)'; % "Professional & Business Services" Sector

statsC  = regstats(y_reg, [FC1+FC2+FC3+FC4        ],'linear',whichstats);
statsCL = regstats(y_reg, [FC1+FC2+FC3+FC4 FL_hat ],'linear',whichstats);

figure;
y         = line((1:T_LF)', y_reg       ) ;
y_hat_C   = line((1:T_LF)', statsC.yhat ) ;
y_hat_CL  = line((1:T_LF)', statsCL.yhat) ;

set(y       , 'LineWidth',1.5, 'Color', 'b'                  );
set(y_hat_C , 'LineWidth',1.5, 'Color', 'r', 'LineStyle',':' );
set(y_hat_CL, 'LineWidth',1.5, 'Color', 'k', 'LineStyle','--');
set(gca,'XTick', Xtick_LF); set(gca,'XTickLabel', XtickLabel_LF); grid on ;
title('Prof. and business services growth'); xlabel('Date');
suptitle('Figure D.12(d): Regressions of GDP "Prof. and business services" Sector index growth on factors');

%--------------------------------------------------------------------------
% Regressions: LF obsrvables vs. ALL 3 factors (common, HF-specific, LF-specific)
n_gdp_ind  = size(gdp_g_real_MACRO_INDEXES,1) ;

disp(' '); disp(' ');
disp('=================================================================')
disp('Table D.27: Regression of annual aggregate GDP indexes growth on common and LF-specific factors. Adjusted R^2 in latex format')
disp('===================================================================')
% Display table with adj. R^2
disp('Sector R2(C)  R2(L)  R2(H)  R2(C+L+H)  4-1 ')
disp('-----------------------------------------------------------------')
R2_table = NaN(n_gdp_ind,5) ; i =[]; 
for i = 1:n_gdp_ind
y_reg       = gdp_g_real_MACRO_INDEXES(i,dates_gdp_subsamp)'         ;
statsC     = regstats(y_reg, [FC1+FC2+FC3+FC4 ],'linear',whichstats) ;
statsH     = regstats(y_reg, [FH1+FH2+FH3+FH4 ],'linear',whichstats) ;
statsL     = regstats(y_reg, FL_hat,'linear',whichstats) ;
statsCHL   = regstats(y_reg, [FC1+FC2+FC3+FC4 FH1+FH2+FH3+FH4 FL_hat],'linear',whichstats);
R2_table(i,1) = statsC.adjrsquare*100   ; % common factor only
R2_table(i,2) = statsL.adjrsquare*100   ; % LF-specific factor only
R2_table(i,3) = statsH.adjrsquare*100   ; % HF-specific factor only
R2_table(i,4) = statsCHL.adjrsquare*100 ; % all 3 factors together

%Increment of adj.R2 when two spfecific factors are added
R2_table(i,5) = (statsCHL.adjrsquare - statsC.adjrsquare)*100 ; 

% Display table with adj. R^2
disp([gdp_g_real_MACRO_INDEXES_names{i},' & ',...
      num2str(R2_table(i,1) ,'%.2f')   ,' & ',...
      num2str(R2_table(i,2) ,'%.2f')   ,' & ',...
      num2str(R2_table(i,3) ,'%.2f')   ,' & ',...
      num2str(R2_table(i,4) ,'%.2f')   ,' & ',...
      num2str(R2_table(i,5) ,'%.2f')   ,' \\' ]);
end
disp('===================================================================')
end