function [numfac_tab_IPC1, numfac_tab_IPC2] = k1k2_selection_func(X,Y,kmax)
%--------------------------------------------------------------------------
% DESCRIPTION: Matlab function performing the selection of the number of
% pervasive factors using the Bai and Ng (2002) IC_p and PC_p criteria on
% two panels of High Frequency (HF) and Low Frequency (LF) data, 
% and different subpanels of the HF data.
%
% NOTE: works only with yearly/quarterly FLOW_SAMPLED data
%--------------------------------------------------------------------------
% Date  : 31.03.2019
% Author: Mirco Rubin
% Email : mircorubin@gmail.com
% updated files can be found also on the author's website:
% Web   : https://sites.google.com/site/mircorubin/ 
%--------------------------------------------------------------------------
% INPUT
% X          : (T_HF X N_HF) matrix
% Y          : (T_LF X N_LF) matrix
% kmax       : scalar, 'k_max' parameter = maximum number of factors in Bai and Ng (2002)
%--------------------------------------------------------------------------
% OUTPUT
% numfac_tab_ICP1 : table with estimated number of factors for 
%                   different panels for IC_p1 criterion, Bai and Ng (2002)
%
% numfac_tab_ICP2 : table with estimated number of factors for 
%                   different panels for IC_p2 criterion, Bai and Ng (2002)
%--------------------------------------------------------------------------
% Dimensions of panels (or 'groups')
[T_HF, N_HF] = size(X) ; 
[T_LF, N_LF] = size(Y) ;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% old function just for m = 4 sub-periods
% [X1, X2, X3, X4] = Stack_HF_LF_4superiods(X) ; 
%--------------------------------------------------------------------------
% More general function 
% NOTE: it can be memory consuming for very large matrices, as it generates a 3D-array
m = 4 ;
X_unstacked  = Stack_HF_LF_m_superiods(X,m);

X1       = X_unstacked(:,:,1) ;
X2       = X_unstacked(:,:,2) ;
X3       = X_unstacked(:,:,3) ;
X4       = X_unstacked(:,:,4) ;

Xagg             = X1 + X2 + X3 + X4         ;
%--------------------------------------------------------------------------
% Select number of factors
k_vec_selK_1 = PCA_BAING_2002_select_k_noplot(X1  ,kmax) ;
k_vec_selK_2 = PCA_BAING_2002_select_k_noplot(X2  ,kmax) ;
k_vec_selK_3 = PCA_BAING_2002_select_k_noplot(X3  ,kmax) ;
k_vec_selK_4 = PCA_BAING_2002_select_k_noplot(X4  ,kmax) ;
k_vec_selK_5 = PCA_BAING_2002_select_k_noplot(X   ,kmax) ; % X_HF , displayed in paper
k_vec_selK_6 = PCA_BAING_2002_select_k_noplot(Xagg,kmax) ; % X^H  , displayed in paper
k_vec_selK_7 = PCA_BAING_2002_select_k_noplot(Y   ,kmax) ; % X_L  , displayed in paper
k_vec_selK_8 = PCA_BAING_2002_select_k_noplot([Xagg,Y],kmax) ;
%--------------------------------------------------------------------------
% Tables with results
%--------------------------------------------------------------------------
% IPC 1
numfac_tab_IPC1(1,1)  = N_HF ;
numfac_tab_IPC1(1,2)  = N_LF ;
numfac_tab_IPC1(1,3)  = T_HF ;
numfac_tab_IPC1(1,4)  = T_LF ;
numfac_tab_IPC1(1,5)  = k_vec_selK_1(1,1)  ;
numfac_tab_IPC1(1,6)  = k_vec_selK_2(1,1)  ;
numfac_tab_IPC1(1,7)  = k_vec_selK_3(1,1)  ;
numfac_tab_IPC1(1,8)  = k_vec_selK_4(1,1)  ;
%--------------------------------------------------------------------------
numfac_tab_IPC1(1,9)  = k_vec_selK_5(1,1)  ; % X_HF, displayed in paper
numfac_tab_IPC1(1,10) = k_vec_selK_6(1,1)  ; % X^H , displayed in paper
numfac_tab_IPC1(1,11) = k_vec_selK_7(1,1)  ; % X_L , displayed in paper
%--------------------------------------------------------------------------
numfac_tab_IPC1(1,12) = k_vec_selK_8(1,1)  ;


%--------------------------------------------------------------------------
% Tables with results
%--------------------------------------------------------------------------
% IPC 2
numfac_tab_IPC2(1,1)  = N_HF ;
numfac_tab_IPC2(1,2)  = N_LF ;
numfac_tab_IPC2(1,3)  = T_HF ;
numfac_tab_IPC2(1,4)  = T_LF ;
numfac_tab_IPC2(1,5)  = k_vec_selK_1(1,2)  ;
numfac_tab_IPC2(1,6)  = k_vec_selK_2(1,2)  ;
numfac_tab_IPC2(1,7)  = k_vec_selK_3(1,2)  ;
numfac_tab_IPC2(1,8)  = k_vec_selK_4(1,2)  ;
%--------------------------------------------------------------------------
numfac_tab_IPC2(1,9)  = k_vec_selK_5(1,2)  ; % X_HF, displayed in paper
numfac_tab_IPC2(1,10) = k_vec_selK_6(1,2)  ; % X^H , displayed in paper
numfac_tab_IPC2(1,11) = k_vec_selK_7(1,2)  ; % X_L , displayed in paper
%--------------------------------------------------------------------------
numfac_tab_IPC2(1,12) = k_vec_selK_8(1,2)  ;


%% START OF NESTED FUNCTION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [kICp_vec, k_PCp_vec] = PCA_BAING_2002_select_k_noplot(X_nest, kmax_nest)
%--------------------------------------------------------------------------
% INPUT
% X         : (T X N) matrix
% kmax_nest : scalar = 'k_max' of Bai and Ng (2002)  
%
% OUTPUT
%
%--------------------------------------------------------------------------
[T_nest, N_nest] = size(X_nest)         ;
C2_NT            = min([N_nest,T_nest]) ;

[~, ~, ~, s2_nest, ~] = PCA_BAING_2002(X_nest,kmax_nest) ;

for k_nest = 1:kmax_nest
    
    ssr_nest    = [] ;
    
    [~, ~, ~, ssr_nest, ~] = PCA_BAING_2002(X_nest,k_nest) ;
    
    % IC_p1 (p.203, Bai Ng 2002)
    ICp(k_nest,1) =  log(ssr_nest) + k_nest*((N_nest+T_nest)/(N_nest*T_nest))*log((N_nest*T_nest)/(N_nest+T_nest)) ;
    % IC_p1 (p.203, Bai Ng 2002)
    ICp(k_nest,2) =  log(ssr_nest) + k_nest*((N_nest+T_nest)/(N_nest*T_nest))*log(C2_NT);
    % IC_p3 (p.203, Bai Ng 2002)
    ICp(k_nest,3) =  log(ssr_nest) + k_nest*(log(C2_NT)/C2_NT ) ; 
    % PC_p1 (p.203, Bai Ng 2002)
    PCp(k_nest,1) =  ssr_nest + k_nest*s2_nest*((N_nest+T_nest)/(N_nest*T_nest))*log((N_nest*T_nest)/(N_nest+T_nest))   ;
    % PC_p1 (p.203, Bai Ng 2002)
    PCp(k_nest,2) =  ssr_nest + k_nest*s2_nest*((N_nest+T_nest)/(N_nest*T_nest))*log(C2_NT) ;
    % PC_p1 (p.203, Bai Ng 2002)
    PCp(k_nest,3) =  ssr_nest + k_nest*s2_nest*(log(C2_NT)/C2_NT ) ; 
end
%--------------------------------------------------------------------------
% Case k = 0
ssr_nest = sum(trace(X_nest*X_nest'))/(N_nest*T_nest)   ;
ICp(kmax_nest+1,1) = log(ssr_nest) ;
ICp(kmax_nest+1,2) = log(ssr_nest) ;
ICp(kmax_nest+1,3) = log(ssr_nest) ;

PCp(kmax_nest+1,1) = ssr_nest      ;
PCp(kmax_nest+1,2) = ssr_nest      ;
PCp(kmax_nest+1,3) = ssr_nest      ;
%--------------------------------------------------------------------------
% ICp
[ k1, ~ ] = find(ICp(:,1) == min(ICp(:,1))) ;
[ k2, ~ ] = find(ICp(:,2) == min(ICp(:,2))) ;
[ k3, ~ ] = find(ICp(:,3) == min(ICp(:,3))) ;

if k1 > kmax_nest; k1 = 0 ; end
if k2 > kmax_nest; k2 = 0 ; end
if k3 > kmax_nest; k3 = 0 ; end

kICp_vec = [k1,k2,k3] ;
%--------------------------------------------------------------------------
% PCp % not displayed in output
[ k4, ~ ] = find(PCp(:,1) == min(PCp(:,1))) ;
[ k5, ~ ] = find(PCp(:,2) == min(PCp(:,2))) ;
[ k6, ~ ] = find(PCp(:,3) == min(PCp(:,3))) ;

if k4 > kmax_nest; k4 = 0 ; end
if k5 > kmax_nest; k5 = 0 ; end
if k6 > kmax_nest; k6 = 0 ; end

k_PCp_vec = [k4,k5,k6] ;

end
% END OF NESTED FUNCTION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end