% #########################################################################
% This is the replication file to reproduce all results of the 
% Monte Carlo (MC) Simulation Analysis of the paper:
% 
% ``Inference in Group Factor Models 
%   with an Application to Mixed Frequency Data''
% 
% by Elena Andreou, Patrick Gagliardini, Eric Ghysels, Mirco Rubin 
%
% The DGP and the MC results are rported and commented in 
% main Paper Section 6, and the Online Appendix (OA) Section E.
%--------------------------------------------------------------------------
% Date  : 31.03.2019
% Author: Mirco Rubin
% Email : mircorubin@gmail.com
% updated files can be found also on the author's website:
% Web   : https://sites.google.com/site/mircorubin/ 
%##########################################################################
clc; close all; clear all;
%##########################################################################
% DESIGN SELECTION

% Select simulation design by assigning an integer number between 1 and 15
design_n   = 1 ; 
% NOTE: Designs 1 - 11 correspond to the designs listed in 
%       in Table E.1, Section E.2 of the Online Appendix
%
% design_n = 12 ; % produces TABLE E.3 in Online Appendix (OA)
% design_n = 13 ; % produces TABLE E.4 in OA 
% design_n = 14 ; % produces TABLE E.5 in OA 
% design_n = 15 ; % produces TABLE E.6 in OA 
%##########################################################################
% FIGURES (Yes / No)

% Decide if figures of INFEASIBLE test statistics for the number of 
% common factors are produced and saved 
%(as in Figure 1 of the paper) by changing the value of 'figure_ind'

% Select by uncommenting relevant line
figure_ind = 1 ;   % produce histograms of INFEASIBLE statistics
% figure_ind = 0 ; % DOES NOT produce histograms of INFEASIBLE statistics
%##########################################################################
% SAMPLE SIZES 

% Few (i.e. 2) sample sizes (N_H, N_L, T) to test code quickly 
% (comment next 2 lines to replicate the entire MC analysis)

N_HLT_mat = [  50, 50,  35 ;...  
              100, 50,  35 ];

% ALL (i.e. 12) sample sizes (N_H, N_L, T) displayed in the OA of the paper 
% (uncomment next 5 lines to replicate the entire MC analysis)
         
% N_HLT_mat = [  50, 50,  35 ; ...
%               100, 50,  35 ; 100,100, 35 ; 100,100, 50 ;...
%               200,100,  50 ; 200,200, 50 ; 200,200,100 ;...
%               500,500, 100 ; 500,500,200 ; 500,500,300 ;...
%               800,800, 500 ; 1000, 1000, 600] ;
%##########################################################################
% NUMBER of MC SIMULATIONS

% NOTE: 'n_sim' must be >= 2 to avoid issues with 'mean' function 
% applied to vectors of saved simulation results within functions called
% this code

n_sim = 20; % small number of MC simulations to run code quickly.

% Uncomment next line to replicate the MC results in the Online Appendix
% n_sim = 4000  ;  % Number of MC simulations considered in the OA

% NOTE: considering 'n_sim' large (say, n_sim > 10) could imply that the
%       code takes a time > 30 min. to run, especially for simulations 
%       designs where T > 100

% To have an idea: 1 MC simulation, for one set of parameters, and one set
% of sample sizes N_H, N_T, T takes:
% CASE 1)  ~ 1 second  to run when N > T = 35  
% CASE 2)  ~ 2 MINUTES to run when N > T = 600

% For the latter case ( N > T = 600), but also for cases N > T >= 200
% Parallelization makes the code much faster to execute when n_sim > 100

%##########################################################################
% NAME OF OUTPUT FILES and SUBFOLDER where output are saved

% Assign name of a new .txt file to be saved in current folder 
% containing the tables of results for the MC simulation displayed 
% in the OA for each design
currentFolder = pwd ; % Change folder path to save output .mat files 

% Alternatively 'currentFolder' can be set manually as:
% currentFolder = 'C:\folder\subfolder\subsubfolder'
%-----------
% Create new folder named 'mat_table_save_DESIGN_i_yyyymmddTHHMMSS' within current folder
folderName = ['mat_table_save_DESIGN',num2str(design_n),'_',datestr(now, 'yyyymmddTHHMMSS')];
mkdir(folderName) % creates new folder

% comment/uncomment the appropriate one of the next two lines
% depending on the OS of the machine where code is running
savdir_mat = [currentFolder,'\',folderName];   % Microsoft Windows OS
%savdir_mat = [currentFolder,'/',folderName]; % Linux OS 
%-----------
output_file_name = ['Tables_design_',num2str(design_n),'.txt'];
% delete existing output file if present
if (exist(output_file_name) == 2); delete(output_file_name); end 
diary(output_file_name) % create new output file
%##########################################################################
% PARALLEL COMPUTING

% If code is run on a server with multiple cores for each node
% which supports Parallel Computing Toolbox, uncomment next line to
% OPEN Parpool as 'local',

% Assume that 'nworkers' are available in each node

% nworkers = 16 ; parpool('local',nworkers) 

% NOTE: The code is written such that the computational speed increases 
%       linearly with the number of workers

% To use PARALLEL COMPUTING the following change should also be made to
% function "SIMULATION_function.m":
% line 275 should be UNcommented and look line:  parfor i_sim = 1:n_sim 
% line 276 should be   commented and look line:  % for i_sim = 1:n_sim 

%##########################################################################
%##########################################################################
% NO NEED TO CHANGE CODE FROM HERE ONWARDS
%##########################################################################
%##########################################################################
% PARAMETERS kept constant across all simulation Designs 1 - 11
% (but are changed in designs 12 - 15 to reproduce additional tables in OA)

R_Hall_max     = 0.8   ;  % R_Hall_max
a_e            = 0     ;  % AR(1) param. of innovations
c              = 0.95  ;  % Parameters for critical values of the test
gamma          = 0.1   ;  % Parameters for critical values of the test
m_mat          = 4     ;  % n. of HF subperiods within each LF period
alpha_size_vec = [0.01, 0.05, 0.10]; % Nominal level of the test for size / power tables 
kmax           = 10    ;  % max n. of factors used in ICp criteria of  Bai & Ng (2002)
%##########################################################################
% PARAMETERS changing in each simulation design

if design_n == 1 ;
Kvec           = [1, 1, 1] ; % K_C, K_H and K_L, as one vector: Kvec = [k^c, k^H, k^L]
ICsel_nfactors = 2         ; % ICp2 (Bai Ng 2002)
beta           = 0         ; % beta, param of contemp. correlation among innovations
af_vec         = 0         ; % AR(1) param. of all factors
phi_vec        = 0         ; % contemp. correlation among pairs of specific factors
%---------------------------------------------------------
elseif design_n == 2 ;
Kvec           = [2, 0, 0] ; 
ICsel_nfactors = 2         ; % ICp2 (Bai Ng 2002)
beta           = 0         ; 
af_vec         = 0         ; 
phi_vec        = 0         ; 
%---------------------------------------------------------
elseif design_n == 3 ;
Kvec           = [2, 1, 1] ; 
ICsel_nfactors = 2         ; % ICp2 
beta           = 0         ; 
af_vec         = 0         ; 
phi_vec        = 0         ; 
%---------------------------------------------------------
elseif design_n == 4 ;
Kvec           = [1, 1, 1] ; 
ICsel_nfactors = 2         ; % ICp2 
beta           = 0.2       ; 
phi_vec        = 0         ; 
af_vec         = 0         ; 
%---------------------------------------------------------
elseif design_n == 5 ;
Kvec           = [1, 1, 1] ; 
ICsel_nfactors = 2         ; % ICp2 
beta           = 0         ; 
af_vec         = 0.6       ; 
phi_vec        = 0         ; 
%---------------------------------------------------------
elseif design_n == 6 ;
Kvec           = [1, 1, 1] ;
ICsel_nfactors = 2         ; % ICp2 
beta           = 0         ;
af_vec         = 0         ; 
phi_vec        = 0.7       ; 
%---------------------------------------------------------
elseif design_n == 7 ;
Kvec           = [1, 1, 1] ; 
ICsel_nfactors = 2         ; % ICp2 
beta           = 0         ; 
af_vec         = 0         ; 
phi_vec        = 0.95      ; 
%---------------------------------------------------------
elseif design_n == 8 ;
Kvec           = [1, 5, 5] ; 
ICsel_nfactors = 3         ; % ICp3 (Bai Ng 2002)
beta           = 0         ; 
af_vec         = 0         ; 
phi_vec        = 0         ; 
%---------------------------------------------------------
elseif design_n == 9 ;
Kvec           = [1, 5, 5] ; 
ICsel_nfactors = 3         ; % ICp3 
beta           = 0         ; 
af_vec         = 0         ; 
phi_vec        = 0.5       ; 
%---------------------------------------------------------
elseif design_n == 10 ;
Kvec           = [1, 5, 5] ; 
ICsel_nfactors = 3         ; % ICp3 
beta           = 0         ; 
af_vec         = 0         ; 
phi_vec        = 0.7       ; 
%---------------------------------------------------------
elseif design_n == 11 ;
Kvec           = [1, 5, 5] ; 
ICsel_nfactors = 3         ; % ICp3 
beta           = 0         ; 
af_vec         = 0         ; 
phi_vec        = 0.95      ; 
%##########################################################################
elseif design_n == 12 ;% produces TABLE E.3 in Online Appendix (all panels)
Kvec           = [1, 1, 1] ; 
ICsel_nfactors = 2         ; 
beta           = 0         ; 
af_vec         = 0.6       ; 
phi_vec        = 0         ;
%
N_HLT_mat      = [100, 50, 35];
R_Hall_max     = 0.8          ;
%##########################################################################
elseif design_n == 13 ;% produces TABLE E.4 in OA (all panels)
Kvec           = [1, 1, 1] ; 
ICsel_nfactors = 2         ;  
beta           = 0         ; 
af_vec         = 0.6       ; 
phi_vec        = 0         ;
%
N_HLT_mat      = [100, 50, 35];
R_Hall_max     = 0.6          ;
%##########################################################################
elseif design_n == 14 ;% produces TABLE E.5 in OA (all panels)
Kvec           = [1, 1, 1] ; 
ICsel_nfactors = 2         ;  
beta           = 0         ; 
af_vec         = 0         ; 
phi_vec        = 0.7       ;
%
N_HLT_mat      = [100, 50, 35];
R_Hall_max     = 0.8          ;
%##########################################################################
elseif design_n == 15 ;% produces TABLE E.6 in OA (all panels)
Kvec           = [1, 1, 1] ; 
ICsel_nfactors = 2         ; 
beta           = 0         ; 
af_vec         = 0         ; 
phi_vec        = 0.9       ;
%
N_HLT_mat      = [100, 50, 35];
R_Hall_max     = 0.8          ;
end
%##########################################################################
%##########################################################################
% rename some INPUTS, and fix some others
KC_sim = Kvec(1,1) ;
KH_sim = Kvec(1,2) ;
KL_sim = Kvec(1,3) ;

% LOADINGS DGP PARAMETERS
% determined by the values of R^2 max of each group of factors 
% (R^2 unif distributed for the moment)

R_Hall_min  = 0.10 ; % min R^2 of all fac. on HF data,    can be = 0

delta_HCmin = 0.2        ; % min >  0
delta_HCmax = 0.8        ; % max <= 1

R_Lall_min  = 0.10       ; % min R^2 of all fac. on LF data, can    be = 0
R_Lall_max  = R_Hall_max ; % max R^2 of all fac. on LF data, cannot be = 0

delta_LCmin = 0.2        ; % min >  0
delta_LCmax = 0.8        ; % max <= 1

n_samp_sizes = size(N_HLT_mat,1);        
%##########################################################################
% Generate empty tables containing MC simulation results summary as in 
% the OA of the paper, Displayed on Matlab command window,
% and saved into the 'Tables_design_?.txt' for this specific design

tot_lines = size(af_vec,1)*size(phi_vec,1)*n_samp_sizes ;

tab_out_SIZE_POWER_PCA_first = ones(tot_lines,12)*999 ;
tab_out_SIZE_POWER_AGG_first = ones(tot_lines,12)*999 ;
tab_out_EST_NFAC_k12_EST     = ones(tot_lines,15)*999 ;
tab_out_EST_NFAC_k12_TRU     = ones(tot_lines,15)*999 ;

% Initialize line number indicator: in the displayed tables of results 
% each line corresponds to three specific values of the 
% sample size param. N_H, N_L, T
line_count = 1 ; 
%##########################################################################
for ind_af = 1:size(af_vec,1)
    a_fac = af_vec(ind_af,1);
    
for ind_phi = 1:size(phi_vec,1)
    phi = phi_vec(ind_phi,1);
        
for ind_sizes = 1:size(N_HLT_mat,1)
    N_HLT = N_HLT_mat(ind_sizes,:) ;

for ind_m = 1:size(m_mat,1)
    m = m_mat(ind_m,1)     ;
%--------------------------------------------------------------------------
% Creates "structure" of input parameters used in MC simulations

sim_input.n_sim  = n_sim                  ;
sim_input.KC_sim = KC_sim                 ;
sim_input.KH_sim = KH_sim                 ;
sim_input.KL_sim = KL_sim                 ;
sim_input.m      = m                      ;
sim_input.N_HLT  = N_HLT                  ;
sim_input.a_fac  = a_fac                  ;
sim_input.a_e    = a_e                    ;
sim_input.phi    = phi                    ;
sim_input.beta   = beta                   ;

sim_input.R_Hall_min     = R_Hall_min     ;
sim_input.R_Hall_max     = R_Hall_max     ;
sim_input.delta_HCmin    = delta_HCmin    ;
sim_input.delta_HCmax    = delta_HCmax    ;
sim_input.R_Lall_min     = R_Lall_min     ;
sim_input.R_Lall_max     = R_Lall_max     ;
sim_input.delta_LCmin    = delta_LCmin    ;
sim_input.delta_LCmax    = delta_LCmax    ;
sim_input.c              = c              ;
sim_input.gamma          = gamma          ;
sim_input.savdir_mat     = savdir_mat     ;
sim_input.alpha_size_vec = alpha_size_vec ;
sim_input.ICsel_nfactors = ICsel_nfactors ;
sim_input.kmax           = kmax           ;
sim_input.design_n       = design_n       ;
sim_input.figure_ind     = figure_ind     ;

%##########################################################################
% RUN ALL 'n_sim' MC simulations 
% for a specific  set of parameters, and fixed sample sizes N_H, N_L, T

tic % initialize clock to monitor computational time on screen

[line_sim_tab_SizePower_AGGfirst, ...
 line_sim_tab_SizePower_PCAfirst,...
 line_sim_tab_Num_Factors_ESTIMATEDk1k2,...
 line_sim_tab_Num_Factors_TRUEk1k2 ]= SIMULATION_function(sim_input);

% Save simulation output for specific sample sizes in the appropriate lines
% of each table of results to be displayed
tab_out_SIZE_POWER_PCA_first(line_count,:) = line_sim_tab_SizePower_PCAfirst        ;
tab_out_SIZE_POWER_AGG_first(line_count,:) = line_sim_tab_SizePower_AGGfirst        ; 
tab_out_EST_NFAC_k12_EST(line_count,:)     = line_sim_tab_Num_Factors_ESTIMATEDk1k2 ;
tab_out_EST_NFAC_k12_TRU(line_count,:)     = line_sim_tab_Num_Factors_TRUEk1k2      ;

% Display which sample sizs have been executed, and design parameters on
% Matlab Command Window
text_shown_cw = sprintf('%s%d%s%d, %s %d%d%d, %s%.2f, %s%.2f, %s%.2f, %s%.2f, %s%d, %s%d, %d, %d, %s%d',...
                'line n. ',line_count, '/',tot_lines,...
                'K=',KC_sim,KH_sim,KL_sim, 'beta = ',beta,...
                'a_e = ',a_e, 'a_{fac} = ',a_fac,...
                'phi = ',phi, 'nsim = ',n_sim,...
                'N_H, N_L, T = ',N_HLT(1,1),N_HLT(1,2),N_HLT(1,3),...
                'm = ',m); disp(' ');                   
disp(text_shown_cw)

line_count = line_count + 1 ; % update to next line number

toc % STOP clock: it show on command window time to run all MC simulations 
    % for a specific set of parameters and sample sizes N_H, N_L, T
%--------------------------------------------------------------------------
end      
end
end
end

%##########################################################################
% DISPLAY OUTPUT TABLES on Matlab command window in Latex format

% NOTE: the code above is generic enough to allow vector valued:
% 1) af_vec
% 2) phi_vec
% 3) m_mat

% Nevertheless, the code to display the results below assumes that these
% last three vectors are indeed scalar

%##########################################################################
%##########################################################################
%##########################################################################
% SIZE/POWER 
%##########################################################################
%##########################################################################
%##########################################################################
disp(' ')
disp('#####################################################################################################################')
disp('DESIGN PARAMETERS')
fprintf('%s %d, %d, %d, %s%.2f, %s%.2f, %s%.2f, %s%.2f, %s%d, %s%d',...
        'k^C, k^H, k^L = ', KC_sim, KH_sim, KL_sim,...
        'beta = ', beta, 'a_e = ', a_e, 'a_{fac} = ',a_fac,...
        'phi = ',  phi,'nsim = ', n_sim, 'm = ', m_mat); disp(' ');
%--------------------------------------------------------------------------
if design_n <= 11 % produce the following tables only for Designs 1 - 11
%--------------------------------------------------------------------------
disp('#####################################################################################################################')
disp(' '); disp(' ');
disp('#####################################################################################################################')
disp('SIZE/POWER table.   HF DATA: PCA first, then flow sample the factors')
disp('---------------------------------------------------------------------------------------------------------------------')
disp('                                 SIZE                         SIZE                         POWER                     ')
disp('                                 INFEAS. : nominal size       FEAS. : nominal size         INFEAS. : nominal size    ')
disp('---------------------------------------------------------------------------------------------------------------------')
disp('     N_H      N_L         T      0.01      0.05      0.10     0.01      0.05      0.10     0.01      0.05      0.10  ')
disp('---------------------------------------------------------------------------------------------------------------------')

for ind_line_screen = 1:tot_lines
fprintf(['%7.0f & %7.0f & %7.0f & ' ,...
         '%7.2f & %7.2f & %7.2f &' ,...
         '%7.2f & %7.2f & %7.2f &' ,...
         '%7.2f & %7.2f & %7.2f' ,...
         '\\\\'],... 
         tab_out_SIZE_POWER_PCA_first(ind_line_screen,1:12)); disp(' ')
end
disp('---------------------------------------------------------------------------------------------------------------------')
disp('SIZE/POWER table.   HF DATA: flow sample first, then PCA')
disp('---------------------------------------------------------------------------------------------------------------------')
disp('                                 SIZE                         SIZE                         POWER                     ')
disp('                                 INFEAS. : nominal size       FEAS. : nominal size         INFEAS. : nominal size    ')
disp('---------------------------------------------------------------------------------------------------------------------')
disp('     N_H      N_L         T      0.01      0.05      0.10     0.01      0.05      0.10     0.01      0.05      0.10  ')
disp('---------------------------------------------------------------------------------------------------------------------')
for ind_line_screen = 1:tot_lines
fprintf(['%7.0f & %7.0f & %7.0f & ' ,...
         '%7.2f & %7.2f & %7.2f &' ,...
         '%7.2f & %7.2f & %7.2f &' ,...
         '%7.2f & %7.2f & %7.2f' ,...
         '\\\\'],... 
         tab_out_SIZE_POWER_AGG_first(ind_line_screen,1:12)); disp(' ')
end
disp('#####################################################################################################################')
disp(' '); disp(' ');

%##########################################################################
%##########################################################################
%##########################################################################
% ESTIMATED NUMBER OF FACTORS
%##########################################################################
%##########################################################################
%##########################################################################
disp('################################################################################################################################################')
disp('|                             |   AGGR (2016)               | AGGR(2016)                 |  CHEN (2012)             |   WANG (2012)            |')
disp('|                             |   HF data: PCA  first       | HF data: aggregation first |                          |                          |')
disp('|----------------------------------------------------------------------------------------------------------------------------------------------|')
disp('| EST. NUMBER OF FACTORS table: ESTIMATED k_1 and k_2                                                                                          |')
disp('|----------------------------------------------------------------------------------------------------------------------------------------------|')
disp('|                                Average number of estimated factors over "n_sim" MC Simulations                                               |')
disp('|    N_H      N_L         T    | k^C       k^H       k^L    | k^C       k^H       k^L    | k^C       k^H       k^L   | k^C       k^H       k^L |')
disp('|----------------------------------------------------------------------------------------------------------------------------------------------|')
for ind_line_screen = 1:tot_lines
fprintf( ['%7.0f & %7.0f & %7.0f &' ,...
         '%7.2f & %7.2f & %7.2f &' ,...
         '%7.2f & %7.2f & %7.2f &' ,...
         '%7.2f & %7.2f & %7.2f &' ,...         
         '%7.2f & %7.2f & %7.2f '  ,...
         '\\\\'],...  
         tab_out_EST_NFAC_k12_EST(ind_line_screen,1:15)); disp(' ')
end
disp('|----------------------------------------------------------------------------------------------------------------------------------------------|')
disp('| EST. NUMBER OF FACTORS table: TRUE k_1 and k_2                                                                                               |')
disp('|----------------------------------------------------------------------------------------------------------------------------------------------|')
disp('|                                Average number of estimated factors over "n_sim" MC Simulations                                               |')
disp('|    N_H      N_L         T    | k^C       k^H       k^L    | k^C       k^H       k^L    | k^C       k^H       k^L   | k^C       k^H       k^L |')
disp('|----------------------------------------------------------------------------------------------------------------------------------------------|')
for ind_line_screen = 1:tot_lines
fprintf( ['%7.0f & %7.0f & %7.0f &' ,...
         '%7.2f & %7.2f & %7.2f &' ,...
         '%7.2f & %7.2f & %7.2f &' ,...
         '%7.2f & %7.2f & %7.2f &' ,...         
         '%7.2f & %7.2f & %7.2f '  ,...
         '\\\\'],...  
         tab_out_EST_NFAC_k12_TRU(ind_line_screen,1:15)); disp(' ')
end
disp('################################################################################################################################################')
%--------------------------------------------------------------------------
end
%--------------------------------------------------------------------------
diary off % closes .txt file saving the tables to import in the OA

% Uncomment the next line to close Matlab when code has run
% exit; 