function [line_sim_tab_SizePower_AGGfirst, ...
line_sim_tab_SizePower_PCAfirst,...
line_sim_tab_Num_Factors_ESTIMATEDk1k2 ,...
line_sim_tab_Num_Factors_TRUEk1k2] = SIMULATION_function(sim_input)
% MC Simulation function to run MC simulations of the paper
% ``Inference in Group Factor Models with an Application to Mixed Frequency Data''

% by Elena Andreou, Patrick Gagliardini, Eric Ghysels, Mirco Rubin . 
%--------------------------------------------------------------------------
% Date  : 30.03.2019
% Author: Mirco Rubin
% Email : mircorubin@gmail.com
% updated files can be found also on the author's website:
% Web   : https://sites.google.com/site/mircorubin/ 
%--------------------------------------------------------------------------
% INPUT
% sim_input      : structure file
%--------------------------------------------------------------------------
% OUTPUT
% lines of tables of results in the OA of the paper, 
% and figures of MC analysis
%--------------------------------------------------------------------------
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SIMULATION ALGORITHM: Canonical correlation test TEST 
%                       for selection of the number of COMMON factors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DGP description
% m = 4, i.e. 4 HF subperiods for each LF period (Y/Q data). 
%        This number can be any integer > 0 in this code

% FACTOR MODEL, eq. (2.1):
% x_{m,t}  = Lambda_{HC} g_{m,t}^C + Lambda_{H} g_{m,t}^H + e_{m,t}^H   (N_H  X  1)
% y_{m,t}* = Lambda_{LC} g_{m,t}^C + Lambda_{H} g_{m,t}^L + e_{m,t}^L   (N_L  X  1)

% KC, KH, KL = n. of factors

% HF VAR(1) on true factors:
% G_mt = [g_{m,t}^C , g_{m,t}^H , g_{m,t}^L]'
% A    = diag(a_fC,...,a_fC, a_fH,..., a_fH, a_fL, ...a_fL), 

% where:
% a_fC = a_FH = a_fL = a_f
% G_mt = A G_{m-1,t} + (zeta^0.5)*eta_mt
% u_mt ~ iidN(0, Sigma_eta) 
% zeta = (1-a_fac^2)/M2k

%             [ I  0     0   ]
% Sigma_eta = [ 0  I     Phi ]   
%             [ 0  Phi'  I   ]
%--------------------------------------------------------------------------
% LOADINGS 
% By construction of the simulation designs
% each type factor C, H, L contribute (on average) to R^2 
% in the same way if KC or KH or KL >1
%--------------------------------------------------------------------------
% IDIOSYNCRATIC INNOVATIONS 
% e_{m,t}^H = a_eH e_{m-1,t}^H + v_t^H
% e_{m,t}^L = a_eL e_{m-1,t}^L + v_t^L
%
% v_t = [v_t^H, v_t^H] ~ iiN(0, Sigma_v)
% Sigma_v(ij) = beta^(|i-j|);           % TOEPLITZ MATRIX
%--------------------------------------------------------------------------
% SIMULATION DESIGN SETTINGS: DGP and other input parameters

n_sim          = sim_input.n_sim          ;
KC_sim         = sim_input.KC_sim         ;
KH_sim         = sim_input.KH_sim         ;
KL_sim         = sim_input.KL_sim         ;
m              = sim_input.m              ;
N_H            = sim_input.N_HLT(1,1)     ;
N_L            = sim_input.N_HLT(1,2)     ;
T              = sim_input.N_HLT(1,3)     ;
a_fac          = sim_input.a_fac          ;
a_e            = sim_input.a_e            ;
phi            = sim_input.phi            ;
beta           = sim_input.beta           ;
R_Hall_min     = sim_input.R_Hall_min     ;
R_Hall_max     = sim_input.R_Hall_max     ;
delta_HCmin    = sim_input.delta_HCmin    ;
delta_HCmax    = sim_input.delta_HCmax    ;
R_Lall_min     = sim_input.R_Lall_min     ;
R_Lall_max     = sim_input.R_Lall_max     ;
delta_LCmin    = sim_input.delta_LCmin    ;
delta_LCmax    = sim_input.delta_LCmax    ;
c              = sim_input.c              ;
gamma          = sim_input.gamma          ;
savdir_mat     = sim_input.savdir_mat     ;
alpha_size_vec = sim_input.alpha_size_vec ;
ICsel_nfactors = sim_input.ICsel_nfactors ;
kmax           = sim_input.kmax           ;
design_n       = sim_input.design_n       ;
figure_ind     = sim_input.figure_ind     ;
%--------------------------------------------------------------------------
% rename some inputs

a_gC    = a_fac ; 
a_gH    = a_fac ; 
a_gL    = a_fac ;

a_eH    = a_e   ; 
a_eL    = a_e   ;

N_H_sim = N_H   ; 
N_L_sim = N_L   ; 
N       = min([N_H_sim, N_L_sim])    ;
T_sim   = T     ;

k_1_sim   = KC_sim + KH_sim          ;
k_2_sim   = KC_sim + KH_sim          ;
k_min_sim = min([k_1_sim,k_2_sim])   ;
K_all_sim = KC_sim + KH_sim + KL_sim ;

% Block diagonal Autoregressive matrix for factor dynamics
if KC_sim == 0;  KC_simG = 1 ; else KC_simG = KC_sim;  end
if KH_sim == 0;  KH_simG = 1 ; else KH_simG = KH_sim;  end
if KL_sim == 0;  KL_simG = 1 ; else KL_simG = KL_sim;  end

K_all_simG = KC_simG + KH_simG + KL_simG;

A11     = a_gC*ones(KC_simG,1)      ; 
A22     = a_gH*ones(KH_simG,1)      ;
A33     = a_gL*ones(KL_simG,1)      ;
A_mtx   = diag([A11;A22;A33])       ;

Phi_mtx = zeros(KH_simG,KL_simG)    ;
if KH_simG == KL_simG
    Phi_mtx = phi*eye(KL_simG)      ;
elseif KH_simG < KL_simG
    Phi_mtx(1:KH_simG,1:KH_simG) = phi*eye(KH_simG) ;
elseif KH_simG > KL_simG
    Phi_mtx(1:KL_simG,1:KL_simG) = phi*eye(KL_simG) ;
end

N_all_sim = N_H_sim + N_L_sim       ;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Create empty matrices containing summary of results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FEASIBLE test/estimators of n. of factors

mat_summary_all_LF        = zeros(n_sim,3+k_min_sim);
mat_summary_all_sumcc_LF  = zeros(n_sim,k_min_sim)  ;
mat_summary_all_bias_LF   = zeros(n_sim,k_min_sim)  ;
mat_summary_all_std_LF    = zeros(n_sim,k_min_sim)  ;
%--------------------------------------------------------------------------
mat_summary_all_HF        = zeros(n_sim,3+k_min_sim);
mat_summary_all_sumcc_HF  = zeros(n_sim,k_min_sim)  ;
mat_summary_all_bias_HF   = zeros(n_sim,k_min_sim)  ;
mat_summary_all_std_HF    = zeros(n_sim,k_min_sim)  ;
%--------------------------------------------------------------------------
mat_summary_all_stL_k12 = zeros(n_sim,3)          ; 
mat_summary_all_stH_k12 = zeros(n_sim,3)          ;
%--------------------------------------------------------------------------
% matrices for CHEN (2012)
mat_summary_all_CHEN_k12true = zeros(n_sim ,3+k_min_sim+1+k_min_sim+1); 
mat_summary_all_CHEN_k12est  = zeros(n_sim ,3)         ;
%--------------------------------------------------------------------------
% matrices for WANG (2012)
K_gHL_est_mat = zeros(n_sim,2)    ;
k_est_WANG    = zeros(n_sim,3)    ;
k_true_WANG   = zeros(n_sim,3)    ;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% UNFEASIBLE estimators of n. of factors

% LF
mat_summary_all_UNF_LF       = zeros(n_sim,1);
mat_summary_all_sumcc_UNF_LF = zeros(n_sim,1);
mat_summary_all_bias_UNF_LF  = zeros(n_sim,1);
mat_summary_all_std_UNF_LF   = zeros(n_sim,1);

% HF
mat_summary_all_UNF_HF       = zeros(n_sim,1);
mat_summary_all_sumcc_UNF_HF = zeros(n_sim,1);
mat_summary_all_bias_UNF_HF  = zeros(n_sim,1);
mat_summary_all_std_UNF_HF   = zeros(n_sim,1);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Table to store all simulated adj. R^2 needed 
% to produce Tables E.3 and E.4 in the Online Appendix
if design_n == 12 || design_n == 13

% adj. R2 quantiles (obtained from 'true' factors)
RY_fL_quant_sim  = zeros(n_sim,5);
RY_fLC_quant_sim = zeros(n_sim,5);
RY_fC_quant_sim  = zeros(n_sim,5); 
RX_fH_quant_sim  = zeros(n_sim,5);
RX_fHC_quant_sim = zeros(n_sim,5);
RX_fC_quant_sim  = zeros(n_sim,5);

% adj. R2 quantiles (obtained from 'estimated' factors)
RY_fL_quant_hat  = zeros(n_sim,5);
RY_fLC_quant_hat = zeros(n_sim,5);
RY_fC_quant_hat  = zeros(n_sim,5);
RX_fH_quant_hat  = zeros(n_sim,5);
RX_fHC_quant_hat = zeros(n_sim,5);
RX_fC_quant_hat  = zeros(n_sim,5);

end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Table to store all simulated adj. R^2 needed 
% to produce Tables E.5 and E.6 in the Online Appendix
if design_n == 14 || design_n == 15

% R2 quantiles (obtained from 'estimated' factors)
RY_fL_quant_hat111     = zeros(n_sim,5);
RY_fLC_quant_hat111    = zeros(n_sim,5);
RY_fC_quant_hat111     = zeros(n_sim,5);
RX_fH_quant_hat111     = zeros(n_sim,5);
RX_fHC_quant_hat111    = zeros(n_sim,5);
RX_fC_quant_hat111     = zeros(n_sim,5);

RY_fC_quant_hat200     = zeros(n_sim,5);
RX_fC_quant_hat200     = zeros(n_sim,5);

% Adj. R2 quantiles (obtained from 'estimated' factors)
adjRY_fL_quant_hat111  = zeros(n_sim,5);
adjRY_fLC_quant_hat111 = zeros(n_sim,5);
adjRY_fC_quant_hat111  = zeros(n_sim,5);
adjRX_fH_quant_hat111  = zeros(n_sim,5);
adjRX_fHC_quant_hat111 = zeros(n_sim,5);
adjRX_fC_quant_hat111  = zeros(n_sim,5);

adjRY_fC_quant_hat200  = zeros(n_sim,5);
adjRX_fC_quant_hat200  = zeros(n_sim,5);

end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SIMULATE ONCE FOR ALL sim loadings and factors 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% create structure of INPUT parameters used to simulate factors & loadings
v_sim_input.KC_sim      = KC_sim      ;
v_sim_input.KH_sim      = KH_sim      ;
v_sim_input.KL_sim      = KL_sim      ;
v_sim_input.m           = m           ;
v_sim_input.T           = T           ;
v_sim_input.N_H_sim     = N_H_sim     ;
v_sim_input.N_L_sim     = N_L_sim     ;
v_sim_input.T_sim       = T_sim       ;
v_sim_input.a_gC        = a_gC        ;
v_sim_input.a_gH        = a_gH        ;
v_sim_input.a_gL        = a_gL        ;
v_sim_input.a_fac       = a_fac       ;
v_sim_input.a_e         = a_e         ;
v_sim_input.beta        = beta        ;
v_sim_input.R_Hall_min  = R_Hall_min  ;
v_sim_input.R_Hall_max  = R_Hall_max  ;
v_sim_input.delta_HCmin = delta_HCmin ; 
v_sim_input.delta_HCmax = delta_HCmax ;
v_sim_input.R_Lall_min  = R_Lall_min  ;
v_sim_input.R_Lall_max  = R_Lall_max  ;
v_sim_input.delta_LCmin = delta_LCmin ;
v_sim_input.delta_LCmax = delta_LCmax ;
v_sim_input.k_1_sim     = k_1_sim     ;
v_sim_input.k_2_sim     = k_2_sim     ;
v_sim_input.k_min_sim   = k_min_sim   ;
v_sim_input.K_all_sim   = K_all_sim   ;
v_sim_input.KC_simG     = KC_simG     ;
v_sim_input.KH_simG     = KH_simG     ;
v_sim_input.KL_simG     = KL_simG     ;
v_sim_input.K_all_simG  = K_all_simG  ;
v_sim_input.A11         = A11         ;
v_sim_input.A22         = A22         ;
v_sim_input.A33         = A33         ; 
v_sim_input.A_mtx       = A_mtx       ;
v_sim_input.Phi_mtx     = Phi_mtx     ;
v_sim_input.N_all_sim   = N_all_sim   ;
%##########################################################################
%##########################################################################
%##########################################################################
% 'for' or 'parfor' loop starts here
%##########################################################################
%##########################################################################
%##########################################################################
% comment/uncomment for/parfor to use/not use Parallel computing 
% parfor i_sim = 1:n_sim 
for i_sim = 1:n_sim

% Uncomment to display executed individual MC simualation number on screen:
% i_sim
%##########################################################################
% Simulate factors and loadings from HF Data Generating Process
[FC_sim, FH_sim, FL_sim,...
 L_HC_sim, L_H_sim,     ...
 L_LC_sim, L_L_sim] = simulation_factors_and_loadings(v_sim_input);

%##########################################################################
% Simulate innovations e_{m,t}^H and e_{m,t}^L
toep_row_temp = zeros(1,N_all_sim);
toep_row_temp(1,1) = 1;

for ind = 2:N_all_sim; 
    toep_row_temp(1,ind) = beta^(ind);
end

v_mat_all = mvnrnd(zeros(1,N_all_sim),toeplitz(toep_row_temp), m*T_sim+1) ;

% HF and LF innovations, autocorrelated
e_mat_simH = zeros(m*T_sim+1, N_H_sim);
e_mat_simL = zeros(m*T_sim+1, N_L_sim);

e_mat_simH(1,:) = v_mat_all(1,1:N_H_sim            );
e_mat_simL(1,:) = v_mat_all(1,(N_H_sim+1):N_all_sim);

for t=2:(m*T_sim+1)
    e_mat_simH(t,:) = a_eH*e_mat_simH(t-1,:) + sqrt(1-a_eH^2)*v_mat_all(t,1:N_H_sim) ;
    e_mat_simL(t,:) = a_eL*e_mat_simL(t-1,:) + sqrt(1-a_eL^2)*v_mat_all(t,(N_H_sim+1):N_all_sim,:);
end

e_mat_simH = e_mat_simH(2:end,:);
e_mat_simL = e_mat_simL(2:end,:);
%##########################################################################
% GENRATE X and Y panels of HF observations from simulated factors, innovations and loadings

% x_{m,t}  = Lambda_{HC} g_{m,t}^C + Lambda_{H} g_{m,t}^H + e_{m,t}^H    (N_H  X  1)
% y_{m,t}* = Lambda_{LC} g_{m,t}^C + Lambda_{L} g_{m,t}^L + e_{m,t}^L    (N_L  X  1)

X_sim     = FC_sim*L_HC_sim' + FH_sim*L_H_sim' + e_mat_simH ;  % (m*T_sim X N_H_sim)
Ystar_sim = FC_sim*L_LC_sim' + FL_sim*L_L_sim' + e_mat_simL ;  % (m*T_sim X N_L_sim)

% Generates "flow" sampled LF observables (Y), and true factors
Y_sim_fl      = zeros(T_sim, N_L_sim)         ;
X_sim_fl      = zeros(T_sim, N_H_sim)         ;

FL_sim_fl     = zeros(T_sim, max([1;KL_sim])) ;
FC_sim_fl     = zeros(T_sim, max([1;KC_sim])) ;
e_mat_simH_LF = zeros(T_sim, N_H_sim)         ;
e_mat_simL_LF = zeros(T_sim, N_L_sim)         ;

for t = 1:T_sim
    % Flow samp.
    t_start = m*(t-1)+1 ;
    t_end   = m*t       ;
    Y_sim_fl(t,:)  = sum(Ystar_sim(t_start:t_end,:),1) ;
    X_sim_fl(t,:)  = sum(X_sim(t_start:t_end,:),1)     ;
    FL_sim_fl(t,:) = sum(FL_sim(t_start:t_end,:),1)    ;
    FC_sim_fl(t,:) = sum(FC_sim(t_start:t_end,:),1)    ;
    
    e_mat_simH_LF(t,:) = sum(e_mat_simH(t_start:t_end,:),1)   ;
    e_mat_simL_LF(t,:) = sum(e_mat_simL(t_start:t_end,:),1)   ;
end
%##########################################################################
% Estimate number of factors and save in tables

% Here: n. of pervasive factors in each panel k_1 and k_2 
%       is estimated using the IC_p selection criteria of Bai and Ng (2002) 
%       applied on the 2 groups of data separately
%--------------------------------------------------------------------------
[k1_vec, ~] = PCA_BAING_2002_select_k_noplot(zscore(X_sim)   ,kmax) ;
[k2_vec, ~] = PCA_BAING_2002_select_k_noplot(zscore(Y_sim_fl),kmax) ;
%--------------------------------------------------------------------------
if ICsel_nfactors == 1     % ICP1
K_gH_est = k1_vec(1,1); 
K_gL_est = k2_vec(1,1); 
elseif ICsel_nfactors == 2 % ICP2
K_gH_est = k1_vec(1,2); 
K_gL_est = k2_vec(1,2); 
elseif ICsel_nfactors == 3 % ICP3
K_gH_est = k1_vec(1,3); 
K_gL_est = k2_vec(1,3); 
end
K_gHL_est_mat(i_sim,:) = [K_gH_est, K_gL_est];

%##########################################################################
%##########################################################################
%##########################################################################
% Estimation of n. of factors as in WANG (2012)
%##########################################################################
%##########################################################################
%##########################################################################
% Estimation of number of factors suggested as in WANG (2012)
% performed by using:

% a) the estimated number of pervasive factors in each group: k_1 and k_2
%    using the IC_p criteria of Bai & Ng (2002)

% b) the true number of pervasive factors in each group: k_1 and k_2
%--------------------------------------------------------------------------
% The number of estimated factors in the panels containing the two staked
% panels of HF (aggregated at LF) and LF data is always estimated using the
% IC_p criteria

% this allows to compare the effect of the initial estimation of 
% k_1 and k_2 on the estimator of the estimated number of common factors

[k12stack_vec, ~] = PCA_BAING_2002_select_k_noplot(zscore([X_sim_fl,Y_sim_fl]),2*kmax) ;

%##########################################################################
% NOTE: different IC_p (Bai & Ng ECMA 2002) information criteria produce 
% different number of estimated factors in very small sample sizes N,T
if ICsel_nfactors == 1               % ICP1
k12stack_est = k12stack_vec(1,1) ;
elseif ICsel_nfactors == 2           % ICP2
k12stack_est = k12stack_vec(1,2) ; 
elseif ICsel_nfactors == 3           % ICP3
k12stack_est = k12stack_vec(1,3) ;
end

kCest_WANG = K_gH_est + K_gL_est - k12stack_est ;

%--------------------------------------------------------------------------
if ((K_gH_est~=0)&&(K_gL_est~=0))
k_est_WANG(i_sim,:)=[kCest_WANG,...
                     K_gH_est - kCest_WANG ,...
                     K_gL_est - kCest_WANG ];
                 
elseif ((K_gH_est==0)&&(K_gL_est~=0))
k_est_WANG(i_sim,:)= [0,0,K_gL_est];

elseif ((K_gH_est~=0)&&(K_gL_est==0))
k_est_WANG(i_sim,:)= [0,K_gH_est,0]; 

elseif ((K_gH_est==0)&&(K_gL_est==0))
k_est_WANG(i_sim,:)= [0,0,0]; 

end  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% a) True values of estimated factors:
% k1 : renamed as K_gH in this code
% k2 : renamed as K_gL in this code

K_gH = KC_sim + KH_sim  ;
K_gL = KC_sim + KL_sim  ;

kCtrue_WANG   = K_gH + K_gL - k12stack_est ;

k_true_WANG(i_sim,:)=[kCtrue_WANG,...
                      K_gH - kCtrue_WANG ,...
                      K_gL - kCtrue_WANG ];  
%##########################################################################
%##########################################################################
%##########################################################################
if ((K_gH_est~=0)&&(K_gL_est~=0))
%--------------------------------------------------------------------------  
% performs test on the number of common factors using the estimated values
% of k_1 and k_2

aggregation_first_ind = 1 ; % aggregation first
stand_HL = 'L'            ; % data standardized after aggregation 

[cc_mat_summary_standLF_k12est] = sel_nfactors_MC(X_sim, Y_sim_fl, K_gH_est, K_gL_est,...
                                                  'cdir_HF', c, gamma,...
                                                  FC_sim,...
                                                  L_HC_sim, L_H_sim, ...
                                                  L_LC_sim, L_L_sim, ...
                                                  FC_sim_fl,...
                                                  m, 'F', stand_HL, aggregation_first_ind);
%--------------------------------------------------------------------------
aggregation_first_ind = 0 ; % PCA first
stand_HL = 'H'            ; % data standardized prior aggregation

[cc_mat_summary_standHF_k12est] = sel_nfactors_MC(X_sim, Y_sim_fl, K_gH_est, K_gL_est,...
                                                  'cdir_HF', c, gamma,...
                                                  FC_sim,...
                                                  L_HC_sim, L_H_sim, ...
                                                  L_LC_sim, L_L_sim, ...
                                                  FC_sim_fl,...
                                                  m, 'F', stand_HL, aggregation_first_ind);
%--------------------------------------------------------------------------
elseif ((K_gH_est==0)&&(K_gL_est~=0))
cc_mat_summary_standLF_k12est = [0,0,K_gL_est];
cc_mat_summary_standHF_k12est = [0,0,K_gL_est];

elseif ((K_gH_est~=0)&&(K_gL_est==0))
cc_mat_summary_standLF_k12est = [0,K_gH_est,0];
cc_mat_summary_standHF_k12est = [0,K_gH_est,0]; 

elseif ((K_gH_est==0)&&(K_gL_est==0))
cc_mat_summary_standLF_k12est = [0,0,0];
cc_mat_summary_standHF_k12est = [0,0,0];

end

%##########################################################################
% Estimate number of factors using canonical correlation test
% and save in summary tables
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% HERE: n. of pervasive factors in each panel k_1 and k_2 
%       are the TRUE ones for the moment
% BAI & NG (2002) selection of number of pervasive factors is performed 
% on the 2 groups separately
% K_gH = KC_sim + KH_sim  ;
% K_gL = KC_sim + KL_sim  ;

%--------------------------------------------------------------------------  
% performs test on the number of common factors using the estimated values
% of k_1 and k_2
aggregation_first_ind = 1 ; % HF data are first aggregated at LF, and then PCA on the aggregated data
stand_HL = 'L'            ; % data standardized after aggregation

% NOTE: in this case (i.e. when HF data are first aggregated at LF), 
% standardizing the data before or after the aggregation of HF data 
% does not change the empirical size and power 
% of the FEASIBLE test statistics for all the desings, 
% and produces minor differences w.r.t. the reported results only for the
% empirical size of the UNFEASIBLE test for the designs in which T <= 50

[cc_mat_summary_standLF_k12true, ...
 cc_mat_standLF_k12true,...
 cc_mat_UNF_standLF_k12true] = sel_nfactors_MC(X_sim, Y_sim_fl, K_gH, K_gL,...
                                               'cdir_HF', c, gamma,...
                                               FC_sim,...
                                               L_HC_sim, L_H_sim, ...
                                               L_LC_sim, L_L_sim, ...
                                               FC_sim_fl,...
                                               m, 'I', stand_HL, aggregation_first_ind);
%--------------------------------------------------------------------------
aggregation_first_ind = 0 ; % PCA first on HF data, then aggregate PCs at LF
stand_HL = 'H'            ; % data standardized prior aggregation

[cc_mat_summary_standHF_k12true, ...
 cc_mat_standHF_k12true,...
 cc_mat_UNF_standHF_k12true] = sel_nfactors_MC(X_sim, Y_sim_fl, K_gH, K_gL,...
                                               'cdir_HF', c, gamma,...
                                               FC_sim,...
                                               L_HC_sim, L_H_sim, ...
                                               L_LC_sim, L_L_sim, ...
                                               FC_sim_fl,...
                                               m, 'I', stand_HL, aggregation_first_ind);
%--------------------------------------------------------------------------
% FEASIBLE
mat_summary_all_LF(i_sim,:)       = cc_mat_summary_standLF_k12true;
mat_summary_all_sumcc_LF(i_sim,:) = cc_mat_standLF_k12true(:,3)' ;
mat_summary_all_bias_LF(i_sim,:)  = cc_mat_standLF_k12true(:,4)' ;
mat_summary_all_std_LF(i_sim,:)   = cc_mat_standLF_k12true(:,5)' ;
%--------------------------------------------------------------------------
mat_summary_all_HF(i_sim,:)       = cc_mat_summary_standHF_k12true;
mat_summary_all_sumcc_HF(i_sim,:) = cc_mat_standHF_k12true(:,3)' ;
mat_summary_all_bias_HF(i_sim,:)  = cc_mat_standHF_k12true(:,4)' ;
mat_summary_all_std_HF(i_sim,:)   = cc_mat_standHF_k12true(:,5)' ;
%--------------------------------------------------------------------------
mat_summary_all_stL_k12(i_sim,:)  = cc_mat_summary_standLF_k12est(1,1:3);
mat_summary_all_stH_k12(i_sim,:)  = cc_mat_summary_standHF_k12est(1,1:3);
%--------------------------------------------------------------------------
% UNFEASIBLE
mat_summary_all_UNF_LF(i_sim,:)       = cc_mat_UNF_standLF_k12true(1,2); % save value of UNFEASIBLE TEST STATISTCS (reproduced/saved in histograms)
mat_summary_all_sumcc_UNF_LF(i_sim,:) = cc_mat_UNF_standLF_k12true(1,3);
mat_summary_all_bias_UNF_LF(i_sim,:)  = cc_mat_UNF_standLF_k12true(1,4);
mat_summary_all_std_UNF_LF(i_sim,:)   = cc_mat_UNF_standLF_k12true(1,5);
%--------------------------------------------------------------------------
mat_summary_all_UNF_HF(i_sim,:)       = cc_mat_UNF_standHF_k12true(1,2);
mat_summary_all_sumcc_UNF_HF(i_sim,:) = cc_mat_UNF_standHF_k12true(1,3);
mat_summary_all_bias_UNF_HF(i_sim,:)  = cc_mat_UNF_standHF_k12true(1,4);
mat_summary_all_std_UNF_HF(i_sim,:)   = cc_mat_UNF_standHF_k12true(1,5);

%##########################################################################
%##########################################################################
%##########################################################################
% Estimation of n. of factors with Chen (2012) penalized criteria
%##########################################################################
%##########################################################################
%##########################################################################
% true k1 and k2
[cc_test_mat_summary_CHEN_k12true] = sel_nfactors_CHEN_given_k1k2(X_sim, Y_sim_fl, 'yq', 'flow', K_gH, K_gL, m);
% estimated k1 and k2
if ((K_gH_est~=0)&&(K_gL_est~=0))
[cc_test_mat_summary_CHEN_k12est ] = sel_nfactors_CHEN_given_k1k2(X_sim, Y_sim_fl, 'yq', 'flow', K_gH_est, K_gL_est, m);
elseif ((K_gH_est==0)&&(K_gL_est~=0))
cc_test_mat_summary_CHEN_k12est = [0,0,K_gL_est];
elseif ((K_gH_est~=0)&&(K_gL_est==0))
cc_test_mat_summary_CHEN_k12est = [0,K_gH_est,0]; 
elseif ((K_gH_est==0)&&(K_gL_est==0))
cc_test_mat_summary_CHEN_k12est = [0,0,0]; 
end  

mat_summary_all_CHEN_k12true(i_sim,:) = cc_test_mat_summary_CHEN_k12true;
mat_summary_all_CHEN_k12est(i_sim,:)  = cc_test_mat_summary_CHEN_k12est(1,1:3);

K_gH_est                        = [];
K_gL_est                        = [];
k12stack_est                    = [];
cc_mat_summary_standLF_k12est   = [];
cc_mat_summary_standHF_k12est   = [];
cc_test_mat_summary_CHEN_k12est = [];
%##########################################################################
%##########################################################################
%##########################################################################


%##########################################################################
%##########################################################################
%##########################################################################
%##########################################################################
%##########################################################################
%##########################################################################
% Table to store all simulated adj. R^2 needed 
% to produce Tables E.3 and E.4 in the Online Appendix
if design_n == 12 || design_n == 13

RY_fL_hat  = zeros(N_L_sim, 1);     RX_fH_hat  = zeros(N_H_sim, 1);
RY_fL_sim  = zeros(N_L_sim, 1);     RX_fH_sim  = zeros(N_H_sim, 1);
RY_fLC_hat = zeros(N_L_sim, 1);     RX_fHC_hat = zeros(N_H_sim, 1);
RY_fLC_sim = zeros(N_L_sim, 1);     RX_fHC_sim = zeros(N_H_sim, 1);
RY_fC_hat  = zeros(N_L_sim, 1);     RX_fC_hat  = zeros(N_H_sim, 1);
RY_fC_sim  = zeros(N_L_sim, 1);     RX_fC_sim  = zeros(N_H_sim, 1);

X_sim_st = zscore(X_sim   ); % standardize data
Y_sim_st = zscore(Y_sim_fl); % standardize data

% ESTIMATE FACTORS, taking number of common factors toestimate as input
kChat_savef  = 1       ;
[~,~,~,~,~,...
 FC_hat, FH_hat, FL_hat] = Estimation_nfac_and_factors_EMPIRICAL(X_sim_st, Y_sim_st, aggregation_first_ind, K_gH, K_gL, '1', c, gamma, kChat_savef);
%--------------------------------------------------------------------------
% 'Unstack' estimated factors: from 1 HF panel --> 4 LF panels
FC_hat_unstacked  = Stack_HF_LF_m_superiods(FC_hat,m);
FC1_hat           = FC_hat_unstacked(:,:,1) ; 
FC2_hat           = FC_hat_unstacked(:,:,2) ;
FC3_hat           = FC_hat_unstacked(:,:,3) ;
FC4_hat           = FC_hat_unstacked(:,:,4) ;

FC_hat_unstacked = []; % clean memory
whichstats = {'adjrsquare'}   ; % regression output to save
% Y : LF OBSERVABLES ------------------------------------------------------
for i = 1:N_L_sim
    % LF Factors
    reg = regstats(Y_sim_st(:,i),[FL_hat],'linear',whichstats);
    RY_fL_hat(i,1)   = reg.adjrsquare*100; 
    reg = regstats(Y_sim_st(:,i),[FL_sim_fl],'linear',whichstats);
    RY_fL_sim(i,1)   = reg.adjrsquare*100; 
    % LF Factors and COM factor  (sum of values over the LF period)
    reg = regstats(Y_sim_st(:,i),[(FC1_hat+FC2_hat+FC3_hat+FC4_hat) FL_hat ],'linear',whichstats);
    RY_fLC_hat(i,1)  = reg.adjrsquare*100; 
    reg = regstats(Y_sim_st(:,i),[FC_sim_fl FL_sim_fl ],'linear',whichstats);
    RY_fLC_sim(i,1)  = reg.adjrsquare*100;
    % COM Factor (sum of values over the LF period)
    reg = regstats(Y_sim_st(:,i),[(FC1_hat+FC2_hat+FC3_hat+FC4_hat)],'linear',whichstats);
    RY_fC_hat(i,1)   = reg.adjrsquare*100;
    reg = regstats(Y_sim_st(:,i),[FC_sim_fl],'linear',whichstats);
    RY_fC_sim(i,1)   = reg.adjrsquare*100;
end
% HF OBSERVABLES ----------------------------------------------------------
for i = 1:N_H_sim
    % on Common factors
    reg = regstats(X_sim_st(:,i),[FC_hat],'linear',whichstats);
    RX_fC_hat(i,1)   = reg.adjrsquare*100;
    reg = regstats(X_sim_st(:,i),[FC_sim],'linear',whichstats);
    RX_fC_sim(i,1)   = reg.adjrsquare*100;
    % COM and HF factors
    reg = regstats(X_sim_st(:,i),[FC_hat FH_hat],'linear',whichstats);
    RX_fHC_hat(i,1)  = reg.adjrsquare*100; 
    reg = regstats(X_sim_st(:,i),[FC_sim FH_sim],'linear',whichstats);
    RX_fHC_sim(i,1)  = reg.adjrsquare*100;
    % HF factor
    reg = regstats(X_sim_st(:,i),[FH_hat],'linear',whichstats);
    RX_fH_hat(i,1)  = reg.adjrsquare*100;    
    reg = regstats(X_sim_st(:,i),[FH_sim],'linear',whichstats);
    RX_fH_sim(i,1)  = reg.adjrsquare*100; 
end 
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% Computes Quantiles of adj. R^2 to show in Tables E.3 and E.4
q2show = [0.10 0.25 0.50 0.75 0.90] ; % quantiles to compute and to show

%RY_fL_quant_hat(i_sim,:)  = quantile(RY_fL_hat , q2show(1,1:5));

RY_fL_quant_hat(i_sim,:)  = quantile(RY_fL_hat , q2show(1,1:5));
RY_fLC_quant_hat(i_sim,:) = quantile(RY_fLC_hat, q2show(1,1:5)); 
RY_fC_quant_hat(i_sim,:)  = quantile(RY_fC_hat , q2show(1,1:5)); 
RX_fH_quant_hat(i_sim,:)  = quantile(RX_fH_hat , q2show(1,1:5)); 
RX_fHC_quant_hat(i_sim,:) = quantile(RX_fHC_hat, q2show(1,1:5)); 
RX_fC_quant_hat(i_sim,:)  = quantile(RX_fC_hat , q2show(1,1:5)); 

RY_fL_quant_sim(i_sim,:)  = quantile(RY_fL_sim , q2show(1,1:5)); 
RY_fLC_quant_sim(i_sim,:) = quantile(RY_fLC_sim, q2show(1,1:5)); 
RY_fC_quant_sim(i_sim,:)  = quantile(RY_fC_sim , q2show(1,1:5)); 
RX_fH_quant_sim(i_sim,:)  = quantile(RX_fH_sim , q2show(1,1:5)); 
RX_fHC_quant_sim(i_sim,:) = quantile(RX_fHC_sim, q2show(1,1:5)); 
RX_fC_quant_sim(i_sim,:)  = quantile(RX_fC_sim , q2show(1,1:5));
end
%##########################################################################
%##########################################################################
%##########################################################################
%##########################################################################
%##########################################################################
%##########################################################################
%##########################################################################
%##########################################################################
%##########################################################################
% Table to store all simulated adj. R^2 needed 
% to produce Tables E.5 and E.6 in the Online Appendix
if design_n == 14 || design_n == 15

RY_fL_hat111     = zeros(N_L_sim, 1);     
RY_fLC_hat111    = zeros(N_L_sim, 1);     
RY_fC_hat111     = zeros(N_L_sim, 1);     
RX_fH_hat111     = zeros(N_H_sim, 1);
RX_fHC_hat111    = zeros(N_H_sim, 1);
RX_fC_hat111     = zeros(N_H_sim, 1);

RY_fC_hat200     = zeros(N_L_sim, 1); 
RX_fC_hat200     = zeros(N_H_sim, 1); 

adjRY_fL_hat111  = zeros(N_L_sim, 1);     
adjRY_fLC_hat111 = zeros(N_L_sim, 1);     
adjRY_fC_hat111  = zeros(N_L_sim, 1);     
adjRX_fH_hat111  = zeros(N_H_sim, 1);
adjRX_fHC_hat111 = zeros(N_H_sim, 1);
adjRX_fC_hat111  = zeros(N_H_sim, 1);

adjRY_fC_hat200  = zeros(N_L_sim, 1); 
adjRX_fC_hat200  = zeros(N_H_sim, 1); 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
X_sim_st = zscore(X_sim   ); % standardize data
Y_sim_st = zscore(Y_sim_fl); % standardize data

% ESTIMATE FACTORS, taking number of common factors to estimate as input
kChat_savef  = 1       ;
[~,~,~,~,~,...
 FC_hat, FH_hat, FL_hat] = Estimation_nfac_and_factors_EMPIRICAL(X_sim_st, Y_sim_st, aggregation_first_ind, K_gH, K_gL, '1', c, gamma, kChat_savef);

% ESTIMATE FACTORS, taking number of common factors to estimate as input
kChat_savef  = 2       ;
[~,~,~,~,~,...
 FC_hat200, FH_hat200, FL_hat200] = Estimation_nfac_and_factors_EMPIRICAL(X_sim_st, Y_sim_st, aggregation_first_ind, K_gH, K_gL, '1', c, gamma, kChat_savef);
%--------------------------------------------------------------------------
% 'Unstack' estimated factors: from 1 HF panel --> 4 LF panels
FC_hat_unstacked     = Stack_HF_LF_m_superiods(FC_hat,m)    ;
FC1_hat              = FC_hat_unstacked(:,:,1)              ; 
FC2_hat              = FC_hat_unstacked(:,:,2)              ;
FC3_hat              = FC_hat_unstacked(:,:,3)              ;
FC4_hat              = FC_hat_unstacked(:,:,4)              ;

FC_hat_unstacked200  = Stack_HF_LF_m_superiods(FC_hat200,m) ;
FC1_hat200           = FC_hat_unstacked200(:,:,1)           ; 
FC2_hat200           = FC_hat_unstacked200(:,:,2)           ;
FC3_hat200           = FC_hat_unstacked200(:,:,3)           ;
FC4_hat200           = FC_hat_unstacked200(:,:,4)           ;

FC_hat_unstacked = []; FC_hat_unstacked200 = []; % clean memory
whichstats = {'adjrsquare','rsquare'}   ; % regression output to save
% Y : LF OBSERVABLES ------------------------------------------------------
for i = 1:N_L_sim
    % LF Factors
    reg = regstats(Y_sim_st(:,i),[FL_hat],'linear',whichstats);
    adjRY_fL_hat111(i,1)   = reg.adjrsquare*100;
       RY_fL_hat111(i,1)   = reg.rsquare*100; 
    % LF Factors and COM factor  (sum of values over the LF period)
    reg = regstats(Y_sim_st(:,i),[(FC1_hat+FC2_hat+FC3_hat+FC4_hat) FL_hat ],'linear',whichstats);
    adjRY_fLC_hat111(i,1)  = reg.adjrsquare*100;
       RY_fLC_hat111(i,1)  = reg.rsquare*100; 
    % COM Factor (sum of values over the LF period)
    reg = regstats(Y_sim_st(:,i),[(FC1_hat+FC2_hat+FC3_hat+FC4_hat)],'linear',whichstats);
    adjRY_fC_hat111(i,1)   = reg.adjrsquare*100;
       RY_fC_hat111(i,1)   = reg.rsquare*100;
    % COM Factor (sum of values over the LF period)
    reg200 = regstats(Y_sim_st(:,i),[(FC1_hat200+FC2_hat200+FC3_hat200+FC4_hat200)],'linear',whichstats);
    adjRY_fC_hat200(i,1)   = reg200.adjrsquare*100;
       RY_fC_hat200(i,1)   = reg200.rsquare*100;   
end
% HF OBSERVABLES ----------------------------------------------------------
for i = 1:N_H_sim
    % on Common factors
    reg = regstats(X_sim_st(:,i),[FC_hat],'linear',whichstats);
    adjRX_fC_hat111(i,1)   = reg.adjrsquare*100;
       RX_fC_hat111(i,1)   = reg.rsquare*100;
    % on Common factors
    reg200 = regstats(X_sim_st(:,i),[FC_hat200],'linear',whichstats);
    adjRX_fC_hat200(i,1)   = reg200.adjrsquare*100;
       RX_fC_hat200(i,1)   = reg200.rsquare*100;   
    % COM and HF factors
    reg = regstats(X_sim_st(:,i),[FC_hat FH_hat],'linear',whichstats);
    adjRX_fHC_hat111(i,1)  = reg.adjrsquare*100; 
       RX_fHC_hat111(i,1)  = reg.rsquare*100; 
    % HF factor
    reg = regstats(X_sim_st(:,i),[FH_hat],'linear',whichstats);
    adjRX_fH_hat111(i,1)  = reg.adjrsquare*100;    
       RX_fH_hat111(i,1)  = reg.rsquare*100;    
end 
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% Computes Quantiles of adj. R^2 to show in Tables E.3 and E.4
q2show = [0.10 0.25 0.50 0.75 0.90] ; % quantiles to compute and to show

% RY_fL_quant_hat(i_sim,1:5)  = quantile(RY_fL_hat , q2show(1,1:5));

% R^2    
RY_fL_quant_hat111(i_sim,:)  = quantile(RY_fL_hat111 , q2show(1,1:5));
RY_fLC_quant_hat111(i_sim,:) = quantile(RY_fLC_hat111, q2show(1,1:5)); 
RY_fC_quant_hat111(i_sim,:)  = quantile(RY_fC_hat111 , q2show(1,1:5)); 
RX_fH_quant_hat111(i_sim,:)  = quantile(RX_fH_hat111 , q2show(1,1:5)); 
RX_fHC_quant_hat111(i_sim,:) = quantile(RX_fHC_hat111, q2show(1,1:5)); 
RX_fC_quant_hat111(i_sim,:)  = quantile(RX_fC_hat111 , q2show(1,1:5)); 

RY_fC_quant_hat200(i_sim,:)  = quantile(RY_fC_hat200 , q2show(1,1:5)); 
RX_fC_quant_hat200(i_sim,:)  = quantile(RX_fC_hat200 , q2show(1,1:5)); 

%adj. R^2
adjRY_fL_quant_hat111(i_sim,:)  = quantile(adjRY_fL_hat111 , q2show(1,1:5));
adjRY_fLC_quant_hat111(i_sim,:) = quantile(adjRY_fLC_hat111, q2show(1,1:5)); 
adjRY_fC_quant_hat111(i_sim,:)  = quantile(adjRY_fC_hat111 , q2show(1,1:5)); 
adjRX_fH_quant_hat111(i_sim,:)  = quantile(adjRX_fH_hat111 , q2show(1,1:5)); 
adjRX_fHC_quant_hat111(i_sim,:) = quantile(adjRX_fHC_hat111, q2show(1,1:5)); 
adjRX_fC_quant_hat111(i_sim,:)  = quantile(adjRX_fC_hat111 , q2show(1,1:5)); 

adjRY_fC_quant_hat200(i_sim,:)  = quantile(adjRY_fC_hat200 , q2show(1,1:5)); 
adjRX_fC_quant_hat200(i_sim,:)  = quantile(adjRX_fC_hat200 , q2show(1,1:5)); 

end
%##########################################################################
%##########################################################################
%##########################################################################
%##########################################################################
%##########################################################################
%##########################################################################
end  % 'for' of  'parfor' loop ends here
%##########################################################################
%##########################################################################
%##########################################################################
%##########################################################################
%##########################################################################
%##########################################################################
% SUMMARY OF OUTPUT to print in latex: CONSISTENT ESTIMATOR
% Sample sizes
summ_final_cons_stHhf               = zeros(1,6)             ;
summ_final_cons_stLhf               = zeros(1,6)             ;
summ_final_cons_st_k12esthf         = zeros(1,12)            ;
summ_final_cons_st_k12truehf        = zeros(1,12)            ;

summ_final_cons_stHhf(1,1:3)        = [N_H_sim N_L_sim T_sim];

summ_final_cons_stLhf(1,1:3)        = [N_H_sim N_L_sim T_sim];
summ_final_cons_st_k12esthf(1,1:3)  = [N_H_sim N_L_sim T_sim];
summ_final_cons_st_k12truehf(1,1:3) = [N_H_sim N_L_sim T_sim];

% mean number of estimated factors
% cc
summ_final_cons_stHhf(1,4:6)        = mean(mat_summary_all_HF(:,1:3))     ;
summ_final_cons_stLhf(1,4:6)        = mean(mat_summary_all_LF(:,1:3))     ;
summ_final_cons_st_k12esthf(1,4:6)  = mean(mat_summary_all_stH_k12(:,1:3));
summ_final_cons_st_k12esthf(1,7:9)  = mean(mat_summary_all_stL_k12(:,1:3));
summ_final_cons_st_k12truehf(1,4:6) = mean(mat_summary_all_HF(:,1:3))     ;
summ_final_cons_st_k12truehf(1,7:9) = mean(mat_summary_all_LF(:,1:3))     ;

% CHEN (2010)
summ_final_cons_st_k12esthf(1,10:12)  = mean(mat_summary_all_CHEN_k12est(:,1:3)) ; 
summ_final_cons_st_k12truehf(1,10:12) = mean(mat_summary_all_CHEN_k12true(:,1:3)); 

% WANG (WANG)
k_est_WANG_mean  = mean(k_est_WANG) ;
k_true_WANG_mean = mean(k_true_WANG);

%##########################################################################
% SIZE / POWER

% recall
% mat_summary_all:  contains estimated n. of factors using AGGR, 
% and values of test stat for all sequential tests
%##########################################################################
% alpha_size_vec % row vector
n_alphas = size(alpha_size_vec,2);
summ_final_size_power_LF        = ones(1,2*n_alphas)*999;
summ_final_size_power_unf_LF    = ones(1,2*n_alphas)*999;
summ_final_size_power_HF        = ones(1,2*n_alphas)*999;
summ_final_size_power_unf_HF    = ones(1,2*n_alphas)*999;
%--------------------------------------------------------------------------
% FEASIBLE  
for ia = 1:n_alphas
% SIZE
%--------------------------------------------------------------------------
if KC_sim~=0
ind_size_temp = ( mat_summary_all_LF(:,3+k_min_sim-KC_sim+1) < norminv(alpha_size_vec(1,ia)) ) ;
summ_final_size_power_LF(1,ia) = sum(ind_size_temp)/n_sim  ;  
ind_size_temp = [];
%--------------------------------------------------------------------------
ind_size_temp = ( mat_summary_all_HF(:,3+k_min_sim-KC_sim+1) < norminv(alpha_size_vec(1,ia)) ) ;
summ_final_size_power_HF(1,ia) = sum(ind_size_temp)/n_sim  ; 
ind_size_temp = [];
%--------------------------------------------------------------------------
else
ind_size_temp = ( mat_summary_all_LF(:,3+k_min_sim-KC_sim) < norminv(alpha_size_vec(1,ia)) ) ;
summ_final_size_power_LF(1,ia) = sum(ind_size_temp)/n_sim  ;  
ind_size_temp = [];
%--------------------------------------------------------------------------
ind_size_temp = ( mat_summary_all_HF(:,3+k_min_sim-KC_sim) < norminv(alpha_size_vec(1,ia)) ) ;
summ_final_size_power_HF(1,ia) = sum(ind_size_temp)/n_sim  ; 
ind_size_temp = []; 
%--------------------------------------------------------------------------
end
%--------------------------------------------------------------------------
% POWER 
if KH_sim~=0
ind_power_temp = ( mat_summary_all_LF(:,3+k_min_sim-KC_sim) < norminv(alpha_size_vec(1,ia)));
summ_final_size_power_LF(1,n_alphas + ia) = sum(ind_power_temp)/n_sim  ; 
ind_power_temp = []; 
%--------------------------------------------------------------------------
ind_power_temp = ( mat_summary_all_HF(:,3+k_min_sim-KC_sim) < norminv(alpha_size_vec(1,ia)));
summ_final_size_power_HF(1,n_alphas + ia) = sum(ind_power_temp)/n_sim  ; 
ind_power_temp = []; 
%--------------------------------------------------------------------------
else
summ_final_size_power_LF(1,n_alphas + ia) = NaN ;
%--------------------------------------------------------------------------
summ_final_size_power_HF(1,n_alphas + ia) = NaN ;
end
%end
%--------------------------------------------------------------------------
% UNFEASIBLE TEST STATISTICS
% SIZE 
ind_size_temp_unf = ( mat_summary_all_UNF_LF(:,1) < norminv(alpha_size_vec(1,ia)) );
summ_final_size_power_unf_LF(1,ia) = sum(ind_size_temp_unf)/n_sim  ;   
ind_size_temp_unf = [];  
%--------------------------------------------------------------------------
ind_size_temp_unf = ( mat_summary_all_UNF_HF(:,1) < norminv(alpha_size_vec(1,ia)) );
summ_final_size_power_unf_HF(1,ia) = sum(ind_size_temp_unf)/n_sim  ; 
ind_size_temp_unf = [];
%--------------------------------------------------------------------------
end
%--------------------------------------------------------------------------
% Create tables for plots/ histograms of test stat.
% recall the order of elements in the original tables
%--------------------------------------------------------------------------
% cc_test_mat(tab_ind,:) = 
% [kc_temp, stat_cc, sum_cc_temp,...
%  (1/(2*N))*trace(Sigma_U_hat),...
%  (1/(N*sqrt(T)))*( (0.5*trace(Sigma_U_hat*Sigma_U_hat))^(0.5) )  ] ;  
%--------------------------------------------------------------------------
% FEASIBLE
% mat_summary_all(i_sim,:)       = cc_test_mat_summary_cons;
% mat_summary_all_sumcc(i_sim,:) = cc_test_mat_all_cons(:,3)' ;
% mat_summary_all_bias(i_sim,:)  = cc_test_mat_all_cons(:,4)' ;
% mat_summary_all_std(i_sim,:)   = cc_test_mat_all_cons(:,5)' ;
% 
% % UNFEASIBLE
% mat_summary_all_UNF(i_sim,:)       = cc_test_mat_all_unf(1,2);
% mat_summary_all_sumcc_UNF(i_sim,:) = cc_test_mat_all_unf(1,3);
% mat_summary_all_bias_UNF(i_sim,:)  = cc_test_mat_all_unf(1,4);
% mat_summary_all_std_UNF(i_sim,:)   = cc_test_mat_all_unf(1,5);
%--------------------------------------------------------------------------
if KC_sim ~=0
ind_th0 = k_min_sim-KC_sim+1 ;
else
ind_th0 = k_min_sim-KC_sim ;
end
%--------------------------------------------------------------------------                 
tab_dist_stat_h0_stLhf =  [ repmat(KC_sim,n_sim,1),repmat(m,n_sim,1),...
                     mat_summary_all_LF(:,3+ind_th0),...
                     mat_summary_all_sumcc_LF(:,ind_th0),...
                     mat_summary_all_bias_LF(:,ind_th0),...
                     mat_summary_all_std_LF(:,ind_th0),...
                     (2*N)*mat_summary_all_bias_LF(:,ind_th0),...
                     (N*sqrt(T))*mat_summary_all_std_LF(:,ind_th0)];
%--------------------------------------------------------------------------                 
tab_dist_stat_h0_stHhf =  [ repmat(KC_sim,n_sim,1),repmat(m,n_sim,1),...
                     mat_summary_all_HF(:,3+ind_th0),...
                     mat_summary_all_sumcc_HF(:,ind_th0),...
                     mat_summary_all_bias_HF(:,ind_th0),...
                     mat_summary_all_std_HF(:,ind_th0),...
                     (2*N)*mat_summary_all_bias_HF(:,ind_th0),...
                     (N*sqrt(T))*mat_summary_all_std_HF(:,ind_th0)];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                                
tab_dist_stat_h0_unf_stLhf = [repmat(KC_sim,n_sim,1),repmat(m,n_sim,1),...
                     mat_summary_all_UNF_LF(:,1),...
                     mat_summary_all_sumcc_UNF_LF(:,1),...
                     mat_summary_all_bias_UNF_LF(:,1),...
                     mat_summary_all_std_UNF_LF(:,1),...
                     (2*N)*mat_summary_all_bias_UNF_LF(:,1),...
                     (N*sqrt(T))*mat_summary_all_std_UNF_LF(:,1)];
%--------------------------------------------------------------------------                 
tab_dist_stat_h0_unf_stHhf = [repmat(KC_sim,n_sim,1),repmat(m,n_sim,1),...
                     mat_summary_all_UNF_HF(:,1),...
                     mat_summary_all_sumcc_UNF_HF(:,1),...
                     mat_summary_all_bias_UNF_HF(:,1),...
                     mat_summary_all_std_UNF_HF(:,1),...
                     (2*N)*mat_summary_all_bias_UNF_HF(:,1),...
                     (N*sqrt(T))*mat_summary_all_std_UNF_HF(:,1)];  
%##########################################################################
%% OUTPUT
%##########################################################################
% TEST for the number of common factors based on the canonical correlation
% test, when HF data are first aggregated, and then PCA is computed on
% LF aggregated data:

% SIZE AND POWER in final TABLE line

line_sim_tab_SizePower_AGGfirst = [summ_final_cons_stLhf(1,1:3),... % N_H, N_L, T
summ_final_size_power_unf_LF(1,1:n_alphas),...                   % INFEASIBLE TEST STATISTICS: empirical size , corresponding to nominal size: 0.01, 0.05, 0.10
summ_final_size_power_LF(1,1:n_alphas),...                       %   FEASIBLE TEST STATISTICS: empirical size , corresponding to nominal size: 0.01, 0.05, 0.10
summ_final_size_power_LF(1,(n_alphas+1):(2*n_alphas))]  ;        %   FEASIBLE TEST STATISTICS: empirical POWER, corresponding to nominal size: 0.01, 0.05, 0.10
%##########################################################################

% TEST for the number of common factors based on the canonical correlation
% test, PCA is computed on HF data, and then PCs are aggregated at LF  

% SIZE AND POWER in final TABLE line

line_sim_tab_SizePower_PCAfirst = [summ_final_cons_stHhf(1,1:3),... % N_H, N_L, T
summ_final_size_power_unf_HF(1,1:n_alphas),...                   % INFEASIBLE TEST STATISTICS: empirical size , corresponding to nominal size: 0.01, 0.05, 0.10
summ_final_size_power_HF(1,1:n_alphas),...                       %   FEASIBLE TEST STATISTICS: empirical size , corresponding to nominal size: 0.01, 0.05, 0.10
summ_final_size_power_HF(1,(n_alphas+1):(2*n_alphas))]  ;        %   FEASIBLE TEST STATISTICS: empirical POWER, corresponding to nominal size: 0.01, 0.05, 0.10

%##########################################################################
%##########################################################################
%##########################################################################
%##########################################################################
%##########################################################################
% TABLES CONTAINING THE NUMBER OF ESTIMATED estimated COMMON and SPECIFIC
% FACTORS , obtianed from:
% - the (feasible) canonical corr. tests (PCA performed on HF data, and then the PCs are aggregated at LF)
% - the (feasible) canonical corr. tests (HF data are first aggregated at LF, and then PCs are computed on aggregated data)
% - Chen (2012)
% - Wang (2012)

%##########################################################################
% n. of common factors is estimated using the ESTIMATED values of 
% k_1 and k_2 (Estimated using Bai and Ng IC_p information criteria)

% average numbers of estimated  k^c, k^H and k^L are reported 
% averages are computed across all MC simulations
line_sim_tab_Num_Factors_ESTIMATEDk1k2 = [summ_final_cons_st_k12esthf,  k_est_WANG_mean]  ; 

%##########################################################################
% n. of common factors is estimated using the TRUE (from DGP) values k_1 and k_2

% average numbers of estimated  k^c, k^H and k^L are reported 
% averages are computed across all MC simulations
line_sim_tab_Num_Factors_TRUEk1k2      = [summ_final_cons_st_k12truehf, k_true_WANG_mean] ; 

%##########################################################################
%##########################################################################
%##########################################################################
% SAVE .mat file with summary of tests for each simulation
file_name_mat = sprintf('%s_%d%d%d_%d_%d_%d_%d_%d_%s%d_%d_%d_%d_%s%d%s',...
                       'SIZEhist_mtab_rev1_v1', KC_sim, KH_sim, KL_sim,...
                       round(beta*10), round(a_e*10), round(R_Hall_max*10), round(a_fac*10), round(phi*100),...
                       'nsim', n_sim,...
                       N_H, N_L, T, 'm', m, '.mat') ;
%--------------------------------------------------------------------------
save(fullfile(savdir_mat,file_name_mat),...
     'sim_input',...
     'summ_final_cons_stHhf',...
     'summ_final_cons_stLhf',...
     'summ_final_cons_st_k12esthf',...
     'summ_final_cons_st_k12truehf',...
     'k_est_WANG',...
     'k_true_WANG',...
     'K_gHL_est_mat',...
     'mat_summary_all_HF',...
     'line_sim_tab_SizePower_AGGfirst', ...
     'line_sim_tab_SizePower_PCAfirst',...
     'tab_dist_stat_h0_stLhf',...
     'tab_dist_stat_h0_stHhf',...
     'tab_dist_stat_h0_unf_stLhf',...
     'tab_dist_stat_h0_unf_stHhf',...
     'summ_final_size_power_LF',...
     'summ_final_size_power_HF',...
     'summ_final_size_power_unf_LF',...
     'summ_final_size_power_unf_HF')
%##########################################################################
%##########################################################################
%##########################################################################
% END of generation of Tables of results for designs 1 - 11 ###############
%##########################################################################
%##########################################################################
%##########################################################################

%##########################################################################
%##########################################################################
%##########################################################################
% START generating Tables E.3 and E.4 in ONLINE APPENDIX ##################
%##########################################################################
%##########################################################################
%##########################################################################

% Produce Tables E.3 and E.4 in the Online Appendix
if design_n == 12 || design_n == 13

% Computes averages across simulations of quantiles of adj. R^2 to show in 
% Tables E.3 and E.4

RY_TRUEfC_mean  = mean(RY_fC_quant_sim) ; 
RY_TRUEfLC_mean = mean(RY_fLC_quant_sim);
RY_TRUEfL_mean  = mean(RY_fL_quant_sim) ; 
RX_TRUEfC_mean  = mean(RX_fC_quant_sim) ;
RX_TRUEfHC_mean = mean(RX_fHC_quant_sim);
RX_TRUEfH_mean  = mean(RX_fH_quant_sim) ;

RY_ESTfC_mean  = mean(RY_fC_quant_hat) ; 
RY_ESTfLC_mean = mean(RY_fLC_quant_hat);
RY_ESTfL_mean  = mean(RY_fL_quant_hat) ; 
RX_ESTfC_mean  = mean(RX_fC_quant_hat) ;
RX_ESTfHC_mean = mean(RX_fHC_quant_hat);
RX_ESTfH_mean  = mean(RX_fH_quant_hat) ;
%--------------------------------------------------------------------------   
disp(' '); disp(' ');
disp('###################################################################')  
if design_n == 12;  % Table E.3 
disp('Table E.3: R^2 quantiles, latex format    ');
disp('                                          ');
disp('PANEL A : R^2_max = 0.8 , TRUE factors');
elseif design_n == 13;  % Table E.4 
disp('Table E.4: R^2 quantiles, latex format    ');
disp('                                          ');
disp('PANEL A : R^2_max = 0.6 , TRUE factors');
end
disp('=================================================================')
disp(['Factors                         R^2 quantiles            '])
disp(['Factors                10%    25%   50%    75%     90%   '])
disp('-----------------------------------------------------------------') 
disp('Observables: LF variables')
disp(['common             ',...
      ' & ', num2str(RY_TRUEfC_mean(1,1), '%.1f'), ...
      ' & ', num2str(RY_TRUEfC_mean(1,2), '%.1f'), ...
      ' & ', num2str(RY_TRUEfC_mean(1,3), '%.1f'), ...
      ' & ', num2str(RY_TRUEfC_mean(1,4), '%.1f'), ...
      ' & ', num2str(RY_TRUEfC_mean(1,5), '%.1f'),'\\']) 
disp(['common, LF-specific',...
      ' & ', num2str(RY_TRUEfLC_mean(1,1), '%.1f'), ...
      ' & ', num2str(RY_TRUEfLC_mean(1,2), '%.1f'), ...
      ' & ', num2str(RY_TRUEfLC_mean(1,3), '%.1f'), ...
      ' & ', num2str(RY_TRUEfLC_mean(1,4), '%.1f'), ...
      ' & ', num2str(RY_TRUEfLC_mean(1,5), '%.1f'),'\\'])
disp(['LF-Specific        ',...
      ' & ', num2str(RY_TRUEfL_mean(1,1), '%.1f'), ...
      ' & ', num2str(RY_TRUEfL_mean(1,2), '%.1f'), ...
      ' & ', num2str(RY_TRUEfL_mean(1,3), '%.1f'), ...
      ' & ', num2str(RY_TRUEfL_mean(1,4), '%.1f'), ...
      ' & ', num2str(RY_TRUEfL_mean(1,5), '%.1f'),'\\'])
disp(['\midrule']) 
disp('Observables: HF variables')
disp(['common             ',...
      ' & ', num2str(RX_TRUEfC_mean(1,1), '%.1f'), ...
      ' & ', num2str(RX_TRUEfC_mean(1,2), '%.1f'), ...
      ' & ', num2str(RX_TRUEfC_mean(1,3), '%.1f'), ...
      ' & ', num2str(RX_TRUEfC_mean(1,4), '%.1f'), ...
      ' & ', num2str(RX_TRUEfC_mean(1,5), '%.1f'),'\\']) 
disp(['common, HF-specific',...
      ' & ', num2str(RX_TRUEfHC_mean(1,1), '%.1f'), ...
      ' & ', num2str(RX_TRUEfHC_mean(1,2), '%.1f'), ...
      ' & ', num2str(RX_TRUEfHC_mean(1,3), '%.1f'), ...
      ' & ', num2str(RX_TRUEfHC_mean(1,4), '%.1f'), ...
      ' & ', num2str(RX_TRUEfHC_mean(1,5), '%.1f'),'\\'])
disp(['HF-Specific        ',...
      ' & ', num2str(RX_TRUEfH_mean(1,1), '%.1f'), ...
      ' & ', num2str(RX_TRUEfH_mean(1,2), '%.1f'), ...
      ' & ', num2str(RX_TRUEfH_mean(1,3), '%.1f'), ...
      ' & ', num2str(RX_TRUEfH_mean(1,4), '%.1f'), ...
      ' & ', num2str(RX_TRUEfH_mean(1,5), '%.1f'),'\\']) 
disp('-----------------------------------------------------------------') 
disp(' '); disp(' ');
disp('###################################################################')  
if design_n == 12;  % Table E.3 
disp('Table E.3: R^2 quantiles, latex format    ');
disp('                                          ');
disp('PANEL B : R^2_max = 0.8 , ESTIMATED factors');
elseif design_n == 13;  % Table E.4 
disp('Table E.4: R^2 quantiles, latex format    ');
disp('                                          ');
disp('PANEL B: R^2_max = 0.6 , ESTIMATED factors');
end
disp('=================================================================')
disp(['Factors                         R^2 quantiles            '])
disp(['Factors                10%    25%   50%    75%     90%   '])
disp('-----------------------------------------------------------------') 
disp('Observables: LF variables')
disp(['common             ',...
      ' & ', num2str(RY_ESTfC_mean(1,1), '%.1f'), ...
      ' & ', num2str(RY_ESTfC_mean(1,2), '%.1f'), ...
      ' & ', num2str(RY_ESTfC_mean(1,3), '%.1f'), ...
      ' & ', num2str(RY_ESTfC_mean(1,4), '%.1f'), ...
      ' & ', num2str(RY_ESTfC_mean(1,5), '%.1f'),'\\']) 
disp(['common, LF-specific',...
      ' & ', num2str(RY_ESTfLC_mean(1,1), '%.1f'), ...
      ' & ', num2str(RY_ESTfLC_mean(1,2), '%.1f'), ...
      ' & ', num2str(RY_ESTfLC_mean(1,3), '%.1f'), ...
      ' & ', num2str(RY_ESTfLC_mean(1,4), '%.1f'), ...
      ' & ', num2str(RY_ESTfLC_mean(1,5), '%.1f'),'\\'])
disp(['LF-Specific        ',...
      ' & ', num2str(RY_ESTfL_mean(1,1), '%.1f'), ...
      ' & ', num2str(RY_ESTfL_mean(1,2), '%.1f'), ...
      ' & ', num2str(RY_ESTfL_mean(1,3), '%.1f'), ...
      ' & ', num2str(RY_ESTfL_mean(1,4), '%.1f'), ...
      ' & ', num2str(RY_ESTfL_mean(1,5), '%.1f'),'\\'])
disp(['\midrule']) 
disp('Observables: HF variables')
disp(['common             ',...
      ' & ', num2str(RX_ESTfC_mean(1,1), '%.1f'), ...
      ' & ', num2str(RX_ESTfC_mean(1,2), '%.1f'), ...
      ' & ', num2str(RX_ESTfC_mean(1,3), '%.1f'), ...
      ' & ', num2str(RX_ESTfC_mean(1,4), '%.1f'), ...
      ' & ', num2str(RX_ESTfC_mean(1,5), '%.1f'),'\\']) 
disp(['common, HF-specific',...
      ' & ', num2str(RX_ESTfHC_mean(1,1), '%.1f'), ...
      ' & ', num2str(RX_ESTfHC_mean(1,2), '%.1f'), ...
      ' & ', num2str(RX_ESTfHC_mean(1,3), '%.1f'), ...
      ' & ', num2str(RX_ESTfHC_mean(1,4), '%.1f'), ...
      ' & ', num2str(RX_ESTfHC_mean(1,5), '%.1f'),'\\'])
disp(['HF-Specific        ',...
      ' & ', num2str(RX_ESTfH_mean(1,1), '%.1f'), ...
      ' & ', num2str(RX_ESTfH_mean(1,2), '%.1f'), ...
      ' & ', num2str(RX_ESTfH_mean(1,3), '%.1f'), ...
      ' & ', num2str(RX_ESTfH_mean(1,4), '%.1f'), ...
      ' & ', num2str(RX_ESTfH_mean(1,5), '%.1f'),'\\']) 
disp('###################################################################')  
end
%##########################################################################
%##########################################################################
%##########################################################################
% END of generation of Tables E.3 and E.4 in ONLINE APPENDIX ##############
%##########################################################################
%##########################################################################
%##########################################################################

%##########################################################################
%##########################################################################
% START generating Tables E.5 and E.6 in ONLINE APPENDIX ##################
%##########################################################################
%##########################################################################

% Produce Tables E.5 and E.6 in the Online Appendix
if design_n == 14 || design_n == 15

% Computes averages across simulations of quantiles of adj. R^2 to show in 
% Tables E.6 and E.6

RY_ESTfC_mean111  = mean(RY_fC_quant_hat111) ; 
RY_ESTfLC_mean111 = mean(RY_fLC_quant_hat111);
RY_ESTfL_mean111  = mean(RY_fL_quant_hat111) ; 
RX_ESTfC_mean111  = mean(RX_fC_quant_hat111) ;
RX_ESTfHC_mean111 = mean(RX_fHC_quant_hat111);
RX_ESTfH_mean111  = mean(RX_fH_quant_hat111) ;

RY_ESTfC_mean200  = mean(RY_fC_quant_hat200) ;
RX_ESTfC_mean200  = mean(RX_fC_quant_hat200) ;


adjRY_ESTfC_mean111  = mean(adjRY_fC_quant_hat111) ; 
adjRY_ESTfLC_mean111 = mean(adjRY_fLC_quant_hat111);
adjRY_ESTfL_mean111  = mean(adjRY_fL_quant_hat111) ; 
adjRX_ESTfC_mean111  = mean(adjRX_fC_quant_hat111) ;
adjRX_ESTfHC_mean111 = mean(adjRX_fHC_quant_hat111);
adjRX_ESTfH_mean111  = mean(adjRX_fH_quant_hat111) ;

adjRY_ESTfC_mean200  = mean(adjRY_fC_quant_hat200) ; 
adjRX_ESTfC_mean200  = mean(adjRX_fC_quant_hat200) ;

disp(' '); disp(' ');
disp('###################################################################')  
if design_n == 14;  % Table E.5 
disp('Table E.5: R^2 quantiles, latex format               ');
disp('                                                     ');
disp('PANEL A : Estimated with k^C = k^H=k^L = 1, phi = 0.7');
elseif design_n == 15;  % Table E.6 
disp('Table E.6: R^2 quantiles, latex format          ');
disp('                                                     ');
disp('PANEL A : Estimated with k^C = k^H=k^L = 1, phi = 0.9');
end
disp('=================================================================')
disp(['Factors                         R^2 quantiles            '])
disp(['Factors                10%    25%   50%    75%     90%   '])
disp('-----------------------------------------------------------------') 
disp('Observables: LF variables')
disp(['common             ',...
      ' & ', num2str(RY_ESTfC_mean111(1,1), '%.1f'), ...
      ' & ', num2str(RY_ESTfC_mean111(1,2), '%.1f'), ...
      ' & ', num2str(RY_ESTfC_mean111(1,3), '%.1f'), ...
      ' & ', num2str(RY_ESTfC_mean111(1,4), '%.1f'), ...
      ' & ', num2str(RY_ESTfC_mean111(1,5), '%.1f'),'\\']) 
disp(['common, LF-specific',...
      ' & ', num2str(RY_ESTfLC_mean111(1,1), '%.1f'), ...
      ' & ', num2str(RY_ESTfLC_mean111(1,2), '%.1f'), ...
      ' & ', num2str(RY_ESTfLC_mean111(1,3), '%.1f'), ...
      ' & ', num2str(RY_ESTfLC_mean111(1,4), '%.1f'), ...
      ' & ', num2str(RY_ESTfLC_mean111(1,5), '%.1f'),'\\'])
disp(['LF-Specific        ',...
      ' & ', num2str(RY_ESTfL_mean111(1,1), '%.1f'), ...
      ' & ', num2str(RY_ESTfL_mean111(1,2), '%.1f'), ...
      ' & ', num2str(RY_ESTfL_mean111(1,3), '%.1f'), ...
      ' & ', num2str(RY_ESTfL_mean111(1,4), '%.1f'), ...
      ' & ', num2str(RY_ESTfL_mean111(1,5), '%.1f'),'\\'])
disp(['\midrule']) 
disp('Observables: HF variables')
disp(['common             ',...
      ' & ', num2str(RX_ESTfC_mean111(1,1), '%.1f'), ...
      ' & ', num2str(RX_ESTfC_mean111(1,2), '%.1f'), ...
      ' & ', num2str(RX_ESTfC_mean111(1,3), '%.1f'), ...
      ' & ', num2str(RX_ESTfC_mean111(1,4), '%.1f'), ...
      ' & ', num2str(RX_ESTfC_mean111(1,5), '%.1f'),'\\']) 
disp(['common, HF-specific',...
      ' & ', num2str(RX_ESTfHC_mean111(1,1), '%.1f'), ...
      ' & ', num2str(RX_ESTfHC_mean111(1,2), '%.1f'), ...
      ' & ', num2str(RX_ESTfHC_mean111(1,3), '%.1f'), ...
      ' & ', num2str(RX_ESTfHC_mean111(1,4), '%.1f'), ...
      ' & ', num2str(RX_ESTfHC_mean111(1,5), '%.1f'),'\\'])
disp(['HF-Specific        ',...
      ' & ', num2str(RX_ESTfH_mean111(1,1), '%.1f'), ...
      ' & ', num2str(RX_ESTfH_mean111(1,2), '%.1f'), ...
      ' & ', num2str(RX_ESTfH_mean111(1,3), '%.1f'), ...
      ' & ', num2str(RX_ESTfH_mean111(1,4), '%.1f'), ...
      ' & ', num2str(RX_ESTfH_mean111(1,5), '%.1f'),'\\']) 
disp('-----------------------------------------------------------------') 
disp(' '); disp(' ');
disp('###################################################################')
if design_n == 14;  % Table E.5
disp('Table E.5: adj. R^2 quantiles, latex format               ');
disp('                                                     ');
disp('PANEL C : Estimated with k^C = k^H=k^L = 1, phi = 0.7');
elseif design_n == 15;  % Table E.6 
disp('Table E.6: adj. R^2 quantiles, latex format          ');
disp('                                                     ');
disp('PANEL C : Estimated with k^C = k^H=k^L = 1, phi = 0.9');
end
disp('=================================================================')
disp(['Factors                         R^2 quantiles            '])
disp(['Factors                10%    25%   50%    75%     90%   '])
disp('-----------------------------------------------------------------') 
disp('Observables: LF variables')
disp(['common             ',...
      ' & ', num2str(adjRY_ESTfC_mean111(1,1), '%.1f'), ...
      ' & ', num2str(adjRY_ESTfC_mean111(1,2), '%.1f'), ...
      ' & ', num2str(adjRY_ESTfC_mean111(1,3), '%.1f'), ...
      ' & ', num2str(adjRY_ESTfC_mean111(1,4), '%.1f'), ...
      ' & ', num2str(adjRY_ESTfC_mean111(1,5), '%.1f'),'\\']) 
disp(['common, LF-specific',...
      ' & ', num2str(adjRY_ESTfLC_mean111(1,1), '%.1f'), ...
      ' & ', num2str(adjRY_ESTfLC_mean111(1,2), '%.1f'), ...
      ' & ', num2str(adjRY_ESTfLC_mean111(1,3), '%.1f'), ...
      ' & ', num2str(adjRY_ESTfLC_mean111(1,4), '%.1f'), ...
      ' & ', num2str(adjRY_ESTfLC_mean111(1,5), '%.1f'),'\\'])
disp(['LF-Specific        ',...
      ' & ', num2str(adjRY_ESTfL_mean111(1,1), '%.1f'), ...
      ' & ', num2str(adjRY_ESTfL_mean111(1,2), '%.1f'), ...
      ' & ', num2str(adjRY_ESTfL_mean111(1,3), '%.1f'), ...
      ' & ', num2str(adjRY_ESTfL_mean111(1,4), '%.1f'), ...
      ' & ', num2str(adjRY_ESTfL_mean111(1,5), '%.1f'),'\\'])
disp(['\midrule']) 
disp('Observables: HF variables')
disp(['common             ',...
      ' & ', num2str(adjRX_ESTfC_mean111(1,1), '%.1f'), ...
      ' & ', num2str(adjRX_ESTfC_mean111(1,2), '%.1f'), ...
      ' & ', num2str(adjRX_ESTfC_mean111(1,3), '%.1f'), ...
      ' & ', num2str(adjRX_ESTfC_mean111(1,4), '%.1f'), ...
      ' & ', num2str(adjRX_ESTfC_mean111(1,5), '%.1f'),'\\']) 
disp(['common, HF-specific',...
      ' & ', num2str(adjRX_ESTfHC_mean111(1,1), '%.1f'), ...
      ' & ', num2str(adjRX_ESTfHC_mean111(1,2), '%.1f'), ...
      ' & ', num2str(adjRX_ESTfHC_mean111(1,3), '%.1f'), ...
      ' & ', num2str(adjRX_ESTfHC_mean111(1,4), '%.1f'), ...
      ' & ', num2str(adjRX_ESTfHC_mean111(1,5), '%.1f'),'\\'])
disp(['HF-Specific        ',...
      ' & ', num2str(adjRX_ESTfH_mean111(1,1), '%.1f'), ...
      ' & ', num2str(adjRX_ESTfH_mean111(1,2), '%.1f'), ...
      ' & ', num2str(adjRX_ESTfH_mean111(1,3), '%.1f'), ...
      ' & ', num2str(adjRX_ESTfH_mean111(1,4), '%.1f'), ...
      ' & ', num2str(adjRX_ESTfH_mean111(1,5), '%.1f'),'\\']) 
disp('-----------------------------------------------------------------') 
disp('###################################################################')  
disp(' '); disp(' ');
disp('###################################################################')  
if design_n == 14;  % Table E.5 
disp('Table E.5: R^2 quantiles, latex format               ');
disp('                                                     ');
disp('PANEL B : Estimated with k^C = 2, k^H=k^L = 1, phi = 0.7');
elseif design_n == 15;  % Table E.6 
disp('Table E.6: R^2 quantiles, latex format          ');
disp('                                                     ');
disp('PANEL B : Estimated with k^C = 2, k^H=k^L = 1, phi = 0.9');
end
disp('=================================================================')
disp(['Factors                         R^2 quantiles            '])
disp(['Factors                10%    25%   50%    75%     90%   '])
disp('-----------------------------------------------------------------') 
disp('Observables: LF variables')
disp(['common             ',...
      ' & ', num2str(RY_ESTfC_mean200(1,1), '%.1f'), ...
      ' & ', num2str(RY_ESTfC_mean200(1,2), '%.1f'), ...
      ' & ', num2str(RY_ESTfC_mean200(1,3), '%.1f'), ...
      ' & ', num2str(RY_ESTfC_mean200(1,4), '%.1f'), ...
      ' & ', num2str(RY_ESTfC_mean200(1,5), '%.1f'),'\\']) 
disp(['\midrule']) 
disp('Observables: HF variables')
disp(['common             ',...
      ' & ', num2str(RX_ESTfC_mean200(1,1), '%.1f'), ...
      ' & ', num2str(RX_ESTfC_mean200(1,2), '%.1f'), ...
      ' & ', num2str(RX_ESTfC_mean200(1,3), '%.1f'), ...
      ' & ', num2str(RX_ESTfC_mean200(1,4), '%.1f'), ...
      ' & ', num2str(RX_ESTfC_mean200(1,5), '%.1f'),'\\']) 
disp('-----------------------------------------------------------------') 
disp(' '); disp(' ');
disp('###################################################################')
if design_n == 14;  % Table E.5
disp('Table E.5: adj. R^2 quantiles, latex format               ');
disp('                                                     ');
disp('PANEL D : Estimated with k^C = k^H=k^L = 1, phi = 0.7');
elseif design_n == 15;  % Table E.6 
disp('Table E.6: adj. R^2 quantiles, latex format          ');
disp('                                                     ');
disp('PANEL D : Estimated with k^C = k^H=k^L = 1, phi = 0.9');
end
disp('=================================================================')
disp(['Factors                         R^2 quantiles            '])
disp(['Factors                10%    25%   50%    75%     90%   '])
disp('-----------------------------------------------------------------') 
disp('Observables: LF variables')
disp(['common             ',...
      ' & ', num2str(adjRY_ESTfC_mean200(1,1), '%.1f'), ...
      ' & ', num2str(adjRY_ESTfC_mean200(1,2), '%.1f'), ...
      ' & ', num2str(adjRY_ESTfC_mean200(1,3), '%.1f'), ...
      ' & ', num2str(adjRY_ESTfC_mean200(1,4), '%.1f'), ...
      ' & ', num2str(adjRY_ESTfC_mean200(1,5), '%.1f'),'\\']) 
disp(['\midrule']) 
disp('Observables: HF variables')
disp(['common             ',...
      ' & ', num2str(adjRX_ESTfC_mean200(1,1), '%.1f'), ...
      ' & ', num2str(adjRX_ESTfC_mean200(1,2), '%.1f'), ...
      ' & ', num2str(adjRX_ESTfC_mean200(1,3), '%.1f'), ...
      ' & ', num2str(adjRX_ESTfC_mean200(1,4), '%.1f'), ...
      ' & ', num2str(adjRX_ESTfC_mean200(1,5), '%.1f'),'\\']) 
  disp('-----------------------------------------------------------------') 
disp('###################################################################')  
end
%##########################################################################
%##########################################################################
% START of HISTOGRAM PLOT #################################################
%##########################################################################
%##########################################################################

% Produces Histogram of Unfeasible statistics as in Figue 1 in the paper
if figure_ind == 1 
    
% otherwise figure is not generated nor saved

% select column vector of simulated values of the unfeasible statics
% for the test of the number of common factors to produce histogram    
unf_stat4hist = tab_dist_stat_h0_unf_stLhf(:,3);

%--------------------------------------------------------------------------    
% HISTOGRAM SETTINGS
% centers = -5:0.25:5;
centers = -6:0.5:6          ;    
d       = diff(centers)/2   ;
edges   = [centers(1)-d(1), centers(1:end-1)+d, centers(end)+d(end)] ;

Nbins = size(edges(2:end),2);
x     = zeros(1,Nbins)      ;
for counter=1:Nbins
    midPointShift = abs(edges(counter) - edges(counter+1))/2 ;
    x(counter)    = edges(counter) + midPointShift           ;
end
centers_norm = -6:0.01:6 ;

h = figure('visible','off'); % does NOT SHOW figure on screen
%h = figure('visible','on'); % SHOW figure on screen

% generates histogram
hist_plot = histogram(unf_stat4hist, edges, 'Normalization','pdf');

xlim([-6, 6]); set(gca,'xtick',[-6:1:6]);

% title of the histogram, including MC param./settings
suptitle('Histogram of the unfeasible test statistics');
title(['Param.:',...
       '$   N_H$=', num2str(round(sim_input.N_HLT(1,1),0)),...
       ',~~$N_L$=', num2str(round(sim_input.N_HLT(1,2),0)),...
       ',~~$T  $=', num2str(round(sim_input.N_HLT(1,3),0)),...
       ',~~$K_C$=', num2str(round(sim_input.KC_sim,0)),...
       ',~~$K_H$=', num2str(round(sim_input.KH_sim,0)),...
       ',~~$K_L$=', num2str(round(sim_input.KL_sim,0)),...
       ',~~$\phi$=',num2str(round(sim_input.phi,2)),...
       ',~~$R^2_{max}$=',num2str(round(sim_input.R_Hall_max,2))],'Interpreter','latex');

hold on
% overlap standard normal distribution: Asymptotic distribution
plot(centers_norm,normpdf(centers_norm),'LineWidth',1.5,'Color','red' )
ylim([0, 0.42]); 

% Create name of figure to save
% note: names includes all MC design param. allowing to associate
%       each histogram to its MC simulation design

% example: 'HISTOGRAM_UNF_STAT_111_0_0_8_0_0_nsim1000_100_100_50_m4.png'
name_temp_save = sprintf('%s_%d%d%d_%d_%d_%d_%d_%d_%s%d_%d_%d_%d_%s%d',...
                       'HISTOGRAM_UNF_STAT',...
                       KC_sim, KH_sim,KL_sim,...
                       round(beta*10), round(a_e*10),...
                       round(R_Hall_max*10), round(a_fac*10),...
                       round(phi*100),...
                       'nsim', n_sim,...
                       N_H,N_L, T,...
                       'm', m) ;
                   
% generate full name with directory                 
file_name_save = fullfile(savdir_mat,name_temp_save);

% save figure in .png format
saveas(h,file_name_save,'png'); close(h);
end
%##########################################################################
%##########################################################################
% end of HISTOGRAM PLOT ###################################################
%##########################################################################
%##########################################################################
end