function [cc_test_mat_summary,...
          cc_test_mat_all] = sel_nfactors_CHEN_given_k1k2(X, Y, freq, samp_type, k_1, k_2, m)
%--------------------------------------------------------------------------
% DESCRIPTION: Matlab function which implements the selection procedure for 
% the number of common factors in two panels observed at different 
% frequencies proposed in Section 3.2 of the the working paper by 
% Pu Chen (2012) and titled:  "Common factors and specific factors".
% The working paper is downloadble from:
% https://mpra.ub.uni-muenchen.de/36114/1/MPRA_paper_36114.pdf
%--------------------------------------------------------------------------
% Date  : 30.03.2019
% Author: Mirco Rubin
% Email : mircorubin@gmail.com
% updated files can be found also on the author's website:
% Web   : https://sites.google.com/site/mircorubin/ 
%--------------------------------------------------------------------------
% NOTE: function works just for quarterly/yearly data 
%--------------------------------------------------------------------------
% INPUT
% X          : (T_HF X N_HF) matrix
% Y          : (T_LF X N_LF) matrix
% freq       : 'yq' or 'qm' (yearly/quarterly -> m = 4) or (quarterly/monthly -> m = 3)
% k1         : kC_hat + kH_hat (estimated in previous step) 
% k2         : kC_hat + kL_hat (estimated in previous step) 
% alpha_test : significance level for the test (e.g. 0.05)
% cf_est_type: common factor estimation type
%--------------------------------------------------------------------------
% OUTPUT
% cc_test_mat_summary : estimated number of common and specific factors according to Chen (2012)
%
% cc_test_mat_summary(1,1) = kc_hat ;
% cc_test_mat_summary(1,2) = kH_hat ;
% cc_test_mat_summary(1,3) = kL_hat ;
%
% cc_test_mat_all     : ...
%
% gChat      : (4*T X KC) estimated common (HF) factor
% gHhat      : (4*T X KH) estimated spec. HF factor 
% gLhat      : (T X KL)   estimated spec. LF factor 
%--------------------------------------------------------------------------
% Dimensions of panels
% T_HF  = size(X,1)        ; 
N_HF  = size(X,2)         ;
T_LF  = size(Y,1)         ;
N_LF  = size(Y,2)         ;
T     = T_LF              ;
N_1   = N_HF              ;
N_2   = N_LF              ;
% muN   = sqrt(N_2/N_1)    ;
k_min = min([k_1;k_2])    ;
N     = N_1 + N_2         ;
alpha = [N_1; N_2] /N     ;
alpha_undbar = min(alpha)/2 ;
alpha_ovbar  = 1-alpha_undbar ;

g            = g_CHEN2012(N,T_LF)                    ;
h_vec        = h_CHEN2012(alpha,alpha_undbar,N,T_LF) ;
h_bar        = alpha'*h_vec                          ;

C_vec        = NaN(k_min+1,1);
C_vec_notcorrected = NaN(k_min+1,1);
% OUTPUT TABLES
cc_test_mat_summary = zeros(1      ,3+k_min+1+k_min+1) ; 
cc_test_mat_all     = zeros(k_min+1,3      )           ;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
switch freq
case 'yq'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%m = 4 ; 
%[X1, X2, X3, X4] = Stack_HF_LF_4superiods(X) ;
X_stack  = Stack_HF_LF_m_superiods(X,m);
%--------------------------------------------------------------------------
switch samp_type
%---------------
case 'flow'
%X_agg = X1 + X2 + X3 + X4 ; 
X_agg = zeros(T,N_HF);
for ind_m = 1:m
     X_agg = X_agg + X_stack(:,:,ind_m); 
end
X_LF  = X_agg ; % here stand. doesn't matter: PCA are already stand.
%X_LF  = zscore(X_agg)             ; 
%---------------
case 'stock'
X_LF = X4 ; % here stand. doesn't matter: PCA are already stand.
%X_LF = zscore(X4) ;
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% STANDARDIZE DATA
X_LF = zscore(X_LF);
Y    = zscore(Y);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%--------------------------------------------------------------------------
[eigvec_X, ~ ] = eigs(X_LF*X_LF'/N_HF,k_1);
eigvec_X       = sqrt(T_LF)*eigvec_X  ;

[eigvec_Y, ~ ] = eigs(Y*Y'/N_LF ,k_2) ;
eigvec_Y       = sqrt(T_LF)*eigvec_Y  ;
%--------------------------------------------------------------------------
% CHEN (2012) criterion for estimation of number of common factors
%--------------------------------------------------------------------------
H1 = eigvec_X         ;
H2 = eigvec_Y         ;
F  = [H1,H2]          ;
Sigma_ast = F'*F/T_LF ;

[a_all_uns, eigval_a_uns]    = eigs(Sigma_ast,k_min)              ;
[eigval_a, index_eigen_sort] = sort(diag(eigval_a_uns),'descend') ;
a_all                        = a_all_uns(:,index_eigen_sort)      ;
%--------------------------------------------------------------------------
tab_ind = 0 ;
% Output table: all cc tests 
for kc_temp = linspace(0,k_min,(k_min+1))         % k_min,k_min-1,...,0
    
    tab_ind    = tab_ind  + 1  ; % index for table  
    % number of specific factors (n. of common facotr = kc_temp)
    k1s_temp   = k_1 - kc_temp ;
    k2s_temp   = k_2 - kc_temp ;  
    % COMPUTE COMMON FACTOR ------------------------------------------------------
    FChat_temp = F*a_all(:,1:kc_temp)/sqrt(2);
    %----------------------------------------------------------------------    
    % Compute specific factors (if any), aggregated at LF
    % Spec. factors are computed frome residuals of regr. on comm. fcts.
    MFC_temp      = eye(T_LF) - FChat_temp*((FChat_temp'*FChat_temp)\FChat_temp') ;
    Xi1           = MFC_temp*X_LF ;
    Xi2           = MFC_temp*Y    ;
        
    % HF SPEC. FACTORS
    if k1s_temp > 0
        [FHast_temp_uns, D_temp_uns] = eigs(Xi1*Xi1'/N_HF, k1s_temp)     ;
        [D_temp, index_eigen_sort]   = sort(diag(D_temp_uns),'descend')  ;
         FHast_temp                  = FHast_temp_uns(:,index_eigen_sort);
                
        FHast_temp       = sqrt(T_LF)*FHast_temp         ;
        F1_temp          = [FChat_temp FHast_temp]       ;
        MF1_temp         = eye(T_LF) - F1_temp*((F1_temp'*F1_temp)\F1_temp') ;
        res_1_temp       = MF1_temp*X_LF                 ;
    else % NO HF spec. factor
        F1_temp          = FChat_temp                    ;
        res_1_temp       = Xi1                           ;
    end

    % LF SPEC. FACTORS
    if k2s_temp > 0
        [FLast_temp_uns, D_temp_uns ] = eigs(Xi2*Xi2'/N_LF, k2s_temp) ;
        [D_temp, index_eigen_sort]   = sort(diag(D_temp_uns),'descend')  ;
         FLast_temp                  = FLast_temp_uns(:,index_eigen_sort);
         
        FLast_temp       = sqrt(T_LF)*FLast_temp         ;
        F2_temp          = [FChat_temp FLast_temp]       ;
        MF2_temp         = eye(T_LF) - F2_temp*((F2_temp'*F2_temp)\F2_temp') ;
        res_2_temp       = MF2_temp*Y                    ;
    else % NO LF spec. factor
        F2_temp          = FChat_temp                    ;
        res_2_temp       = Xi2                           ;
    end
    %----------------------------------   
    % TEST FOR THE NUMBER OF FACTORS
    V1_temp = sum(sum(res_1_temp.^2))/(N_HF*T_LF)        ;
    V2_temp = sum(sum(res_2_temp.^2))/(N_LF*T_LF)        ;
    
    if kc_temp == 0
        sigma2_hat = alpha'*[V1_temp; V2_temp]           ;
    end
    
    ks_bar = alpha'*[k1s_temp; k2s_temp]                 ;
    
    C_vec(tab_ind,1) = alpha'*[V1_temp; V2_temp] + ...
                       sigma2_hat*(ks_bar + h_bar + alpha_ovbar*kc_temp)*...
                       g;
    C_vec_notcorrected(tab_ind,1) = alpha'*[V1_temp; V2_temp];
 
    cc_test_mat_all(tab_ind,:) = [kc_temp, C_vec(tab_ind,1), C_vec_notcorrected(tab_ind,1) ] ;  
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FILL OUTPUT TABLES, case 'yq'
[r_ind_test,~] = find(cc_test_mat_all(:,2) == min(cc_test_mat_all(:,2))) ;

kc_hat = cc_test_mat_all(r_ind_test,1) ;

kH_hat = k_1 - kc_hat ;
kL_hat = k_2 - kc_hat ;

cc_test_mat_summary(1,1) = kc_hat ;
cc_test_mat_summary(1,2) = kH_hat ;
cc_test_mat_summary(1,3) = kL_hat ;

cc_test_mat_summary(1,4:(4+k_min))                   = cc_test_mat_all(:,2)';
cc_test_mat_summary(1,(4+k_min+1):(4+k_min+k_min+1)) = cc_test_mat_all(:,3)';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
case 'qm'
% ...
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end % switch case yq/qm



%##########################################################################
%##########################################################################
% NESTED FUNCTIONS
%##########################################################################
%##########################################################################

%##########################################################################
% NESTED FUNCTION 1
%##########################################################################
function [ h_out ] = h_CHEN2012(alpha,alpha_undbar,N,T_LF)
%'g_CHEN2012' Computes the h functions as in Chen 2012
n_alpha = size(alpha,1)  ;
h_out   = NaN(n_alpha,1) ;
g_den   = g_CHEN2012(alpha_undbar*N,T_LF);
for ind = 1:n_alpha;
    h_out(ind,1) = g_CHEN2012(alpha(ind,1)*N,T_LF)/g_den;  
end
end 
%##########################################################################
% NESTED FUNCTION 2
%##########################################################################
function [ g_out ] = g_CHEN2012(N,T)
%'g_CHEN2012' Computes the c(N,T) function as in Chen 2012
g_out = ((N+T)/(N*T))*log(N*T/(N+T));
end 
%##########################################################################
%##########################################################################
end 