function [cc_mat_summary,...
          cc_mat,...
          cc_mat_unf ] = sel_nfactors_MC(X, Y, k_1, k_2,...
                                         cf_est_type, c, gamma,...
                                         FC_sim,...
                                         L_HC_sim, L_H_sim, ...
                                         L_LC_sim, L_L_sim, ...
                                         FC_sim_fl, ...
                                         m, stat_prod,...
                                         stand_HL, ...
                                         aggregation_first_indicator)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DESCRIPTION: Matlab function performing:
% - the estimation of the number of common and group-specific factors
% - compute and saves:
%   * all the feasible and INFEASIBLE test statics for any 
%        possible number of common factors
%   * the all quanitities (bias, st.dev., sum of canonical correlations) 
%        used to compute the test statics for the muber of common factors
% The inputs are 2 panels of data observed at two different frequencies,
% and the original parameters of the data generating process,
% the true common facotrs, and the true loadings
%--------------------------------------------------------------------------
% Date  : 30.03.2019
% Author: Mirco Rubin
% Email : mircorubin@gmail.com
% updated files can be found also on the author's website:
% Web   : https://sites.google.com/site/mircorubin/ 
%--------------------------------------------------------------------------
% INPUT
% X          : (T_HF X N_HF) matrix
% Y          : (T_LF X N_LF) matrix
% k1         : kC_hat + kH_hat (estimated in previous step) 
% k2         : kC_hat + kL_hat (estimated in previous step) 
% cf_est_type: common factor estimation type ('cdir_HF','cdir_LF','3')
%#############################################################################################################################################
% OUTPUT
%#############################################################################################################################################
%
% cc_mat_summary : (1 X (3+k_min)) vector, where k_min = min(k_1, k_2)
%
%
% cc_mat_summary(1,1)       = kc_hat ; estimated with the feasible statics, and k_min = min (k_1,k_2)
% cc_mat_summary(1,2)       = kH_hat ; estimated with the feasible statics, and k_min = min (k_1,k_2)
% cc_mat_summary(1,3)       = kL_hat ; estimated with the feasible statics, and k_min = min (k_1,k_2)
% cc_mat_summary(1,3+1)     = \tilde{\xi}(k_min)   (i.e. feasible test stat. for kc = k_min)
% cc_mat_summary(1,3+2)     = \tilde{\xi}(k_min-1) (i.e. feasible test stat. for kc = k_min-1)
% ...
% cc_mat_summary(1,3+k_min) = \tilde{\xi}(1)       (i.e. feasible test stat. for kc = 1)
%
%#############################################################################################################################################
%
% cc_mat         : (k_min X 5) MATRIX for the FEASIBLE STATISTICS
%
%---------------------------------------------------------------------------------------------------------------------------------------------
%           | col. 1  | col. 2              | col. 3                            | col. 4                       | col. 5
%-----------|---------|---------------------|-----------------------------------|------------------------------|------------------------------
% row 1     | k_min   | \tilde{\xi}(k_min)  | sum of the first k_min   can. cor.| bias of \tilde{\xi}(k_min)   | st.dev of \tilde{\xi}(k_min)
% row 2     | k_min-1 | \tilde{\xi}(k_min-1)| sum of the first k_min-1 can. cor.| bias of \tilde{\xi}(k_min-1) | st.dev of \tilde{\xi}(k_min-1)
% ...       | ...     | ...                 | ...                               | ...                          | ...
% row k_min | 1       | \tilde{\xi}(1)      | largest canonical correlation     | bias of \tilde{\xi}(1)       | st.dev of \tilde{\xi}(1)
%-----------|---------|---------------------|-----------------------------------|------------------------------|------------------------------
%#############################################################################################################################################
%
% cc_mat_unf     : (k_min X 5) MATRIXfor the INFEASIBLE STATISTICS
%
%---------------------------------------------------------------------------------------------------------------------------------------------
%           | col. 1  | col. 2              | col. 3                            | col. 4                       | col. 5
%-----------|---------|---------------------|-----------------------------------|------------------------------|------------------------------
% row 1     | k_min   | \hat{\xi}(k_min)    | sum of the first k_min   can. cor.| bias of \hat{\xi}(k_min)     | st.dev of \hat{\xi}(k_min)
% row 2     | k_min-1 | \hat{\xi}(k_min-1)  | sum of the first k_min-1 can. cor.| bias of \hat{\xi}(k_min-1)   | st.dev of \hat{\xi}(k_min-1)
% ...       | ...     | ...                 | ...                               | ...                          | ...
% row k_min | 1       | \hat{\xi}(1)        | largest canonical correlation     | bias of \hat{\xi}(1)         | st.dev of \hat{\xi}(1)
%-----------|---------|---------------------|-----------------------------------|------------------------------|------------------------------
%#############################################################################################################################################
% Dimensions of panels
[~   , N_HF] = size(X)    ; 
[T_LF, N_LF] = size(Y)    ;
N     = min([N_HF, N_LF]) ;
T     = T_LF              ;
N_1   = N_HF              ;
N_2   = N_LF              ;
k_min = min([k_1;k_2])    ;
%--------------------------------------------------------------------------
% Empty OUTPUT TABLES
cc_mat_summary = zeros(1    ,3+k_min) ; % feasible stat: summary of results
cc_mat         = zeros(k_min,5      ) ; % feasible stat: all results
cc_mat_unf     = zeros(1    ,5      ) ; % INFEASIBLE stat: all results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if aggregation_first_indicator == 1 % Aggregation first
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
    if stand_HL == 'H' % original HF data are standardized at HF, i.e. before aggregation
    
    X_unstack  = Stack_HF_LF_m_superiods(zscore(X),m);

    % Flow sampling: aggregate (i.e. sum) within all m subperiods of each LF period 
    X_agg = zeros(T,N_HF);
    for ind_m = 1:m
         X_agg = X_agg + X_unstack(:,:,ind_m); 
    end
    X_LF     = X_agg                 ; 
    std_X_HF = std(X)                ; % (used only for INFEASIBLE stat.)
    GAMMA1   = diag(m./(std_X_HF.^2)); % (used only for INFEASIBLE stat.)

    % Loadings of model after standarization (used only for INFEASIBLE stat.)
    L_HC_sim_ds = L_HC_sim  ./ repmat(std_X_HF',1,size(L_HC_sim,2)) ;
    L_H_sim_ds  = L_H_sim   ./ repmat(std_X_HF',1,size(L_H_sim ,2)) ;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    elseif stand_HL == 'L' % original HF data are standardized at LF, i.e. after aggregation
    % original working
    X_unstack  = Stack_HF_LF_m_superiods(X,m);

    % Flow sampling: aggregate (i.e. sum) within all m subperiods of each LF period 
    X_agg = zeros(T,N_HF);
    for ind_m = 1:m
         X_agg = X_agg + X_unstack(:,:,ind_m); 
    end

    X_LF     = zscore(X_agg)           ;
    std_X_LF = std(X_agg)              ; % used only for INFEASIBLE stat.
    GAMMA1   = diag(m./(std_X_LF.^2))  ; % used only for INFEASIBLE stat.

    % Loadings of model after standarization (used only for INFEASIBLE stat.)
    L_HC_sim_ds = L_HC_sim  ./ repmat(std_X_LF',1,size(L_HC_sim,2)) ;
    L_H_sim_ds  = L_H_sim   ./ repmat(std_X_LF',1,size(L_H_sim ,2)) ;
    end
%----------------------------------------------------------------------
[eigvec_X,~] = eigs(X_LF*X_LF'/N_HF,k_1);
% Rescale eigenvectors to have var-cov = I in-sample
eigvec_X     = sqrt(T)*eigvec_X  ;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif aggregation_first_indicator == 0 % PCA first
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    if stand_HL == 'H' % original HF data are standardized at HF, i.e. before aggregation
    
    % PCA on standardized HF data only
    X_HF = zscore(X)   ; % standardize data at HF
    [eigvec_X_HF,~]   = eigs(X_HF*X_HF'/N_HF,k_1);

    eigvec_X_HF_unstack = Stack_HF_LF_m_superiods(eigvec_X_HF,m);
    eigvec_X_HF_agg     = zeros(T_LF,k_1);
    for ind_m = 1:m
         eigvec_X_HF_agg = eigvec_X_HF_agg + eigvec_X_HF_unstack(:,:,ind_m); 
    end    
    %----------------------------------------------------------------------   
    X_unstack  = Stack_HF_LF_m_superiods(X_HF,m);
    
    % Flow sampling: aggregate (i.e. sum) within all m subperiods of each LF period 
    X_agg = zeros(T,N_HF);
    for ind_m = 1:m
         X_agg = X_agg + X_unstack(:,:,ind_m); 
    end
    X_LF     = X_agg                 ; 
    std_X_HF = std(X)                ; % (used only for INFEASIBLE stat.)
    GAMMA1   = diag(m./(std_X_HF.^2)); % (used only for INFEASIBLE stat.)

    % Loadings of model after standarization (used only for INFEASIBLE stat.)
    L_HC_sim_ds = L_HC_sim  ./ repmat(std_X_HF',1,size(L_HC_sim,2)) ;
    L_H_sim_ds  = L_H_sim   ./ repmat(std_X_HF',1,size(L_H_sim ,2)) ;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    elseif stand_HL == 'L' % original HF data are standardized at LF, i.e. after aggregation
    warning('PCA should be performed on HF standardized HF data in the case of "PCA first" ')
    end
%----------------------------------------------------------------------
% Rescale eigenvectors to have var-cov = I in-sample
eigvec_X = eigvec_X_HF_agg*(((eigvec_X_HF_agg'*eigvec_X_HF_agg)/T_LF)^(-0.5)) ; 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% LF data can only be standardazided after being aggregated (al LF only)
std_Y  = std(Y)              ;
GAMMA2 = diag(m./(std_Y.^2)) ;
Y      = zscore(Y)           ;

L_LC_sim_ds = L_LC_sim  ./ repmat(std_Y'   ,1,size(L_LC_sim,2)) ;
L_L_sim_ds  = L_L_sim   ./ repmat(std_Y'   ,1,size(L_L_sim ,2)) ;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[eigvec_Y,~] = eigs(Y*Y'/N_LF ,k_2) ;
eigvec_Y     = sqrt(T)*eigvec_Y  ;
%--------------------------------------------------------------------------
% Andreou, Ghysels, Gagliardini, Rubin (2016) canonical correlation test
%--------------------------------------------------------------------------
H1   = eigvec_X    ;
H2   = eigvec_Y    ;
V11  = H1'*H1/T_LF ;
V12  = H1'*H2/T_LF ;
V21  = V12'        ;
V22  = H2'*H2/T_LF ;
% NOTE: when n. of eigenvalues to compute is = dimension of the squared matrix
%       then 'eigs' compute UNSORTED eigenvectors and the associated
%       eigenvectors.
%       --> Both eigenvalues and eigenvectors must be resorted 
%          (from largest to smallest eigenvalue)
%--------------------------------------------------------------------------
% Compute all canonical correlations
R                         = (V11\V12)*(V22\V21) ;
[eigvR_uns, eigR_mat_uns] = eigs(R,k_min)       ;
% Sort eigenvalues and eigenvectors
[eigR, index_eigen_sort]  = sort(diag(eigR_mat_uns),'descend') ;
eigvR                     = eigvR_uns(:,index_eigen_sort)      ;

can_corr_all              = sqrt(eigR)   ; % sqrt of canonical correlations
%--------------------------------------------------------------------------
tab_ind = 0 ;
% Output table: all cc tests 
for kc_temp = linspace(k_min,1,k_min)         % k_min,k_min-1,...,1
    
    tab_ind     = tab_ind  + 1  ; % index for table  
    % number of specific factors
    k1s_temp    = k_1 - kc_temp ;
    k2s_temp    = k_2 - kc_temp ;
    
    % sum first k_c sqrt of canonical correlations: test statisaitc in eq. (4.24)
    sum_cc_temp = sum(can_corr_all(1:kc_temp,1)); 
    
    % COMPUTE FACTORS (different ways to do it) ---------------------------
    % canonical directions
    switch cf_est_type
        case 'cdir_HF'
            W1_temp    = eigvR(:,1:kc_temp)    ; % common factor v1  
            FChat_temp = H1*W1_temp            ;
        case 'cdir_LF'
            Rast         = (V22\V21)*(V11\V12) ;
            [eigvRast_uns,eigRast_mat_uns] = eigs(Rast,k_min)    ;
            [~, index_eigen_sort]    = sort(diag(eigRast_mat_uns),'descend') ;
             eigvRast                      = eigvRast_uns(:,index_eigen_sort)      ;         
            
            W2_temp    = eigvRast(:,1:kc_temp) ; % common factor v2
            FChat_temp = H2*W2_temp            ;
        case '3'
            %--------------------------------------------------------------------------
            P_sum = H1*H1' + H2*H2';
            % computes all 'k_min' eigenvalues (and eigenvectors) of the TXT matrix 'P_sum'
            [fac_temp_uns, D_uns] = eigs(P_sum, k_min)               ; 
            [~, index_eigen_sort] = sort(diag(D_uns),'descend')      ; % sort eignevalues and eigenvectors
             fac_temp_sort        = fac_temp_uns(:,index_eigen_sort) ;
             
            fac_temp_sort = sqrt(T)*fac_temp_sort                    ;
            %--------------------------------------------------------------
            FChat_temp = fac_temp_sort(:,1:kc_temp) ; % estimated common factor
            %--------------------------------------------------------------
    end
    %----------------------------------------------------------------------    
    % Compute specific factors (if any), aggregated at LF
    % Spec. factors are computed frome residuals of regr. on comm. fcts.
    MFC_temp      = eye(T_LF) - FChat_temp*((FChat_temp'*FChat_temp)\FChat_temp') ;
    Xi1           = MFC_temp*X_LF ;
    Xi2           = MFC_temp*Y    ;
            
    % HF SPEC. FACTORS
    if k1s_temp > 0
        [FHast_temp_uns, D_temp_uns] = eigs(Xi1*Xi1'/N_HF, k1s_temp)     ;
        [~, index_eigen_sort]   = sort(diag(D_temp_uns),'descend')  ;
        FHast_temp                   = FHast_temp_uns(:,index_eigen_sort);
        
        FHast_temp       = sqrt(T_LF)*FHast_temp         ;
        F1_temp          = [FChat_temp FHast_temp]       ;
        MF1_temp         = eye(T_LF) - F1_temp*((F1_temp'*F1_temp)\F1_temp') ;
        res_1_temp       = MF1_temp*X_LF                 ;       
        
    else % NO HF spec. factor
        F1_temp          = FChat_temp                    ;
        res_1_temp       = Xi1                           ;
    end

    % LF SPEC. FACTORS
    if k2s_temp > 0
        [FLast_temp_uns, D_temp_uns ] = eigs(Xi2*Xi2'/N_LF, k2s_temp) ;
        [~, index_eigen_sort]   = sort(diag(D_temp_uns),'descend')  ;
         FLast_temp                  = FLast_temp_uns(:,index_eigen_sort);
         
        FLast_temp       = sqrt(T_LF)*FLast_temp         ;
        F2_temp          = [FChat_temp FLast_temp]       ;
        MF2_temp         = eye(T_LF) - F2_temp*((F2_temp'*F2_temp)\F2_temp') ;
        res_2_temp       = MF2_temp*Y                    ;
    else % NO LF spec. factor
        F2_temp          = FChat_temp                    ;
        res_2_temp       = Xi2                           ;
    end
    
    % FEASIBLE TEST FOR THE NUMBER OF FACTORS
    
    % LOADINGS MATRICES
    L1hat       = (X_LF')*F1_temp/(F1_temp'*F1_temp);
    L2hat       =    (Y')*F2_temp/(F2_temp'*F2_temp);
       
    % Residual matrices
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    if aggregation_first_indicator == 1     % Aggregation first
        Gamma_hat_1_mat = cov(res_1_temp)               ;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
    elseif aggregation_first_indicator == 0 % PC first
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
        F1_temp_HF    = X_HF*L1hat/(L1hat'*L1hat);
        MF1_temp_HF   = eye(m*T) - F1_temp_HF*((F1_temp_HF'*F1_temp_HF)\F1_temp_HF') ;
        res_1_temp_HF = MF1_temp_HF*X_HF                ;   
        Gamma_hat_1_mat = cov(res_1_temp_HF)*m          ; 
    % This estimator has slightly better samll sample properties for 
    % the test statics in most designs considered as mentionend in the OA.
    % When N_1, N_2, T grow to +infty the two estimators produce similar results
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    end
    
    Gamma_hat_2_mat = cov(res_2_temp)               ;
    
    Gamma_hat_1     = diag(diag(Gamma_hat_1_mat))   ;
    Gamma_hat_2     = diag(diag(Gamma_hat_2_mat))   ;

    L1L1            = L1hat'*L1hat                  ;
    L2L2            = L2hat'*L2hat                  ;

    Sigma_hat_u1  = N_1*((L1L1\(L1hat'*Gamma_hat_1*L1hat))/L1L1) ;
    Sigma_hat_u2  = N_2*((L2L2\(L2hat'*Gamma_hat_2*L2hat))/L2L2) ;
    
    Sigma_hat_u1_cc = Sigma_hat_u1(1:kc_temp,1:kc_temp)          ;
    Sigma_hat_u2_cc = Sigma_hat_u2(1:kc_temp,1:kc_temp)          ;
    
    Sigma_U_hat  = (N_2/N_1)*Sigma_hat_u1_cc + Sigma_hat_u2_cc   ;        

    % COMPUTE FEASIBLE TEST STATISTICS 
    stat_cc = N*sqrt(T)*...
              ( (0.5*trace(Sigma_U_hat*Sigma_U_hat))^(-0.5) )*...
              ( sum_cc_temp - kc_temp ...
               +(1/(2*N))*trace(Sigma_U_hat) );
           
    % FILL OUTPUT TABLES FOR FEASIBLE TEST STATISTICS 
    cc_mat(tab_ind,:) = [kc_temp, ...    % n. of common facotrs tested (from k_min to 1)
                         stat_cc, ...    % value of centered and standardized FEASIBLE test statistics \tilde{\xi}
                         sum_cc_temp,... % sum of the first kc_temp canonical correlations
                         (1/(2*N))*trace(Sigma_U_hat),...  % bias of the FEASIBLE  stat.
                         (1/(N*sqrt(T)))*( (0.5*trace(Sigma_U_hat*Sigma_U_hat))^(0.5) )  ] ;  % std. dev. of the FEASIBLE  stat.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% INFEASIBLE STATISTICS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if stat_prod == 'I'     % 'I' stands for "infeasible" 
if kc_temp == size(FC_sim,2)
%--------------------------------------------------------------------------
if (k_1-size(FC_sim,2))~=0
L1hat_unf = [L_HC_sim_ds, L_H_sim_ds];
else
L1hat_unf = L_HC_sim_ds;
end

if (k_2-size(FC_sim,2))~=0
L2hat_unf = [L_LC_sim_ds, L_L_sim_ds];
else
L2hat_unf = L_LC_sim_ds;
end

L1L1_unf           = (L1hat_unf')*L1hat_unf        ;
L2L2_unf           = (L2hat_unf')*L2hat_unf        ;
     
Sigma_hat_u1_ds    = N_1*((L1L1_unf\(L1hat_unf'*GAMMA1*L1hat_unf))/L1L1_unf) ;
Sigma_hat_u2_ds    = N_2*((L2L2_unf\(L2hat_unf'*GAMMA2*L2hat_unf))/L2L2_unf) ;
%--------------------------------------------------------------------------
Sigma_hat_u1_cc_ds = Sigma_hat_u1_ds(1:kc_temp,1:kc_temp)              ;
Sigma_hat_u2_cc_ds = Sigma_hat_u2_ds(1:kc_temp,1:kc_temp)              ;
    
Sigma_U_hat_ds     = (N_2/N_1)*Sigma_hat_u1_cc_ds + Sigma_hat_u2_cc_ds ;  

Sigma_cc_hat_m1    = inv(FC_sim_fl'*FC_sim_fl/T)         ;

% COMPUTE TEST STATISTICS 
stat_cc_ds = N*sqrt(T)*...
            ( (0.5*trace(Sigma_U_hat_ds*Sigma_U_hat_ds))^(-0.5) )*...
            ( sum_cc_temp - kc_temp ...
            +(1/(2*N))*trace(Sigma_cc_hat_m1*Sigma_U_hat_ds) );

% FILL OUTPUT TABLES
cc_mat_unf(1,:) = [kc_temp, stat_cc_ds, sum_cc_temp,...
                  (1/(2*N))*trace(Sigma_cc_hat_m1*Sigma_U_hat_ds),...
                  (1/(N*sqrt(T)))*( (0.5*trace(Sigma_U_hat_ds*Sigma_U_hat_ds))^(0.5) )  ] ;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 % END OF INFEASIBLE STAT. %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%       
end
end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FILL SUMAMRY OUTPUT TABLES
[r_ind_test,~] = find(cc_mat(:,2) >= -c*(N*sqrt(T))^(gamma) ) ;

if isempty(r_ind_test)==1
    kc_hat = 0 ;
else
    kc_hat = cc_mat(min(r_ind_test),1   ) ;
end

kH_hat = k_1 - kc_hat ;
kL_hat = k_2 - kc_hat ;

cc_mat_summary(1,1) = kc_hat ;
cc_mat_summary(1,2) = kH_hat ;
cc_mat_summary(1,3) = kL_hat ;

cc_mat_summary(1,4:(3+k_min)) = cc_mat(:,2)'  ;
end