function [ FC_sim  , FH_sim, FL_sim,...
           L_HC_sim, L_H_sim, ...
           L_LC_sim, L_L_sim,...
           R_Hall_vec, R_H_C_vec,...
           R_Lall_vec, R_L_C_vec] = simulation_factors_and_loadings( vec_sim_input )
%--------------------------------------------------------------------------
% DESCRIPTION: Matlab function which simulates factors and loadings 
% from DGP described in the Online Appendix, Section E.1.
%--------------------------------------------------------------------------
% Date  : 30.03.2019
% Author: Mirco Rubin
% Email : mircorubin@gmail.com
% updated files can be found also on the author's website:
% Web   : https://sites.google.com/site/mircorubin/ 
%--------------------------------------------------------------------------
% Loads input parameters
KC_sim      = vec_sim_input.KC_sim      ;
KH_sim      = vec_sim_input.KH_sim      ;
KL_sim      = vec_sim_input.KL_sim      ;
m           = vec_sim_input.m           ;
N_H_sim     = vec_sim_input.N_H_sim     ;
N_L_sim     = vec_sim_input.N_L_sim     ;
T_sim       = vec_sim_input.T_sim       ;
a_fac       = vec_sim_input.a_fac       ;
a_e         = vec_sim_input.a_e         ;
R_Hall_min  = vec_sim_input.R_Hall_min  ;
R_Hall_max  = vec_sim_input.R_Hall_max  ;
delta_HCmin = vec_sim_input.delta_HCmin ; 
delta_HCmax = vec_sim_input.delta_HCmax ;
R_Lall_min  = vec_sim_input.R_Lall_min  ;
R_Lall_max  = vec_sim_input.R_Lall_max  ;
delta_LCmin = vec_sim_input.delta_LCmin ;
delta_LCmax = vec_sim_input.delta_LCmax ;
KC_simG     = vec_sim_input.KC_simG     ;
KH_simG     = vec_sim_input.KH_simG     ;
KL_simG     = vec_sim_input.KL_simG     ;
K_all_simG  = vec_sim_input.K_all_simG  ;
A_mtx       = vec_sim_input.A_mtx       ;
Phi_mtx     = vec_sim_input.Phi_mtx     ;
%##########################################################################
%##########################################################################
% Simulation of FACTORS
%##########################################################################
%##########################################################################

% constant parameters = population variances of flow-sampled factors and
% idiosyncratic innovations
% for the flow-sampled factors this is equal to (M^2)*kappa as defined in
% the Online Appendix
coeff_sum   = 0 ;
coeff_sum_e = 0 ;
for ind_m_temp = 1:(m-1)
    coeff_sum   = coeff_sum   + 2*(m-ind_m_temp)*a_fac^(ind_m_temp) ;
    coeff_sum_e = coeff_sum_e + 2*(m-ind_m_temp)*a_e^(ind_m_temp)   ;
end

M2k     = m + coeff_sum   ; % corresponding to (M^2)*kappa in the Online Appendix
M2k_e   = m + coeff_sum_e ; % analogous quantity computed for the idiosyncratic innovations

% Empty matrix of factors tobe simualted: (FC, FH, FL) matrix: K_sim X (m*T_LF+1)
g_sim = zeros(K_all_simG,m*T_sim+1) ;

%--------------------------------------------------------------------------
% Simulate innovations sqrt(((1-a_fac^2)/M2k))*eta_mt ~ iiN(0, fac_inn_cov_mat )
fac_inn_cov_mat = ((1-a_fac^2)/M2k)*...
                   [ eye(KC_simG)          , zeros(KC_simG,KH_simG), zeros(KC_simG,KL_simG);...
                     zeros(KH_simG,KC_simG), eye(KH_simG)          , Phi_mtx               ;...
                     zeros(KL_simG,KC_simG), Phi_mtx'              , eye(KL_simG)         ];

% Note: this choice generates an uncoditional var-cov matrix of all the factors 
% sampled at HF, and stacked in g_{m,t} equal to  

%                             [ I  0     0   ]
% V(g_{n,t}) =(1/(M^2)*kappa)*[ 0  I     Phi ]   
%                             [ 0  Phi'  I   ]

% and an unconditional var-cov matrix of all the factors sampled at LF 
% (that is summed over the m subperiods) and stacked in \bar{g}_{t} equal to  

%                  [ I  0     0   ]
% V(\bar{g}_{t}) = [ 0  I     Phi ]   
%                  [ 0  Phi'  I   ]

% as described in the current version of the Online Appendix 
%--------------------------------------------------------------------------
v_sim      = mvnrnd(zeros(1,K_all_simG), fac_inn_cov_mat, (m*T_sim)+1) ;

% Sample first observation from unconditional distribution of factors 
% from the VAR(1) model for the staccked factors (sampled at HF).
% The unconditional var-cov matrix of the VAR process is formula (2.1.32) 
% inthe book  "New Introduction to multiple Time Series"
% by H. Lutkepohl, Springer, corrected second printing 2007 

vec_unc_var_fac = (eye(K_all_simG^2)-kron(A_mtx,A_mtx))\reshape(fac_inn_cov_mat,K_all_simG^2,1) ;
unc_var_fac     = reshape(vec_unc_var_fac, K_all_simG, K_all_simG) ;
v_sim(1,:)      = mvnrnd(zeros(1,K_all_simG), unc_var_fac, 1)      ;

% Use VAR(1) model to simulate fators starting form second observation
for t=2:(m*T_sim+1)
     g_sim(:,t) = A_mtx*g_sim(:,t-1) + v_sim(t,:)' ;
end

% eliminate initial observation and transpose
g_sim  = g_sim(:,2:end)'                          ; 
FC_sim = g_sim(:,1:KC_simG)                       ;
FH_sim = g_sim(:,(KC_simG+1):(KC_simG+KH_simG))   ;
FL_sim = g_sim(:,(KC_simG+KH_simG+1):K_all_simG)  ;

% FLOW SAMPLED VERSION OF THE FACTORS
FC_sim_fl = zeros(T_sim,KC_simG) ;
FH_sim_fl = zeros(T_sim,KH_simG) ;
FL_sim_fl = zeros(T_sim,KL_simG) ;

for t = 1:T_sim
    % Flow samp.
    t_start        = m*(t-1)+1                    ;
    t_end          = m*t                          ;
    FC_sim_fl(t,:) = sum(FC_sim(t_start:t_end,:),1) ;
    FH_sim_fl(t,:) = sum(FH_sim(t_start:t_end,:),1) ;
    FL_sim_fl(t,:) = sum(FL_sim(t_start:t_end,:),1) ;
end
%##########################################################################
%##########################################################################
% Simulation of LOADINGS
%##########################################################################
%##########################################################################
% SAMPLE CS distributions of R^2: Uniform 

R_Hall_vec = unifrnd(R_Hall_min,R_Hall_max, N_H_sim, 1) ; 
if KH_sim ~= 0
delta_HC_load = unifrnd(delta_HCmin, delta_HCmax , N_H_sim, 1);
else
delta_HC_load = unifrnd(1, 1 , N_H_sim, 1);   
end
R_H_C_vec  = R_Hall_vec.*delta_HC_load ; 

R_Lall_vec = unifrnd(R_Lall_min,R_Lall_max, N_L_sim, 1) ; 
if KL_sim ~= 0
delta_LC_load = unifrnd(delta_LCmin, delta_LCmax , N_L_sim, 1);
else
delta_LC_load = unifrnd(1, 1 , N_L_sim, 1);   
end
R_L_C_vec  = R_Lall_vec.*delta_LC_load ; 

%--------------------------------------------------------------------------
% Simulate lambdas as funtions of R^2
%--------------------------------------------------------------------------
L_HC_sim   = zeros(N_H_sim,KC_simG) ;
L_H_sim    = zeros(N_H_sim,KH_simG) ;
L_LC_sim   = zeros(N_L_sim,KC_simG) ;
L_L_sim    = zeros(N_L_sim,KL_simG) ;

L_HC_sim_temp = mvnrnd(zeros(KC_simG,1), eye(KC_simG), N_H_sim) ;
L_H_sim_temp  = mvnrnd(zeros(KH_simG,1), eye(KH_simG), N_H_sim) ;
L_LC_sim_temp = mvnrnd(zeros(KC_simG,1), eye(KC_simG), N_L_sim) ;
L_L_sim_temp  = mvnrnd(zeros(KL_simG,1), eye(KL_simG), N_L_sim) ;

%--------------------------------------------------------------------------
% LOADINGS FOR HF DATA
%--------------------------------------------------------------------------
for ind = 1:N_H_sim
    
    Rall_temp = R_Hall_vec(ind,1); 
    RC_temp   = R_H_C_vec(ind,1) ; 
               
    l_star_HC2  = (M2k/KC_sim)*(RC_temp/(1-Rall_temp))             ;
    l_star_H2   = (M2k/KH_sim)*((Rall_temp-RC_temp)/(1-Rall_temp)) ;
    
    if KC_sim > 0
    L_HC_sim(ind,:) = sqrt(l_star_HC2)*L_HC_sim_temp(ind,:);
    else 
    L_HC_sim(ind,:) = 0*L_HC_sim_temp(ind,:);    
    end 
    
    if KH_sim > 0
    L_H_sim(ind,:)  = sqrt(l_star_H2)*L_H_sim_temp(ind,:); 
    else 
    L_H_sim(ind,:) = 0*L_H_sim_temp(ind,:); 
    end
end

%--------------------------------------------------------------------------
% LOADINGS FOR LF DATA (assuming flow sampling) 
% note: formulas hold for generic value 'm' of HF subperiods 
% within each LF period
%--------------------------------------------------------------------------
for ind = 1:N_L_sim    
    Rall_temp = R_Lall_vec(ind,1); 
    RC_temp   = R_L_C_vec(ind,1) ; 
    
    l_star_LC2  = (M2k_e/KC_sim)*(RC_temp/(1-Rall_temp))             ;
    l_star_L2   = (M2k_e/KL_sim)*((Rall_temp-RC_temp)/(1-Rall_temp)) ;
    
    if KC_sim > 0
    L_LC_sim(ind,:) = sqrt(l_star_LC2)*L_LC_sim_temp(ind,:);
    else 
    L_LC_sim(ind,:) = 0*L_LC_sim_temp(ind,:);    
    end 
    
    if KL_sim > 0
    L_L_sim(ind,:)  = sqrt(l_star_L2)*L_L_sim_temp(ind,:); 
    else
    L_L_sim(ind,:) = 0*L_L_sim_temp(ind,:); 
    end    
end
%--------------------------------------------------------------------------
end % end of function